(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    462418,      13368]
NotebookOptionsPosition[    411866,      11685]
NotebookOutlinePosition[    412828,      11718]
CellTagsIndexPosition[    412740,      11713]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " supplement ",
 StyleBox["for\n\"A Physical Interpretation of the Product Operator Formalism\
\"\nD.P. Goldenberg\n", "Subtitle",
  FontWeight->"Plain"],
 StyleBox["April 2009", "Subsubtitle",
  FontWeight->"Plain"]
}], "Title",
 CellChangeTimes->{{3.4322312827331953`*^9, 3.4322313575580597`*^9}, {
  3.433246753526896*^9, 3.433246757491839*^9}, {3.447694681124321*^9, 
  3.4476947111457357`*^9}}],

Cell[CellGroupData[{

Cell["Introduction to the supplement", "Section",
 CellChangeTimes->{{3.432231370523934*^9, 3.4322313773243017`*^9}}],

Cell[TextData[{
 "This supplement is intended to provide the mathematical details and \
examples that have been left out of the main paper, as well as to provide a \
means for the reader to carry out additional calculations.  \n\nThe \
definitions and equations used for this notebook are provided in two ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package files.  For the system composed of a single isolated spin, the \
\"oneSpinLib\" package is used, while a separate package \"twoSpinLib\" is \
used for calculations involving a scalar-coupled spin pair.  These packages \
are not needed to read the notebook, but are necessary to carry out \
calculations.  The library files must be placed in an appropriate location \
where ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will look for them.  I suggest creating a directory \"NMR \"in the \
Applications directory in $BaseDirectory. (this is /Library/Mathematica on \
Mac OS X) or in  $UserBaseDirectory (~/Library/",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " on Mac OS X).\n\nIf installed in one of these locations, the packages are \
loaded with the commands:\n<< NMR`oneSpinLib`\nor\n<< NMR`twoSpinLib`\n\
Because some of the same names are used for different functions in the two \
libraries, one set must be cleared before the other is loaded.  This is done \
with:\nRemove[\"NMR`oneSpinLib`*\"]\nor \nRemove[\"NMR`twoSpinLib`*\"]\n\n\
Each of the packages includes two sets of functions, one for calculations \
involving wavefunctions representing pure populations and the other for \
calculations involving density matrices, which can represent either pure \
populations or mixtures of spins with different wavefunctions.  Functions \
involving wavefunctions are identified with \"psi\" as part of the name, \
while functions involving density matrices are identified with \"rho\".\n\n\
There are at least two other ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks available for carrying out product-operator calculations:\n\t\
Prod_Op_Cart.nb by John Shriver\n\tPOMA.nb by Peter Guntert.\nBoth of these \
can be obtained at: http://www.nmr.chem.uu.nl/~hsu/NMR/POMA/poma.html\n\nThe \
two notebooks cited above implement the product operator formalism using \
symbolic manipulations.  The packages for this notebook, on the other hand, \
uses matrix representations of the wavefunctions, operators and the density \
matrix to calculate the effects of pulses and evolution periods.  The \
operators are used to calculate the average observable magnetization \
components and correlations, as described in the text.\n\nLike the \
accompanying manuscript, this notebook and the associated packages assumes a \
\"left-hand rule\" for the effects of pulses and precession.  This is \
contrary to the convention of Sorensen et al. (Progress in NMR Spectroscopy \
16, 163-192 (1983)), but it is consistent with most vector representations of \
NMR experiments, where, for instance, a positive pulse along the x-axis \
rotates z-magnetization towards the y-axis.\n"
}], "Text",
 CellChangeTimes->{{3.432231404679473*^9, 3.432231474466008*^9}, {
   3.43223187982471*^9, 3.432232049736486*^9}, {3.4322321046834593`*^9, 
   3.4322321690157824`*^9}, {3.432232969348384*^9, 3.432233063405813*^9}, {
   3.432233097813435*^9, 3.432233229792433*^9}, {3.432233299029387*^9, 
   3.43223335164699*^9}, {3.432233418726645*^9, 3.432233424577702*^9}, {
   3.432233541040265*^9, 3.4322335582530413`*^9}, {3.432233707636104*^9, 
   3.432233889593855*^9}, {3.432238485717683*^9, 3.432238487206109*^9}, {
   3.432239975783184*^9, 3.4322399790588217`*^9}, {3.445620632557312*^9, 
   3.445620637620426*^9}, {3.4456206846349983`*^9, 3.445620686314746*^9}, {
   3.447688116095355*^9, 3.447688117229393*^9}, {3.447688150153009*^9, 
   3.447688150645747*^9}, {3.447688212505816*^9, 3.447688213968966*^9}, {
   3.447688672321331*^9, 3.447688824925433*^9}, {3.4476923483445*^9, 
   3.4476925737803087`*^9}, {3.447692631011696*^9, 3.4476927691666327`*^9}, {
   3.447692807851099*^9, 3.447692843452641*^9}, {3.447693409074745*^9, 
   3.447693428979969*^9}, {3.447693523769137*^9, 3.4476935421529093`*^9}, {
   3.447693610737561*^9, 3.44769361879082*^9}, 3.447694254305821*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Some ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " conventions"
}], "Subsection",
 CellChangeTimes->{{3.43223850577664*^9, 3.432238515429276*^9}}],

Cell[TextData[{
 "Because they have to be interpreted by a machine, the expressions used in \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " must follow rather strict rules of syntax.  One aspect that is \
particularly important in using this notebook is the convention for \
parentheses and brackets:\n1. Parentheses are used only to group the parts of \
an algebraic expression, for instance (a+b)(c+d)\n\n2. Square brackets are \
used to enclose the arguments of a function, either built in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions or user-defined functions.  For instance Sin[x].  The names of \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built in functions always begin with a capital letter, and it is \
considered good form to begin the names of user functions with a lower case \
letter.  I have broken this rule for symbols representing matrices or matrix \
functions, including the Ix, Iy and Iz operators and the matrices for \
rotation and time evolution.\n\n3. Curly brackets are used to represent \
lists, including vectors and matrices.  For instance a two-element vector is \
written as: {a,b}, and a 2x2 matrix is written as a list of two two-element \
vectors, where the individual vectors are the rows: {{a,b},{c,d}}\n\nThe \
output of matrices can be made to follow the normal convention by entering\n\
$PrePrint = If[MatrixQ[#], MatrixForm[#], #] &\nat the beginning of a \
workbook.  This is included automatically in the two libraries, so that when \
a matrix is entered as described above, the output is in the usual row-column \
form:"
}], "Text",
 CellChangeTimes->{{3.432238526086299*^9, 3.432239133035533*^9}, {
   3.432252317049876*^9, 3.4322523779277773`*^9}, {3.432252716043395*^9, 
   3.432252720301952*^9}, 3.447629400948618*^9, {3.447692885742626*^9, 
   3.447692887052318*^9}, {3.447694256220871*^9, 3.4476942711882257`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$PrePrint", " ", "=", " ", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"MatrixQ", "[", "#", "]"}], ",", " ", 
     RowBox[{"MatrixForm", "[", "#", "]"}], ",", " ", "#"}], "]"}], " ", 
   "&"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"MatrixQ", "[", "#1", "]"}], ",", 
    TagBox["#1",
     Function[BoxForm`e$, 
      MatrixForm[BoxForm`e$]]], ",", "#1"}], "]"}], "&"}]], "Output",
 CellChangeTimes->{3.44769372123393*^9, 3.447694127160239*^9, 
  3.447949673424385*^9, 3.447949793757811*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.447682822230792*^9, 3.447682829423208*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2"},
     {"3", "4"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.4322390617949553`*^9, 3.432249822556637*^9, 3.432252124432075*^9, 
   3.432296791210722*^9, 3.4330914546915913`*^9, 3.433176768941765*^9, 
   3.433245728324441*^9, 3.433458042148656*^9, {3.445620867566936*^9, 
   3.445620896961254*^9}, 3.445965683052565*^9, 3.447629446325996*^9, 
   3.447682835412529*^9, 3.44769336380534*^9, {3.4476936926352587`*^9, 
   3.4476937214816628`*^9}, 3.447694127469616*^9, 3.447949673634878*^9, 
   3.447949799320918*^9}]
}, Open  ]],

Cell["\<\
It is often convenient to be able to access the result of a previous \
calculation.  The symbol \"%\" always represents to result of the last \
calculation, and can be entered into a new calculation.  For instance:\
\>", "Text",
 CellChangeTimes->{{3.4476928970125103`*^9, 3.4476929733208733`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"6", "^", "2"}]], "Input",
 CellChangeTimes->{{3.447693034116973*^9, 3.447693037233529*^9}}],

Cell[BoxData["36"], "Output",
 CellChangeTimes->{3.447693039237838*^9, 3.447693363886674*^9, 
  3.447693725967729*^9, 3.447694127593935*^9, 3.44794967369771*^9, 
  3.4479498013229933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["%"], "Input",
 CellChangeTimes->{3.447693043285132*^9}],

Cell[BoxData["36"], "Output",
 CellChangeTimes->{3.447693047672866*^9, 3.4476933640009937`*^9, 
  3.447693730792049*^9, 3.4476941277326183`*^9, 3.4479496737484818`*^9, 
  3.4479498034598637`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sqrt", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.44769304961742*^9, 3.447693056007166*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.4476930569436483`*^9, 3.4476933641351233`*^9, 
  3.447693732964033*^9, 3.4476941278311033`*^9, 3.447949673799354*^9, 
  3.447949805513433*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a number of built in functions to simplify algebraic expressions or \
apply trigonometric identities.  If the program generates something in one \
form, one of these functions can be used to try to simplify it or change it \
to more useful form:"
}], "Text",
 CellChangeTimes->{{3.447693087546352*^9, 3.4476931867068663`*^9}, {
  3.447693239229933*^9, 3.4476932471849327`*^9}, {3.447694285083748*^9, 
  3.447694287715947*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.4476932509704*^9, 3.447693364200878*^9, 
  3.447693739211857*^9, 3.4476941279325123`*^9, 3.447949673866037*^9, 
  3.4479498086223507`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447693252942854*^9, 3.447693259818097*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "-", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}], "-", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "+", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447693260943453*^9, 3.4476933642885647`*^9, 
  3.447693742068281*^9, 3.447694128030785*^9, 3.447949673933655*^9, 
  3.447949811327919*^9}]
}, Open  ]],

Cell["Previous results can also be referred to by line number:", "Text",
 CellChangeTimes->{{3.447693319381741*^9, 3.4476933324307137`*^9}, 
   3.447694289890609*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Out", "[", "6", "]"}]], "Input",
 CellChangeTimes->{{3.447693623504548*^9, 3.447693628542163*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447693630205304*^9, 3.447693744923402*^9, 
  3.447694128131901*^9, 3.447949673999645*^9, 3.447949814883244*^9}]
}, Open  ]],

Cell["Or", "Text",
 CellChangeTimes->{{3.447693754479116*^9, 3.447693755826418*^9}, 
   3.44769429498624*^9}],

Cell[CellGroupData[{

Cell[BoxData["%4"], "Input",
 CellChangeTimes->{{3.4476937605644007`*^9, 3.447693767852017*^9}}],

Cell[BoxData["36"], "Output",
 CellChangeTimes->{3.4476937691923313`*^9, 3.447694128229739*^9, 
  3.4479496740663967`*^9, 3.447949819577127*^9}]
}, Open  ]],

Cell["\<\
Substitutions can be incorporated into expressions as shown below:\
\>", "Text",
 CellChangeTimes->{{3.4476938033720083`*^9, 3.447693836312306*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "+", "y"}]], "Input",
 CellChangeTimes->{{3.447693842246888*^9, 3.447693845009899*^9}}],

Cell[BoxData[
 RowBox[{"x", "+", "y"}]], "Output",
 CellChangeTimes->{3.447693846991119*^9, 3.447694128431781*^9, 
  3.447949674132218*^9, 3.447949823168264*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "+", "y"}], " ", "/.", " ", 
  RowBox[{"x", "\[Rule]", " ", "5"}]}]], "Input",
 CellChangeTimes->{{3.447693848712072*^9, 3.447693888245322*^9}}],

Cell[BoxData[
 RowBox[{"5", "+", "y"}]], "Output",
 CellChangeTimes->{3.4476938891738253`*^9, 3.44769412853111*^9, 
  3.4479496741839542`*^9, 3.447949825056055*^9}]
}, Open  ]],

Cell["A multiple substitution", "Text",
 CellChangeTimes->{{3.447693901973487*^9, 3.447693907422186*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "+", "y"}], " ", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "5"}], ",", " ", 
    RowBox[{"y", "\[Rule]", "6"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.447693912428912*^9, 3.447693934415511*^9}}],

Cell[BoxData["11"], "Output",
 CellChangeTimes->{3.4476939362741957`*^9, 3.4476941286300077`*^9, 
  3.4479496742495832`*^9, 3.447949827798772*^9}]
}, Open  ]],

Cell["\<\
These substitutions do not assign values to the symbols x and y:\
\>", "Text",
 CellChangeTimes->{{3.4476939376490173`*^9, 3.4476939753645163`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["X"], "Input",
 CellChangeTimes->{3.4476939777829313`*^9}],

Cell[BoxData["X"], "Output",
 CellChangeTimes->{3.447693979786627*^9, 3.4476941287126303`*^9, 
  3.447949674300622*^9, 3.447949831185158*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["y"], "Input",
 CellChangeTimes->{3.447693980789261*^9}],

Cell[BoxData["y"], "Output",
 CellChangeTimes->{3.44769398232362*^9, 3.44769412879595*^9, 
  3.447949674351199*^9, 3.4479498342914877`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wavefunctions and operators for an isolated spin", "Section",
 CellChangeTimes->{{3.43223392889676*^9, 3.4322339415458393`*^9}}],

Cell[CellGroupData[{

Cell["Loading the one-spin library", "Subsection",
 CellChangeTimes->{{3.432234011454279*^9, 3.432234020923119*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.432250362035475*^9, 3.4322503694929953`*^9}}],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<NMR`oneSpinLib`*\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"<<", "NMR`oneSpinLib`"}]], "Input",
 CellChangeTimes->{3.432251791818787*^9}],

Cell["\<\
The objects defined by the library can be listed with the Names function\
\>", "Text",
 CellChangeTimes->{{3.432234052371887*^9, 3.432234079702189*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Names", "[", "\"\<NMR`oneSpinLib`*\>\"", "]"}]], "Input",
 CellChangeTimes->{3.4322334036787577`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"allMagPsi\"\>", ",", "\<\"allMagRho\"\>", 
   ",", "\<\"ca\"\>", ",", "\<\"cb\"\>", ",", "\<\"deltaP\"\>", 
   ",", "\<\"H\"\>", ",", "\<\"Hinv\"\>", ",", "\<\"Ix\"\>", 
   ",", "\<\"Iy\"\>", ",", "\<\"Iz\"\>", ",", "\<\"meanPsi\"\>", 
   ",", "\<\"meanRho\"\>", ",", "\<\"nu\"\>", ",", "\<\"op\"\>", 
   ",", "\<\"psi\"\>", ",", "\<\"psiA\"\>", ",", "\<\"psiB\"\>", 
   ",", "\<\"psiGen\"\>", ",", "\<\"psiPi2x\"\>", ",", "\<\"psiPi2y\"\>", 
   ",", "\<\"psiPix\"\>", ",", "\<\"psiPiy\"\>", ",", "\<\"psiPulseX\"\>", 
   ",", "\<\"psiPulseY\"\>", ",", "\<\"psiTime\"\>", ",", "\<\"rho\"\>", 
   ",", "\<\"rhoEq\"\>", ",", "\<\"rhoGen\"\>", ",", "\<\"rhoPi2x\"\>", 
   ",", "\<\"rhoPi2y\"\>", ",", "\<\"rhoPix\"\>", ",", "\<\"rhoPiy\"\>", 
   ",", "\<\"rhoPulseX\"\>", ",", "\<\"rhoPulsey\"\>", 
   ",", "\<\"rhoPulseY\"\>", ",", "\<\"rhoTime\"\>", ",", "\<\"Rinvx\"\>", 
   ",", "\<\"Rinvy\"\>", ",", "\<\"Rx\"\>", ",", "\<\"Ry\"\>", 
   ",", "\<\"t\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.432233394607795*^9, 3.432233404462129*^9}, {
   3.432233446184062*^9, 3.432233459194091*^9}, {3.432233590353037*^9, 
   3.432233595264078*^9}, 3.432233630218534*^9, 3.432234083171461*^9, 
   3.432234260125464*^9, 3.432234298381249*^9, 3.432249823466032*^9, 
   3.432250377356146*^9, 3.4322504351312037`*^9, 3.432250575126768*^9, 
   3.432250627895297*^9, 3.432250774199856*^9, 3.432250816036295*^9, 
   3.4322521251414957`*^9, 3.432296792648465*^9, 3.433091455934577*^9, 
   3.433176770089862*^9, 3.43324572952973*^9, 3.433458043167169*^9, 
   3.445620940934466*^9, 3.44596568443756*^9, 3.447629513994905*^9, 
   3.447682836203046*^9, 3.447693365637763*^9, 3.4476941300549297`*^9, 
   3.44794967553528*^9, 3.4479499173860083`*^9}]
}, Open  ]],

Cell["For information about an object, type \"?name\". For instance:", "Text",
 CellChangeTimes->{{3.432234095347475*^9, 3.432234128940576*^9}, {
  3.4322529165312023`*^9, 3.43225292417739*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "allMagPsi"}]], "Input",
 CellChangeTimes->{{3.432234135665427*^9, 3.432234139453524*^9}}],

Cell[BoxData[
 StyleBox["\<\"allMagPsi[psi] writes output with all three magnetization \
components when applied to a wavefunction psi\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.447949920981179*^9},
 CellTags->"Info3447928320-2751242"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wavefunctions", "Subsection",
 CellChangeTimes->{{3.4322343319265327`*^9, 3.432234337246477*^9}}],

Cell[TextData[{
 "In the text, wavefunctions are written in the Dirac notation, so that the \
general form of a wavefunction for a single spin is written as:\n|",
 StyleBox["Y",
  FontFamily->"Symbol"],
 "> = c",
 StyleBox["a",
  FontFamily->"Symbol"],
 " |",
 StyleBox["a",
  FontFamily->"Symbol"],
 "> + c",
 StyleBox["b",
  FontFamily->"Symbol"],
 " |",
 StyleBox["b",
  FontFamily->"Symbol"],
 ">\nFor calculations with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", it is more convenient to use a vector representation of the \
wavefunctions, and matrices for operators.\nFor a single spin, the \
wavefunction is a vector with two elements, corresponding to the complex \
coefficients for the |",
 StyleBox["a",
  FontFamily->"Symbol"],
 "> and |",
 StyleBox["b",
  FontFamily->"Symbol"],
 "> basis wavefunctions.  The oneSpinLib package defines the general form of \
a wavefunction:"
}], "Text",
 CellChangeTimes->{{3.432234348295326*^9, 3.4322344399956293`*^9}, {
   3.4322345155956297`*^9, 3.432234688452589*^9}, 3.447694305136696*^9}],

Cell[CellGroupData[{

Cell[BoxData["psiGen"], "Input",
 CellChangeTimes->{{3.432234691833708*^9, 3.432234693389522*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"ca", ",", "cb"}], "}"}]], "Output",
 CellChangeTimes->{3.4322346947034397`*^9, 3.43224982403197*^9, 
  3.432252125767465*^9, 3.432296793378728*^9, 3.4330914564478188`*^9, 
  3.433176770566292*^9, 3.43324573017679*^9, 3.433458043732376*^9, 
  3.445620986425604*^9, 3.445621367610363*^9, 3.445965685346884*^9, 
  3.447629560183649*^9, 3.447682836989244*^9, 3.447693366585774*^9, 
  3.4476941310938787`*^9, 3.447949676418704*^9, 3.447949923277605*^9}]
}, Open  ]],

Cell[TextData[{
 "Note that in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", vectors are written as a list of elements enclosed in curly braces.  \
There is no distinction between row and column vectors.  The basis \
wavefunctions,  |",
 StyleBox["a",
  FontFamily->"Symbol"],
 "> and |",
 StyleBox["b",
  FontFamily->"Symbol"],
 ">, are defined as:"
}], "Text",
 CellChangeTimes->{{3.432234723583067*^9, 3.432234770754073*^9}, {
  3.432234855050756*^9, 3.4322348657753687`*^9}, {3.447629583910201*^9, 
  3.44762960501993*^9}}],

Cell[CellGroupData[{

Cell[BoxData["psiA"], "Input",
 CellChangeTimes->{{3.432234868656128*^9, 3.432234869483593*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.4322348707406054`*^9, 3.432249824110176*^9, 
  3.432252125820825*^9, 3.432296793454946*^9, 3.4330914565046663`*^9, 
  3.433176770615065*^9, 3.433245730252798*^9, 3.433458043782711*^9, 
  3.4456213698806562`*^9, 3.445965685432974*^9, 3.447629573373001*^9, 
  3.447682837058282*^9, 3.4476933666715517`*^9, 3.447694131162094*^9, 
  3.447949676487075*^9, 3.447949925136957*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["psiB"], "Input",
 CellChangeTimes->{{3.43223487179456*^9, 3.4322348729605722`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.432234874013091*^9, 3.432249824176647*^9, 
  3.4322521258715963`*^9, 3.4322967935186234`*^9, 3.433091456557769*^9, 
  3.433176770665555*^9, 3.43324573031912*^9, 3.433458043832754*^9, 
  3.4456213725358133`*^9, 3.4459656855003843`*^9, 3.447629577006359*^9, 
  3.447682837208552*^9, 3.4476933667373457`*^9, 3.447694131228187*^9, 
  3.447949676553693*^9, 3.447949926734839*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operators", "Subsection",
 CellChangeTimes->{{3.432234902528612*^9, 3.4322349040541573`*^9}}],

Cell["\<\
Operators are represented by matrices, and the action of the operator on a \
wavefunction is calculated by multiplying the wavefunction by the operator.  \
The three magnetization operators are:\
\>", "Text",
 CellChangeTimes->{{3.432234923503621*^9, 3.432235006139332*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Ix"], "Input",
 CellChangeTimes->{{3.432235010586775*^9, 3.4322350107646933`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432235011838271*^9, 3.43224982425508*^9, 
  3.43225212593783*^9, 3.4322967938573303`*^9, 3.4330914566773357`*^9, 
  3.433176770742992*^9, 3.433245730414033*^9, 3.433458043933783*^9, 
  3.445965685566032*^9, 3.447629616674541*^9, 3.447682837276043*^9, 
  3.4476933668055487`*^9, 3.447694131296256*^9, 3.447949676621716*^9, 
  3.447949930628251*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Iy"], "Input",
 CellChangeTimes->{{3.432235013133041*^9, 3.432235013804225*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}]},
     {
      FractionBox["\[ImaginaryI]", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432235014696232*^9, 3.432249824311206*^9, 
  3.4322521260055304`*^9, 3.43229679392564*^9, 3.433091456723007*^9, 
  3.43317677078214*^9, 3.433245730470091*^9, 3.433458043983389*^9, 
  3.44596568563503*^9, 3.447629620050029*^9, 3.447682837342843*^9, 
  3.447693366872258*^9, 3.447694131363138*^9, 3.447949676688479*^9, 
  3.447949932398518*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Iz"], "Input",
 CellChangeTimes->{{3.432235015830675*^9, 3.4322350161753683`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "2"], "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432235018017104*^9, 3.432249824360941*^9, 
  3.4322521260731163`*^9, 3.432296793991253*^9, 3.4330914568175087`*^9, 
  3.4331767708522463`*^9, 3.43324573053749*^9, 3.43345804405015*^9, 
  3.445965685701613*^9, 3.447629624016642*^9, 3.447682837409964*^9, 
  3.447693366956402*^9, 3.447694131430187*^9, 3.447949676754725*^9, 
  3.447949934185163*^9}]
}, Open  ]],

Cell["\<\
Vector and matrix multiplication are entered by placing a period between the \
arguments, as shown below for some examples of the action of the operators;\
\>", "Text",
 CellChangeTimes->{{3.432235088365162*^9, 3.432235106145433*^9}, {
   3.432235146539166*^9, 3.432235204285944*^9}, 3.4456214806073027`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "psiA"}]], "Input",
 CellChangeTimes->{{3.432235111302422*^9, 3.432235127409093*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", "2"]}], "}"}]], "Output",
 CellChangeTimes->{{3.432235119229311*^9, 3.432235128513657*^9}, 
   3.432249824474979*^9, 3.4322521261392307`*^9, 3.432296794079105*^9, 
   3.433091456997386*^9, 3.433176770940919*^9, 3.433245730668445*^9, 
   3.4334580441321163`*^9, 3.445965685793955*^9, 3.4476297065627813`*^9, 
   3.447682837475627*^9, 3.4476933670398483`*^9, 3.447694131496098*^9, 
   3.447949676820771*^9, 3.44794993693893*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iy", ".", "psiA"}]], "Input",
 CellChangeTimes->{{3.4322352079525537`*^9, 3.432235210210573*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["\[ImaginaryI]", "2"]}], "}"}]], "Output",
 CellChangeTimes->{3.432235211705822*^9, 3.432249824554756*^9, 
  3.4322521262052383`*^9, 3.4322967941586514`*^9, 3.4330914570677547`*^9, 
  3.4331767710919323`*^9, 3.433245730739376*^9, 3.4334580441843433`*^9, 
  3.445965685866864*^9, 3.4476297104566708`*^9, 3.447682837543578*^9, 
  3.447693367123954*^9, 3.4476941315821238`*^9, 3.447949676888288*^9, 
  3.4479499406146917`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iz", ".", "psiA"}]], "Input",
 CellChangeTimes->{{3.432235214599031*^9, 3.432235216710513*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432235217887217*^9, 3.432249824638091*^9, 
  3.432252126274128*^9, 3.432296794229559*^9, 3.43309145715088*^9, 
  3.433176771153043*^9, 3.4332457308060093`*^9, 3.4334580443088837`*^9, 
  3.4459656859510527`*^9, 3.44762971612955*^9, 3.447682837610973*^9, 
  3.447693367189229*^9, 3.447694131666356*^9, 3.447949676954975*^9, 
  3.447949943085782*^9}]
}, Open  ]],

Cell["\<\
Notice that the result of multiplying psiA by Iz is the original vector times \
a constant, 1/2.  This defines psiA as an eigenfunction (or eigenvector} of \
Iz, and the eigenvalue, 1/2, represents the value of the observable, Iz, that \
will always be produced by the measurement.  psiB is the other eigenfunction \
of Iz:\
\>", "Text",
 CellChangeTimes->{{3.432235230814457*^9, 3.4322353619369593`*^9}, {
  3.4322355795954657`*^9, 3.4322355903794823`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iz", ".", "psiB"}]], "Input",
 CellChangeTimes->{{3.432235364763865*^9, 3.432235366563817*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.432235368184895*^9, 3.432249824723467*^9, 
  3.432252126340166*^9, 3.432296794309009*^9, 3.433091457235084*^9, 
  3.433176771219088*^9, 3.433245730856408*^9, 3.433458044384853*^9, 
  3.4459656860355883`*^9, 3.4476297269130983`*^9, 3.447682837680011*^9, 
  3.44769336725522*^9, 3.447694131731741*^9, 3.447949677022217*^9, 
  3.447949946042738*^9}]
}, Open  ]],

Cell[TextData[{
 "In this case, the eigenvalue is -1/2.  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can find the eigenfunctions and eigenvalues for any operator defined by a \
square matrix:"
}], "Text",
 CellChangeTimes->{{3.43223538567444*^9, 3.4322354353748817`*^9}, {
   3.4322355192094088`*^9, 3.4322355217323313`*^9}, 3.4476297418356333`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "Iz", "]"}]], "Input",
 CellChangeTimes->{{3.432235439628689*^9, 3.432235476859323*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.43223546555411*^9, 3.4322354779494743`*^9}, 
   3.4322498248954697`*^9, 3.432252126408671*^9, 3.4322967944009647`*^9, 
   3.4330914573954487`*^9, 3.433176771372053*^9, 3.4332457309560137`*^9, 
   3.433458044529458*^9, 3.445965686140704*^9, 3.447629747666523*^9, 
   3.447682837863146*^9, 3.447693367323061*^9, 3.4476941318153467`*^9, 
   3.4479496770891*^9, 3.4479499567493*^9}]
}, Open  ]],

Cell["\<\
The first part of the result is a list of the two eigenvalues, and the second \
part is a list of the two eigenvectors.  For the other two magnetization \
operators:\
\>", "Text",
 CellChangeTimes->{{3.432235536840351*^9, 3.432235621573031*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "Ix", "]"}]], "Input",
 CellChangeTimes->{{3.432235623899219*^9, 3.432235624130845*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.432235625174933*^9, 3.432249825140243*^9, 
  3.432252126473987*^9, 3.4322967944848337`*^9, 3.4330914575622873`*^9, 
  3.433176771539145*^9, 3.433245731068183*^9, 3.433458044686013*^9, 
  3.4459656862807837`*^9, 3.447629758729266*^9, 3.4476828382805843`*^9, 
  3.4476933673915157`*^9, 3.4476941318993187`*^9, 3.44794967715659*^9, 
  3.447949958794297*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "Iy", "]"}]], "Input",
 CellChangeTimes->{{3.432235635061906*^9, 3.4322356354026337`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[ImaginaryI]", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4322356406510267`*^9, 3.4322498252898617`*^9, 
  3.432252126541009*^9, 3.432296794746544*^9, 3.433091457744905*^9, 
  3.433176771710403*^9, 3.4332457312068*^9, 3.433458044845848*^9, 
  3.445965686527194*^9, 3.447629762306141*^9, 3.4476828385601597`*^9, 
  3.447693367473765*^9, 3.447694132095613*^9, 3.447949677256119*^9, 
  3.447949960675469*^9}]
}, Open  ]],

Cell[TextData[{
 "These forms of the eigenvectors are not normalized, as they must be in \
order to generate appropriate values in quantum-mechanical calculations.  \
But, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can take care of this.  For the Ix eigenfunctions:"
}], "Text",
 CellChangeTimes->{{3.432236754098028*^9, 3.4322368158233852`*^9}, {
   3.432238095365065*^9, 3.432238112737091*^9}, 3.447694313838196*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322368201324043`*^9, 3.432236823270296*^9}, {
  3.4322381208817797`*^9, 3.432238123149847*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.4322381246305733`*^9, 3.432249825376196*^9, 
  3.432252126607638*^9, 3.432296794832623*^9, 3.433091457842923*^9, 
  3.433176771797447*^9, 3.4332457312881413`*^9, 3.4334580449325743`*^9, 
  3.445965686603407*^9, 3.447629774872972*^9, 3.447682838628956*^9, 
  3.44769336765456*^9, 3.447694132184104*^9, 3.447949677322452*^9, 
  3.447949963997348*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.4322381332577333`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.432238135028873*^9, 3.432249825442507*^9, 
  3.432252126674252*^9, 3.432296794913376*^9, 3.4330914579854803`*^9, 
  3.433176771856098*^9, 3.433245731359437*^9, 3.433458044987897*^9, 
  3.445965686685789*^9, 3.447629779496183*^9, 3.4476828387144337`*^9, 
  3.447693367739994*^9, 3.447694132266582*^9, 3.447949677502564*^9, 
  3.447949965902504*^9}]
}, Open  ]],

Cell["For the Iy eigenfunctions:", "Text",
 CellChangeTimes->{{3.432238140342368*^9, 3.432238153415694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{"\[ImaginaryI]", ",", "1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.432238157655902*^9, 3.43223816866048*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.432238169485804*^9, 3.4322498255421133`*^9, 
  3.432252126851707*^9, 3.432296794980268*^9, 3.433091458071279*^9, 
  3.4331767719219837`*^9, 3.433245731425852*^9, 3.4334580450545397`*^9, 
  3.445965686770001*^9, 3.447629784369287*^9, 3.447682838781335*^9, 
  3.447693367822796*^9, 3.447694132350389*^9, 3.447949677572274*^9, 
  3.44794996842388*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], ",", "1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.432238193856492*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["2"]]}], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.4322381951731453`*^9, 3.432249825626727*^9, 
  3.4322521269085207`*^9, 3.4322967950660686`*^9, 3.433091458173321*^9, 
  3.433176771989168*^9, 3.433245731475987*^9, 3.433458045121524*^9, 
  3.445965686854526*^9, 3.4476297877502613`*^9, 3.447682838847376*^9, 
  3.447693367889557*^9, 3.447694132434169*^9, 3.4479496776395063`*^9, 
  3.4479499703108883`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The average outcome of a measurement", "Subsection",
 CellChangeTimes->{{3.4322356944222383`*^9, 3.4322357281025267`*^9}}],

Cell[TextData[{
 "The average value of a measurement, A, applied to a large number of \
particles with the same wavefunction is calculated as:\n<A> = <Psi | A | \
Psi>, as written in Dirac notation.  For a system involving only spins, the \
bracket represents the multiplication of the result of applying A to |Psi> by \
the complex conjugate of the wavefunction (<Psi|).  In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the average outcome of measuring Iz for the basis wavefunction psiA  is \
carried out as:"
}], "Text",
 CellChangeTimes->{{3.4322357567694798`*^9, 3.432236058861125*^9}, {
  3.432236092029985*^9, 3.432236115875264*^9}, {3.447629799971526*^9, 
  3.4476298092656307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", "psiA", "]"}], ".", "Iz", ".", "psiA"}]], "Input",\

 CellChangeTimes->{{3.432236062569318*^9, 3.43223608160564*^9}, {
  3.432236118575664*^9, 3.432236120212595*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.43223612143372*^9, 3.4322498257060328`*^9, 
  3.432252126959025*^9, 3.432296795133513*^9, 3.4330914582523613`*^9, 
  3.433176772134555*^9, 3.4332457315430613`*^9, 3.433458045184716*^9, 
  3.445965686938447*^9, 3.447629825742173*^9, 3.447682838930112*^9, 
  3.447693367957858*^9, 3.447694132507547*^9, 3.4479496777057056`*^9, 
  3.4479499732168703`*^9}]
}, Open  ]],

Cell["\<\
The one-spin library has a function that carries out this manipulation and \
simplifies the result:\
\>", "Text",
 CellChangeTimes->{{3.4322361346518803`*^9, 3.4322361911608677`*^9}, 
   3.447694316841873*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"meanPsi", "[", 
  RowBox[{"Iz", ",", "psiA"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322361949241056`*^9, 3.432236205026011*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.432236205935768*^9, 3.432249825808591*^9, 
  3.4322521270261297`*^9, 3.432296795204712*^9, 3.433091458364285*^9, 
  3.433176772228833*^9, 3.433245731593162*^9, 3.4334580452395906`*^9, 
  3.445965687073901*^9, 3.447629853641074*^9, 3.447682839007031*^9, 
  3.447693368024149*^9, 3.447694132579947*^9, 3.4479496777728786`*^9, 
  3.4479499768113213`*^9}]
}, Open  ]],

Cell["\<\
The simplification is obviously not necessary in this case, but is convenient \
with more complicated examples, especially those involving a wavefunction \
that changes with time.  Be aware that the simplification rules used in this \
function assume that any undefined variables that define the wavefunction are \
real valued, except that it treats as complex the special variables, ca and \
cb, used to define the general form of the wavefunction.  So, an expression \
for calculating the average value of Iz for a general wavefunction can be \
determined using:\
\>", "Text",
 CellChangeTimes->{{3.432236228643269*^9, 3.432236440801817*^9}, {
   3.445625140460334*^9, 3.445625157612439*^9}, 3.447694318612266*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"meanPsi", "[", 
  RowBox[{"Iz", ",", "psiGen"}], "]"}]], "Input",
 CellChangeTimes->{{3.432236443530034*^9, 3.432236458539633*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "ca", " ", 
   RowBox[{"Conjugate", "[", "ca", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "cb", " ", 
   RowBox[{"Conjugate", "[", "cb", "]"}]}]}]], "Output",
 CellChangeTimes->{3.432236459475924*^9, 3.432249826111968*^9, 
  3.432252127093582*^9, 3.432296795282432*^9, 3.433091458668209*^9, 
  3.433176772511386*^9, 3.4332457319394407`*^9, 3.433458045479381*^9, 
  3.4459656873037*^9, 3.447629861942729*^9, 3.447682839163265*^9, 
  3.447693368108368*^9, 3.447694132648333*^9, 3.447949677840686*^9, 
  3.4479499809887743`*^9}]
}, Open  ]],

Cell["\<\
For convenience, the library also includes a function that calculates the \
average values for all three of the magnetization components:\
\>", "Text",
 CellChangeTimes->{{3.432236478518673*^9, 3.432236534878944*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiA", "]"}]], "Input",
 CellChangeTimes->{{3.432236539197665*^9, 3.432236561023679*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.4322365525231333`*^9, 3.4322365622253923`*^9}, 
   3.432249826286887*^9, 3.432252127159575*^9, 3.432296795339498*^9, 
   3.433091458741703*^9, 3.4331767725762053`*^9, 3.433245732012951*^9, 
   3.433458045588622*^9, 3.445965687494738*^9, 3.4476298701063833`*^9, 
   3.447682839252472*^9, 3.4476933681948833`*^9, 3.447694132715345*^9, 
   3.447949677908495*^9, 3.4479499842265043`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.4322365525231333`*^9, 3.4322365622253923`*^9}, 
   3.432249826286887*^9, 3.432252127159575*^9, 3.432296795339498*^9, 
   3.433091458741703*^9, 3.4331767725762053`*^9, 3.433245732012951*^9, 
   3.433458045588622*^9, 3.445965687494738*^9, 3.4476298701063833`*^9, 
   3.447682839252472*^9, 3.4476933681948833`*^9, 3.447694132715345*^9, 
   3.447949677908495*^9, 3.4479499842414103`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.4322365525231333`*^9, 3.4322365622253923`*^9}, 
   3.432249826286887*^9, 3.432252127159575*^9, 3.432296795339498*^9, 
   3.433091458741703*^9, 3.4331767725762053`*^9, 3.433245732012951*^9, 
   3.433458045588622*^9, 3.445965687494738*^9, 3.4476298701063833`*^9, 
   3.447682839252472*^9, 3.4476933681948833`*^9, 3.447694132715345*^9, 
   3.447949677908495*^9, 3.447949984257004*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiB", "]"}]], "Input",
 CellChangeTimes->{{3.432236573322649*^9, 3.4322365741914062`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.43223657508715*^9, 3.432249826447328*^9, 
  3.432252127227231*^9, 3.4322967954226522`*^9, 3.433091458925557*^9, 
  3.433176772709876*^9, 3.4332457320797243`*^9, 3.433458045641439*^9, 
  3.4459656877237062`*^9, 3.447629875343368*^9, 3.4476828393525333`*^9, 
  3.4476933683107*^9, 3.447694132815435*^9, 3.447949678008769*^9, 
  3.44794998677853*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.43223657508715*^9, 3.432249826447328*^9, 
  3.432252127227231*^9, 3.4322967954226522`*^9, 3.433091458925557*^9, 
  3.433176772709876*^9, 3.4332457320797243`*^9, 3.433458045641439*^9, 
  3.4459656877237062`*^9, 3.447629875343368*^9, 3.4476828393525333`*^9, 
  3.4476933683107*^9, 3.447694132815435*^9, 3.447949678008769*^9, 
  3.447949986822654*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.43223657508715*^9, 3.432249826447328*^9, 
  3.432252127227231*^9, 3.4322967954226522`*^9, 3.433091458925557*^9, 
  3.433176772709876*^9, 3.4332457320797243`*^9, 3.433458045641439*^9, 
  3.4459656877237062`*^9, 3.447629875343368*^9, 3.4476828393525333`*^9, 
  3.4476933683107*^9, 3.447694132815435*^9, 3.447949678008769*^9, 
  3.447949986882509*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiGen", "]"}]], "Input",
 CellChangeTimes->{{3.432236584058329*^9, 3.4322365847751102`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "cb", " ", 
     RowBox[{"Conjugate", "[", "ca", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "ca", " ", 
     RowBox[{"Conjugate", "[", "cb", "]"}]}]}]}],
  SequenceForm[
  "<Ix> = ", (Rational[1, 2] NMR`oneSpinLib`cb) 
    Conjugate[NMR`oneSpinLib`ca] + (Rational[1, 2] NMR`oneSpinLib`ca) 
    Conjugate[NMR`oneSpinLib`cb]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432236585643971*^9, 3.432249826631242*^9, 
  3.4322521272944613`*^9, 3.4322967955058603`*^9, 3.433091459184599*^9, 
  3.4331767728966513`*^9, 3.4332457321311817`*^9, 3.433458045692109*^9, 
  3.445965687943083*^9, 3.447629881240139*^9, 3.4476828395557957`*^9, 
  3.447693368427424*^9, 3.447694132916128*^9, 3.4479496781089897`*^9, 
  3.4479499913608294`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "cb", " ", 
     RowBox[{"Conjugate", "[", "ca", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "ca", " ", 
     RowBox[{"Conjugate", "[", "cb", "]"}]}]}]}],
  SequenceForm["<Iy> = ", (Complex[0, 
       Rational[-1, 2]] NMR`oneSpinLib`cb) 
    Conjugate[NMR`oneSpinLib`ca] + (Complex[0, 
       Rational[1, 2]] NMR`oneSpinLib`ca) Conjugate[NMR`oneSpinLib`cb]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432236585643971*^9, 3.432249826631242*^9, 
  3.4322521272944613`*^9, 3.4322967955058603`*^9, 3.433091459184599*^9, 
  3.4331767728966513`*^9, 3.4332457321311817`*^9, 3.433458045692109*^9, 
  3.445965687943083*^9, 3.447629881240139*^9, 3.4476828395557957`*^9, 
  3.447693368427424*^9, 3.447694132916128*^9, 3.4479496781089897`*^9, 
  3.4479499913760347`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "ca", " ", 
     RowBox[{"Conjugate", "[", "ca", "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "cb", " ", 
     RowBox[{"Conjugate", "[", "cb", "]"}]}]}]}],
  SequenceForm[
  "<Iz> = ", (Rational[1, 2] NMR`oneSpinLib`ca) 
    Conjugate[NMR`oneSpinLib`ca] + (Rational[-1, 2] NMR`oneSpinLib`cb) 
    Conjugate[NMR`oneSpinLib`cb]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432236585643971*^9, 3.432249826631242*^9, 
  3.4322521272944613`*^9, 3.4322967955058603`*^9, 3.433091459184599*^9, 
  3.4331767728966513`*^9, 3.4332457321311817`*^9, 3.433458045692109*^9, 
  3.445965687943083*^9, 3.447629881240139*^9, 3.4476828395557957`*^9, 
  3.447693368427424*^9, 3.447694132916128*^9, 3.4479496781089897`*^9, 
  3.447949991391663*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
We can use these functions to confirm the properties of the eigenfunctions \
for Ix and Iy\
\>", "Text",
 CellChangeTimes->{{3.4322366250487013`*^9, 3.432236664691136*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "Ix", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.432236675663128*^9, 3.432249826814719*^9, 
  3.432252127360778*^9, 3.4322967955832653`*^9, 3.433091459344136*^9, 
  3.433176773027667*^9, 3.4332457321817827`*^9, 3.433458045743402*^9, 
  3.445965688156657*^9, 3.447682839650373*^9, 3.447693368525915*^9, 
  3.447694133015383*^9, 3.447949678207522*^9, 3.4479499958813467`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.432236678105969*^9, 3.432236691183568*^9}, {
  3.4322382074664097`*^9, 3.432238215728032*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Ix> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432236693017508*^9, 3.432238217318212*^9, 
  3.4322498268990793`*^9, 3.4322521274283323`*^9, 3.432296795849309*^9, 
  3.433091459428028*^9, 3.4331767731809587`*^9, 3.4332457322965117`*^9, 
  3.4334580458087387`*^9, 3.445965688240543*^9, 3.4476828397184963`*^9, 
  3.447693368700571*^9, 3.4476941331968193`*^9, 3.447949678275676*^9, 
  3.447949998205749*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432236693017508*^9, 3.432238217318212*^9, 
  3.4322498268990793`*^9, 3.4322521274283323`*^9, 3.432296795849309*^9, 
  3.433091459428028*^9, 3.4331767731809587`*^9, 3.4332457322965117`*^9, 
  3.4334580458087387`*^9, 3.445965688240543*^9, 3.4476828397184963`*^9, 
  3.447693368700571*^9, 3.4476941331968193`*^9, 3.447949678275676*^9, 
  3.4479499982211437`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432236693017508*^9, 3.432238217318212*^9, 
  3.4322498268990793`*^9, 3.4322521274283323`*^9, 3.432296795849309*^9, 
  3.433091459428028*^9, 3.4331767731809587`*^9, 3.4332457322965117`*^9, 
  3.4334580458087387`*^9, 3.445965688240543*^9, 3.4476828397184963`*^9, 
  3.447693368700571*^9, 3.4476941331968193`*^9, 3.447949678275676*^9, 
  3.447949998236661*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.4322382338627*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Ix> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.43223823565641*^9, 3.432249827083415*^9, 
  3.4322521274950657`*^9, 3.4322967959178247`*^9, 3.433091459596323*^9, 
  3.433176773312172*^9, 3.433245732412681*^9, 3.4334580458602133`*^9, 
  3.4459656885328693`*^9, 3.447682839817905*^9, 3.44769336881059*^9, 
  3.4476941333006163`*^9, 3.4479496783757133`*^9, 3.4479500042338457`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.43223823565641*^9, 3.432249827083415*^9, 
  3.4322521274950657`*^9, 3.4322967959178247`*^9, 3.433091459596323*^9, 
  3.433176773312172*^9, 3.433245732412681*^9, 3.4334580458602133`*^9, 
  3.4459656885328693`*^9, 3.447682839817905*^9, 3.44769336881059*^9, 
  3.4476941333006163`*^9, 3.4479496783757133`*^9, 3.447950004280789*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.43223823565641*^9, 3.432249827083415*^9, 
  3.4322521274950657`*^9, 3.4322967959178247`*^9, 3.433091459596323*^9, 
  3.433176773312172*^9, 3.433245732412681*^9, 3.4334580458602133`*^9, 
  3.4459656885328693`*^9, 3.447682839817905*^9, 3.44769336881059*^9, 
  3.4476941333006163`*^9, 3.4479496783757133`*^9, 3.447950004335717*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "Iy", "]"}]], "Input",
 CellChangeTimes->{{3.4322382409904957`*^9, 3.4322382553628883`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[ImaginaryI]", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4322382561174192`*^9, 3.432249827362433*^9, 
  3.432252127561887*^9, 3.432296796000886*^9, 3.43309145976372*^9, 
  3.43317677344582*^9, 3.4332457325297318`*^9, 3.433458045910706*^9, 
  3.445965688757052*^9, 3.4476828399152822`*^9, 3.4476933689271173`*^9, 
  3.447694133399456*^9, 3.447949678607058*^9, 3.4479500065690193`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{"\[ImaginaryI]", ",", "1"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.432238272181527*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.44795000946098*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Iy> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.447950009501782*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.447950009562954*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], ",", "1"}], "}"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{3.432238292741063*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432238294179513*^9, 3.432249827636071*^9, 
  3.43225212769584*^9, 3.432296796134707*^9, 3.4330914600140753`*^9, 
  3.433176773750568*^9, 3.433245732632268*^9, 3.433458046025732*^9, 
  3.4459656890588903`*^9, 3.447682840087077*^9, 3.44769336912634*^9, 
  3.447694133665464*^9, 3.4479496787759333`*^9, 3.447950014923691*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432238294179513*^9, 3.432249827636071*^9, 
  3.43225212769584*^9, 3.432296796134707*^9, 3.4330914600140753`*^9, 
  3.433176773750568*^9, 3.433245732632268*^9, 3.433458046025732*^9, 
  3.4459656890588903`*^9, 3.447682840087077*^9, 3.44769336912634*^9, 
  3.447694133665464*^9, 3.4479496787759333`*^9, 3.44795001493856*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432238294179513*^9, 3.432249827636071*^9, 
  3.43225212769584*^9, 3.432296796134707*^9, 3.4330914600140753`*^9, 
  3.433176773750568*^9, 3.433245732632268*^9, 3.433458046025732*^9, 
  3.4459656890588903`*^9, 3.447682840087077*^9, 3.44769336912634*^9, 
  3.447694133665464*^9, 3.4479496787759333`*^9, 3.447950014953937*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium population difference for a single spin", "Section",
 CellChangeTimes->{{3.432239169554309*^9, 3.432239172746088*^9}, {
  3.432239963914885*^9, 3.432239964994853*^9}, {3.432252495648507*^9, 
  3.432252506909853*^9}, {3.445626172143382*^9, 3.4456261765668364`*^9}, {
  3.445628212921586*^9, 3.4456282165335817`*^9}}],

Cell["\<\
The relative concentrations of two states at thermal equilibrium are given by \
the Boltzmann equation:\
\>", "Text",
 CellChangeTimes->{
  3.445626202749263*^9, {3.44562700257379*^9, 3.445627091637035*^9}, 
   3.445627167094719*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Na", "/", "Nb"}], " ", "\[Equal]", " ", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Eb", "-", "Ea"}], ")"}], "/", 
    RowBox[{"(", "kT", ")"}]}], "]"}], "==", 
  RowBox[{"Exp", "[", 
   RowBox[{"deltaE", "/", 
    RowBox[{"(", "kT", ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4456271013966293`*^9, 3.4456271486851254`*^9}, {
  3.445627267130939*^9, 3.445627289997879*^9}, {3.445627405360395*^9, 
  3.4456274100309362`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["Na", "Nb"], "\[Equal]", 
  SuperscriptBox["\[ExponentialE]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "Ea"}], "+", "Eb"}], "kT"]], "\[Equal]", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"deltaE", "/", "kT"}]]}]], "Output",
 CellChangeTimes->{
  3.445627151306458*^9, {3.445627283177948*^9, 3.445627291508513*^9}, 
   3.445627411229059*^9, 3.4459656892750893`*^9, 3.4476828402000227`*^9, 
   3.4476933692267523`*^9, 3.4476941338319683`*^9, 3.447949678875215*^9, 
   3.4479500197651*^9}]
}, Open  ]],

Cell["\<\
For conventional NMR experiments, deltaE << kT, and the Boltzmann \
distribution can be approximated as:\
\>", "Text",
 CellChangeTimes->{{3.445627359422679*^9, 3.4456274614453897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Na", "/", "Nb"}], " ", "==", " ", 
  RowBox[{"1", " ", "+", " ", 
   RowBox[{"deltaE", "/", 
    RowBox[{"(", "kT", ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.445627464484013*^9, 3.445627485083634*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["Na", "Nb"], "\[Equal]", 
  RowBox[{"1", "+", 
   FractionBox["deltaE", "kT"]}]}]], "Output",
 CellChangeTimes->{{3.445627475205488*^9, 3.445627486167142*^9}, 
   3.445965689357877*^9, 3.447682840300263*^9, 3.4476933692964478`*^9, 
   3.447694133949216*^9, 3.447949678941658*^9, 3.447950022787036*^9}]
}, Open  ]],

Cell["Na can be written in terms of Nb:", "Text",
 CellChangeTimes->{{3.445627809065*^9, 3.445627834439959*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Na", " ", "==", " ", 
  RowBox[{"Nb", 
   RowBox[{"(", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"deltaE", "/", 
      RowBox[{"(", "kT", ")"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.445627837711195*^9, 3.4456278951042624`*^9}, 
   3.445627945224011*^9}],

Cell[BoxData[
 RowBox[{"Na", "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["deltaE", "kT"]}], ")"}], " ", "Nb"}]}]], "Output",
 CellChangeTimes->{3.445627956904986*^9, 3.445965689441622*^9, 
  3.447682840367708*^9, 3.447693369376947*^9, 3.4476941340172157`*^9, 
  3.44794967900902*^9, 3.447950026011015*^9}]
}, Open  ]],

Cell["The fractional population difference, deltaP is defined as:", "Text",
 CellChangeTimes->{{3.445627196629856*^9, 3.445627217529196*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deltaP", " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Na", "-", "Nb"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"Na", "+", "Nb"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.445627219912339*^9, 3.445627231234193*^9}, {
  3.445627306523273*^9, 3.4456273290400867`*^9}}],

Cell[BoxData[
 RowBox[{"deltaP", "\[Equal]", 
  FractionBox[
   RowBox[{"Na", "-", "Nb"}], 
   RowBox[{"Na", "+", "Nb"}]]}]], "Output",
 CellChangeTimes->{3.44562722198004*^9, 3.445627330007084*^9, 
  3.4459656896136637`*^9, 3.4476828404326982`*^9, 3.447693369443111*^9, 
  3.4476941340837307`*^9, 3.44794967907519*^9, 3.447950029251031*^9}]
}, Open  ]],

Cell["The numerator can be written as:", "Text",
 CellChangeTimes->{{3.4456275089522676`*^9, 3.445627516952647*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Na", "-", "Nb"}], ")"}], "  ", "==", " ", 
  RowBox[{"Nb", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"deltaE", "/", 
        RowBox[{"(", "kT", ")"}]}]}], ")"}], "-", "1"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.445627784245777*^9, 3.4456277938663883`*^9}, 
   3.445627907501388*^9, {3.4456279651677303`*^9, 3.445628009797068*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Na", "-", "Nb"}], "\[Equal]", 
  FractionBox[
   RowBox[{"deltaE", " ", "Nb"}], "kT"]}]], "Output",
 CellChangeTimes->{3.4456280138419943`*^9, 3.4459656896997833`*^9, 
  3.4476828407162647`*^9, 3.4476933695103207`*^9, 3.4476941342731457`*^9, 
  3.4479496791436033`*^9, 3.4479500327578983`*^9}]
}, Open  ]],

Cell["The denominator is:", "Text",
 CellChangeTimes->{{3.4456280380123568`*^9, 3.445628046241908*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Nb", "+", "Na"}], " ", "\[Equal]", " ", 
  RowBox[{"Nb", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"deltaE", "/", 
        RowBox[{"(", "kT", ")"}]}]}], ")"}], "+", "1"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.445628050462619*^9, 3.44562808074212*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Na", "+", "Nb"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "+", 
     FractionBox["deltaE", "kT"]}], ")"}], " ", "Nb"}]}]], "Output",
 CellChangeTimes->{3.445628081601714*^9, 3.445965689792074*^9, 
  3.447682840848278*^9, 3.44769336957731*^9, 3.4476941343512783`*^9, 
  3.447949679209919*^9, 3.447950038186944*^9}]
}, Open  ]],

Cell["Since  deltaE/(kT) << 1,", "Text",
 CellChangeTimes->{{3.4456280844960413`*^9, 3.445628152998829*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Na", "+", "Nb"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", "2", ")"}], " ", "Nb"}]}]], "Input",
 CellChangeTimes->{3.4456281718748007`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Na", "+", "Nb"}], "\[Equal]", 
  RowBox[{"2", " ", "Nb"}]}]], "Output",
 CellChangeTimes->{3.4456281732465267`*^9, 3.4459656898836403`*^9, 
  3.447682840966309*^9, 3.4476933697598267`*^9, 3.447694134419841*^9, 
  3.447949679276754*^9, 3.4479500415768347`*^9}]
}, Open  ]],

Cell["And", "Text",
 CellChangeTimes->{{3.445628180095702*^9, 3.445628180565957*^9}, 
   3.447694328896947*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deltaP", " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Na", "-", "Nb"}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"Na", "+", "Nb"}], ")"}]}], " ", "\[Equal]", 
  RowBox[{
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{"deltaE", " ", "Nb"}], "kT"], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", "Nb"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.445628222916848*^9, 3.445628273822201*^9}}],

Cell[BoxData[
 RowBox[{"deltaP", "\[Equal]", 
  FractionBox[
   RowBox[{"Na", "-", "Nb"}], 
   RowBox[{"Na", "+", "Nb"}]], "\[Equal]", 
  FractionBox["deltaE", 
   RowBox[{"2", " ", "kT"}]]}]], "Output",
 CellChangeTimes->{3.445628276327066*^9, 3.4459656899754868`*^9, 
  3.447682841166782*^9, 3.44769336984451*^9, 3.447694134485552*^9, 
  3.4479496793427343`*^9, 3.447950047706568*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pulses and time evolution for a single spin", "Section",
 CellChangeTimes->{{3.432239169554309*^9, 3.432239172746088*^9}, {
  3.432239963914885*^9, 3.432239964994853*^9}, {3.432252495648507*^9, 
  3.432252506909853*^9}}],

Cell[CellGroupData[{

Cell["Pulses", "Subsection",
 CellChangeTimes->{{3.432252514274576*^9, 3.432252515301969*^9}, {
  3.432252584528118*^9, 3.432252601571681*^9}}],

Cell["\<\
Rotations along the x' and y' axis are represented as matrices.  The new \
wavefunction is generated by multiplying the old wavefunction by the rotation \
matrix.  For a pulse of angle along the x'-axis the matrix is:\
\>", "Text",
 CellChangeTimes->{{3.432239188310534*^9, 3.432239274967128*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rx", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.432239279125992*^9, 3.432239282608225*^9}, {
  3.432249781962306*^9, 3.432249783131598*^9}, {3.432250838932199*^9, 
  3.432250840135302*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432239283593697*^9, 3.432249827820043*^9, 
  3.4322508415329523`*^9, 3.432252127876869*^9, 3.43229679620757*^9, 
  3.4330914602681026`*^9, 3.433176773917673*^9, 3.433245732747114*^9, 
  3.433458046077083*^9, 3.4459656900508747`*^9, 3.4476301406160316`*^9, 
  3.447682841354642*^9, 3.44769336991184*^9, 3.4476941345529327`*^9, 
  3.4479496794105177`*^9, 3.447950062834777*^9}]
}, Open  ]],

Cell["For a pulse along the y'-axis, the matrix is:", "Text",
 CellChangeTimes->{{3.432239320371523*^9, 3.432239352316985*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ry", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.4322497866487226`*^9, 3.432249788116088*^9}, {
  3.432250844036701*^9, 3.432250846239182*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}]},
     {
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432239355760675*^9, 3.432249827902594*^9, 
  3.432250847142367*^9, 3.4322521279306498`*^9, 3.432296796275138*^9, 
  3.4330914603221283`*^9, 3.433176773961896*^9, 3.433245732798835*^9, 
  3.4334580461268473`*^9, 3.445965690124127*^9, 3.447630143647151*^9, 
  3.447682841421609*^9, 3.447693369978919*^9, 3.447694134619877*^9, 
  3.447949679610386*^9, 3.447950066680457*^9}]
}, Open  ]],

Cell["For example, a pi/2 pulse along the x'-axis applied to psiA:", "Text",
 CellChangeTimes->{{3.43223938360359*^9, 3.43223940578719*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Rx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}], ".", "psiA"}]], "Input",
 CellChangeTimes->{{3.432239411054192*^9, 3.432239420164349*^9}, {
  3.4322497917238207`*^9, 3.432249796163747*^9}, {3.432250850194269*^9, 
  3.432250852511554*^9}, {3.445628727088855*^9, 3.44562874345953*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.432239421282699*^9, 3.432249827987543*^9, 3.4322508536708593`*^9, 
   3.432252127981208*^9, 3.432296796335058*^9, 3.4330914603882713`*^9, 
   3.433176773993744*^9, 3.433245732914716*^9, 3.4334580461765957`*^9, {
   3.445628728685112*^9, 3.44562874785375*^9}, 3.445965690190055*^9, 
   3.447630148918518*^9, 3.447682841486889*^9, 3.4476933700455437`*^9, 
   3.44769413468473*^9, 3.447949679677043*^9, 3.4479500707756844`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", 
     SqrtBox["2"]], ",", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["2"]]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.43223942913363*^9, 3.432239444514649*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239446818618*^9, 3.432249828069642*^9, 
  3.4322521280472593`*^9, 3.432296796401655*^9, 3.4330914604554377`*^9, 
  3.433176774046217*^9, 3.433245733114917*^9, 3.433458046225853*^9, 
  3.4459656902575293`*^9, 3.447630153131084*^9, 3.447682841754202*^9, 
  3.4476933701119347`*^9, 3.447694134753078*^9, 3.447949679744368*^9, 
  3.447950073010665*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239446818618*^9, 3.432249828069642*^9, 
  3.4322521280472593`*^9, 3.432296796401655*^9, 3.4330914604554377`*^9, 
  3.433176774046217*^9, 3.433245733114917*^9, 3.433458046225853*^9, 
  3.4459656902575293`*^9, 3.447630153131084*^9, 3.447682841754202*^9, 
  3.4476933701119347`*^9, 3.447694134753078*^9, 3.447949679744368*^9, 
  3.4479500730262547`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239446818618*^9, 3.432249828069642*^9, 
  3.4322521280472593`*^9, 3.432296796401655*^9, 3.4330914604554377`*^9, 
  3.433176774046217*^9, 3.433245733114917*^9, 3.433458046225853*^9, 
  3.4459656902575293`*^9, 3.447630153131084*^9, 3.447682841754202*^9, 
  3.4476933701119347`*^9, 3.447694134753078*^9, 3.447949679744368*^9, 
  3.447950073041441*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
confirming that the magnetization is rotated from the z-axis to the y'-axis.  \
A pulse along the y'-axis:\
\>", "Text",
 CellChangeTimes->{{3.4322395103200808`*^9, 3.432239545031131*^9}, 
   3.432239580575328*^9, 3.447694338969729*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Ry", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}], ".", "psiA"}]], "Input",
 CellChangeTimes->{{3.4322395544279547`*^9, 3.432239554736442*^9}, {
  3.4322498031637373`*^9, 3.4322498041476927`*^9}, {3.432250857042239*^9, 
  3.432250857967339*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.432239556681122*^9, 3.432249828254962*^9, 
  3.4322508589302588`*^9, 3.432252128114707*^9, 3.43229679648669*^9, 
  3.433091460522674*^9, 3.433176774096072*^9, 3.433245733266034*^9, 
  3.433458046277381*^9, 3.4459656903576317`*^9, 3.4476301630996723`*^9, 
  3.447682841919208*^9, 3.447693370211741*^9, 3.447694134852119*^9, 
  3.447949679844171*^9, 3.447950077185296*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", 
     SqrtBox["2"]], ",", 
    RowBox[{"-", 
     FractionBox["1", 
      SqrtBox["2"]]}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322395622851954`*^9, 3.432239574092073*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Ix> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239574905002*^9, 3.4322498284354687`*^9, 
  3.432252128181427*^9, 3.432296796552548*^9, 3.433091460589017*^9, 
  3.433176774385207*^9, 3.433245733400364*^9, 3.433458046326992*^9, 
  3.4459656904248447`*^9, 3.447682842054612*^9, 3.4476933702798347`*^9, 
  3.447694134919293*^9, 3.4479496799116087`*^9, 3.447950079608729*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239574905002*^9, 3.4322498284354687`*^9, 
  3.432252128181427*^9, 3.432296796552548*^9, 3.433091460589017*^9, 
  3.433176774385207*^9, 3.433245733400364*^9, 3.433458046326992*^9, 
  3.4459656904248447`*^9, 3.447682842054612*^9, 3.4476933702798347`*^9, 
  3.447694134919293*^9, 3.4479496799116087`*^9, 3.447950079652294*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239574905002*^9, 3.4322498284354687`*^9, 
  3.432252128181427*^9, 3.432296796552548*^9, 3.433091460589017*^9, 
  3.433176774385207*^9, 3.433245733400364*^9, 3.433458046326992*^9, 
  3.4459656904248447`*^9, 3.447682842054612*^9, 3.4476933702798347`*^9, 
  3.447694134919293*^9, 3.4479496799116087`*^9, 3.447950079708643*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
This shows that the rotations follow the left-hand convention. 

The library also includes some functions for specific pulses:
Pulses along the x-axis:
psiPulseX
psiPi2x (a pi/2 pulse)
psiPix
Pulses along the y'-axis
psiPulseY
psiPulsePi2y (a pi/2 pulse)
psiPiy
Some more examples:\
\>", "Text",
 CellChangeTimes->{{3.43223958731534*^9, 3.432239777793582*^9}, {
   3.432249811020731*^9, 3.4322498130678596`*^9}, 3.447694341770925*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPulseX", "[", 
  RowBox[{"psiA", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.432239780559218*^9, 3.432239793264287*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.432239794431892*^9, 3.432249828585505*^9, 
  3.432252128247965*^9, 3.4322967966238537`*^9, 3.433091460655847*^9, 
  3.433176774431287*^9, 3.4332457335015583`*^9, 3.433458046377865*^9, 
  3.445965690524377*^9, 3.447682842219194*^9, 3.4476933703790417`*^9, 
  3.447694135018866*^9, 3.4479496800117683`*^9, 3.447950083949521*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPi2x", "[", "psiA", "]"}]], "Input",
 CellChangeTimes->{{3.4322397960382557`*^9, 3.432239811028729*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4322398077937326`*^9, 3.4322398123340693`*^9}, 
   3.43224982864609*^9, 3.432252128314473*^9, 3.4322967968695507`*^9, 
   3.4330914607233753`*^9, 3.433176774481391*^9, 3.433245733601079*^9, 
   3.433458046428113*^9, 3.445965690691989*^9, 3.4476828422886677`*^9, 
   3.447693370445981*^9, 3.4476941350856047`*^9, 3.447949680078123*^9, 
   3.447950086020705*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPi2x", "[", "psiB", "]"}]], "Input",
 CellChangeTimes->{{3.4322398199209337`*^9, 3.432239829344513*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.447950095074692*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPi2y", "[", "psiB", "]"}]], "Input",
 CellChangeTimes->{{3.4322398345188026`*^9, 3.4322398427553253`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.432239845138752*^9, 3.432249828763282*^9, 
  3.432252128415451*^9, 3.432296797069841*^9, 3.433091460857308*^9, 
  3.433176774581316*^9, 3.43324573380162*^9, 3.433458046528001*^9, 
  3.445965690825407*^9, 3.447682842422153*^9, 3.447693370579503*^9, 
  3.447694135391861*^9, 3.447949680211607*^9, 3.447950107114964*^9}]
}, Open  ]],

Cell["\<\
The operations for the pulses and for calculating the magnetization \
components don't have to be done separately:\
\>", "Text",
 CellChangeTimes->{{3.432239858768496*^9, 3.4322399016288757`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiPi2y", "[", "psiA", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.432239905739731*^9, 3.4322399226593323`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Ix> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239923635598*^9, 3.432249828830101*^9, 
  3.432252128466463*^9, 3.432296797124112*^9, 3.433091460925013*^9, 
  3.4331767746322727`*^9, 3.433245733888043*^9, 3.433458046653461*^9, 
  3.4459656908928137`*^9, 3.447682842490437*^9, 3.447693370711635*^9, 
  3.4476941354708757`*^9, 3.4479496802795057`*^9, 3.447950110355875*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239923635598*^9, 3.432249828830101*^9, 
  3.432252128466463*^9, 3.432296797124112*^9, 3.433091460925013*^9, 
  3.4331767746322727`*^9, 3.433245733888043*^9, 3.433458046653461*^9, 
  3.4459656908928137`*^9, 3.447682842490437*^9, 3.447693370711635*^9, 
  3.4476941354708757`*^9, 3.4479496802795057`*^9, 3.4479501103712587`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432239923635598*^9, 3.432249828830101*^9, 
  3.432252128466463*^9, 3.432296797124112*^9, 3.433091460925013*^9, 
  3.4331767746322727`*^9, 3.433245733888043*^9, 3.433458046653461*^9, 
  3.4459656908928137`*^9, 3.447682842490437*^9, 3.447693370711635*^9, 
  3.4476941354708757`*^9, 3.4479496802795057`*^9, 3.447950110386334*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiPi2y", "[", "psiB", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322399322327967`*^9, 3.4322399326776543`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Ix> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4322399336745996`*^9, 3.432249828897167*^9, 
  3.4322521285325203`*^9, 3.432296797191718*^9, 3.433091460992527*^9, 
  3.433176774682005*^9, 3.433245734005365*^9, 3.433458046713208*^9, 
  3.44596569099255*^9, 3.4476828427063932`*^9, 3.447693370925036*^9, 
  3.4476941355703297`*^9, 3.447949680380012*^9, 3.447950113061956*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4322399336745996`*^9, 3.432249828897167*^9, 
  3.4322521285325203`*^9, 3.432296797191718*^9, 3.433091460992527*^9, 
  3.433176774682005*^9, 3.433245734005365*^9, 3.433458046713208*^9, 
  3.44596569099255*^9, 3.4476828427063932`*^9, 3.447693370925036*^9, 
  3.4476941355703297`*^9, 3.447949680380012*^9, 3.4479501130761223`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4322399336745996`*^9, 3.432249828897167*^9, 
  3.4322521285325203`*^9, 3.432296797191718*^9, 3.433091460992527*^9, 
  3.433176774682005*^9, 3.433245734005365*^9, 3.433458046713208*^9, 
  3.44596569099255*^9, 3.4476828427063932`*^9, 3.447693370925036*^9, 
  3.4476941355703297`*^9, 3.447949680380012*^9, 3.447950113091016*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time evolution", "Subsubsection",
 CellChangeTimes->{{3.432240005376292*^9, 3.432240007666918*^9}}],

Cell["\<\
Like pulses, the effects of time evolution in stationary magnetic field are \
calculated by matrix multiplication.  In this case, it is the matrix form of \
the Hamiltonian operator.  For the purposes of calculations, it is convenient \
to express the energies of the |a> and |b> states in terms of the frequency \
of radiation required to stimulate a transition:
deltaE = h nu = gamma B/(2 Pi)
where h is Planck's constant, and gamma is the gyromagnetic ratio, and B is \
the strength of the external magnetic field.  The energies of the two states \
are:
Ea = -gamma B/(4 Pi) = -h nu/2
Eb = gamma B/(4 Pi) = h nu/2
If these equations are divided by Planck's constant, the energies are \
expressed in units of h.  This, then, allows all of the calculated results \
for the time-dependent changes in the wavefunction and magnetization \
components to be expressed in terms of the resonance frequency, nu.

Following this convention the Hamiltonian matrix is given by:\
\>", "Text",
 CellChangeTimes->{{3.432250899657565*^9, 3.432251005946033*^9}, {
   3.4456296773846407`*^9, 3.445629835055764*^9}, {3.445629977226243*^9, 
   3.445629989787674*^9}, {3.445630027960293*^9, 3.445630177534461*^9}, {
   3.445630388944755*^9, 3.445630509101584*^9}, {3.445630572561558*^9, 
   3.4456306176506367`*^9}, {3.4476303040085917`*^9, 3.447630304475754*^9}, 
   3.447694354078038*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H", "[", 
  RowBox[{"t", ",", "nu"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322510088615227`*^9, 3.4322510234285603`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], "0"},
     {"0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4322510252982187`*^9, 3.432252128600666*^9, 
  3.432296797259532*^9, 3.433091461058793*^9, 3.433176774732974*^9, 
  3.433245734057003*^9, 3.4334580467651653`*^9, 3.4459656910932198`*^9, 
  3.4476303321577177`*^9, 3.447682842872876*^9, 3.447693371030648*^9, 
  3.447694135670536*^9, 3.447949680479714*^9, 3.4479501185737667`*^9}]
}, Open  ]],

Cell["The general form of the time-dependent wavefunction is:", "Text",
 CellChangeTimes->{{3.432251049260871*^9, 3.432251115627335*^9}, 
   3.445630523195557*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"t", ",", "nu"}], "]"}], ".", "psiGen"}]], "Input",
 CellChangeTimes->{{3.432251120654501*^9, 3.432251130585143*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ca", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]]}], ",", 
   RowBox[{"cb", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", 
      "t"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.432251133727468*^9, 3.432252128666649*^9, 
  3.432296797325478*^9, 3.43309146112626*^9, 3.433176774782874*^9, 
  3.4332457341210737`*^9, 3.4334580468302097`*^9, 3.445965691159068*^9, 
  3.44763034273706*^9, 3.4476828430223494`*^9, 3.447693371097002*^9, 
  3.447694135737514*^9, 3.447949680679091*^9, 3.4479501268569803`*^9}]
}, Open  ]],

Cell["\<\
where  ca and cb are the complex coefficients in the starting wavefunction.  

Calculate what happens following a pi/2-x pulse to the psiA wavefunction:\
\>", "Text",
 CellChangeTimes->{{3.432251142613813*^9, 3.432251158594762*^9}, {
  3.432251285998231*^9, 3.4322513233139887`*^9}, {3.432251371801918*^9, 
  3.432251444624208*^9}, {3.4322522207485657`*^9, 3.432252221602089*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"t", ",", "nu"}], "]"}], ".", 
  RowBox[{"psiPi2x", "[", "psiA", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.4322514476675673`*^9, 3.432252128733301*^9, 
  3.432296797392353*^9, 3.43309146119368*^9, 3.433176774832837*^9, 
  3.43324573415493*^9, 3.433458046880067*^9, 3.445965691225828*^9, 
  3.447630363731743*^9, 3.447682843090838*^9, 3.447693371163466*^9, 
  3.4476941358043833`*^9, 3.447949680745859*^9, 3.4479501741804132`*^9}]
}, Open  ]],

Cell["\<\
The library also contains a function for calculating the time-dependent \
wavefunction: psiTime[psi,t]\
\>", "Text",
 CellChangeTimes->{{3.432251623801621*^9, 3.432251665182073*^9}, {
  3.4322518053514214`*^9, 3.432251806066196*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiTime", "[", 
  RowBox[{
   RowBox[{"psiPi2x", "[", "psiA", "]"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322516683793993`*^9, 3.4322516926975718`*^9}, {
  3.432251809514554*^9, 3.4322518097856503`*^9}, {3.432252063864829*^9, 
  3.432252071885642*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.432251678802978*^9, 3.4322516950744047`*^9}, 
   3.4322518118606358`*^9, 3.432252039081855*^9, 3.432252074224544*^9, 
   3.43225212891601*^9, 3.432252209213262*^9, 3.4322967974595833`*^9, 
   3.4330914613574743`*^9, 3.433176774882642*^9, 3.4332457341895447`*^9, 
   3.433458046930266*^9, 3.445965691292623*^9, 3.447630374646372*^9, 
   3.447682843156954*^9, 3.447693371230247*^9, 3.447694135870885*^9, 
   3.44794968081443*^9, 3.447950176228294*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], 
     SqrtBox["2"]], ",", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", 
        "t"}]]}], 
     SqrtBox["2"]]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.43225146666273*^9, 3.432251476945805*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Ix> = ", Rational[1, 2] Sin[((2 NMR`oneSpinLib`nu) Pi) NMR`oneSpinLib`t]],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.432251481993023*^9, 3.4322521289678297`*^9, 
  3.432252206424412*^9, 3.432296797524115*^9, 3.433091461409457*^9, 
  3.433176774933548*^9, 3.433245734236828*^9, 3.43345804698109*^9, 
  3.4459656913599253`*^9, 3.447630424664715*^9, 3.447682843241171*^9, 
  3.4476933712975407`*^9, 3.447694135938567*^9, 3.447949680886059*^9, 
  3.4479501798707314`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Iy> = ", Rational[1, 2] Cos[((2 NMR`oneSpinLib`nu) Pi) NMR`oneSpinLib`t]],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.432251481993023*^9, 3.4322521289678297`*^9, 
  3.432252206424412*^9, 3.432296797524115*^9, 3.433091461409457*^9, 
  3.433176774933548*^9, 3.433245734236828*^9, 3.43345804698109*^9, 
  3.4459656913599253`*^9, 3.447630424664715*^9, 3.447682843241171*^9, 
  3.4476933712975407`*^9, 3.447694135938567*^9, 3.447949680886059*^9, 
  3.4479501798859167`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432251481993023*^9, 3.4322521289678297`*^9, 
  3.432252206424412*^9, 3.432296797524115*^9, 3.433091461409457*^9, 
  3.433176774933548*^9, 3.433245734236828*^9, 3.43345804698109*^9, 
  3.4459656913599253`*^9, 3.447630424664715*^9, 3.447682843241171*^9, 
  3.4476933712975407`*^9, 3.447694135938567*^9, 3.447949680886059*^9, 
  3.447950179900735*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Calculate what happens to spins in psiB-state after the same pulse:\
\>", "Text",
 CellChangeTimes->{{3.432252237166359*^9, 3.432252259467852*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiTime", "[", 
  RowBox[{
   RowBox[{"psiPi2x", "[", "psiB", "]"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.4322522762473783`*^9, 3.4322522769094048`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.43225227793468*^9, 3.4322967976041727`*^9, 
  3.433091461476232*^9, 3.433176774983439*^9, 3.433245734337916*^9, 
  3.433458047033105*^9, 3.4459656914601717`*^9, 3.447630470729631*^9, 
  3.447682843405555*^9, 3.447693371397316*^9, 3.4476941360377607`*^9, 
  3.447949680980928*^9, 3.447950193096805*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4322522834415503`*^9, 3.432252293013186*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Ix> = ", Rational[-1, 2] Sin[((2 NMR`oneSpinLib`nu) Pi) NMR`oneSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.43225229377325*^9, 3.432296797672016*^9, 
  3.433091461543893*^9, 3.433176775034196*^9, 3.433245734441285*^9, 
  3.433458047098488*^9, 3.4459656915443296`*^9, 3.4476304748517313`*^9, 
  3.447682843524914*^9, 3.4476933714648523`*^9, 3.447694136106286*^9, 
  3.44794968104776*^9, 3.447950196341908*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Iy> = ", Rational[-1, 2] Cos[((2 NMR`oneSpinLib`nu) Pi) NMR`oneSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.43225229377325*^9, 3.432296797672016*^9, 
  3.433091461543893*^9, 3.433176775034196*^9, 3.433245734441285*^9, 
  3.433458047098488*^9, 3.4459656915443296`*^9, 3.4476304748517313`*^9, 
  3.447682843524914*^9, 3.4476933714648523`*^9, 3.447694136106286*^9, 
  3.44794968104776*^9, 3.447950196357929*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.43225229377325*^9, 3.432296797672016*^9, 
  3.433091461543893*^9, 3.433176775034196*^9, 3.433245734441285*^9, 
  3.433458047098488*^9, 3.4459656915443296`*^9, 3.4476304748517313`*^9, 
  3.447682843524914*^9, 3.4476933714648523`*^9, 3.447694136106286*^9, 
  3.44794968104776*^9, 3.447950196372805*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\

The magnetization components for the spins that begin in the two state always \
point in opposite directions, so that the net magnetization is that of the \
small excess that began in the psiA state.\
\>", "Text",
 CellChangeTimes->{{3.432252401002469*^9, 3.432252466525709*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wavefunctions and operators for a coupled spin pair", "Section",
 CellChangeTimes->{{3.4322962575189466`*^9, 3.432296267032956*^9}}],

Cell["\<\
Remove definitions from oneSpinLib and load twoSpinLib:
\
\>", "Text",
 CellChangeTimes->{{3.432296724483674*^9, 3.432296748819603*^9}}],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<NMR`oneSpinLib`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.432296701148443*^9, 3.4322967109175243`*^9}, {
  3.432296768889481*^9, 3.432296778471424*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "NMR`twoSpinLib`"}]], "Input",
 CellChangeTimes->{{3.4322967852707567`*^9, 3.432296786500201*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "::", "\<\"shdw\"\>"}], ":", 
  " ", "\<\"Symbol \\!\\(\\\"t\\\"\\) appears in multiple contexts \
\\!\\({\\\"NMR`twoSpinLib`\\\", \\\"Global`\\\"}\\); definitions in context \
\\!\\(\\\"NMR`twoSpinLib`\\\"\\) may shadow or be shadowed by other \
definitions. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/shdw\\\", ButtonNote -> \
\\\"NMR`twoSpinLib`t::shdw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.447949681630424*^9, 3.447950208061356*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nuI", "::", "\<\"shdw\"\>"}], ":", 
  " ", "\<\"Symbol \\!\\(\\\"nuI\\\"\\) appears in multiple contexts \
\\!\\({\\\"NMR`twoSpinLib`\\\", \\\"Global`\\\"}\\); definitions in context \
\\!\\(\\\"NMR`twoSpinLib`\\\"\\) may shadow or be shadowed by other \
definitions. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/shdw\\\", ButtonNote -> \
\\\"NMR`twoSpinLib`nuI::shdw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.447949681630424*^9, 3.447950208503232*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nuS", "::", "\<\"shdw\"\>"}], ":", 
  " ", "\<\"Symbol \\!\\(\\\"nuS\\\"\\) appears in multiple contexts \
\\!\\({\\\"NMR`twoSpinLib`\\\", \\\"Global`\\\"}\\); definitions in context \
\\!\\(\\\"NMR`twoSpinLib`\\\"\\) may shadow or be shadowed by other \
definitions. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/shdw\\\", ButtonNote -> \
\\\"NMR`twoSpinLib`nuS::shdw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.447949681630424*^9, 3.4479502089473143`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Names", "[", "\"\<NMR`twoSpinLib`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4322969009000053`*^9, 3.432296901881803*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"allCorPsi\"\>", ",", "\<\"allCorRho\"\>", 
   ",", "\<\"allMagPsi\"\>", ",", "\<\"allMagRho\"\>", ",", "\<\"caa\"\>", 
   ",", "\<\"cab\"\>", ",", "\<\"cba\"\>", ",", "\<\"cbb\"\>", 
   ",", "\<\"deltaPi\"\>", ",", "\<\"deltaPs\"\>", ",", "\<\"H\"\>", 
   ",", "\<\"Hc\"\>", ",", "\<\"HcInv\"\>", ",", "\<\"Hinv\"\>", 
   ",", "\<\"Hs\"\>", ",", "\<\"HsInv\"\>", ",", "\<\"i\"\>", 
   ",", "\<\"Ix\"\>", ",", "\<\"IxSx\"\>", ",", "\<\"IxSy\"\>", 
   ",", "\<\"IxSz\"\>", ",", "\<\"Iy\"\>", ",", "\<\"IySx\"\>", 
   ",", "\<\"IySy\"\>", ",", "\<\"IySz\"\>", ",", "\<\"Iz\"\>", 
   ",", "\<\"IzSx\"\>", ",", "\<\"IzSy\"\>", ",", "\<\"IzSz\"\>", 
   ",", "\<\"i$\"\>", ",", "\<\"J\"\>", ",", "\<\"meanPsi\"\>", 
   ",", "\<\"meanRho\"\>", ",", "\<\"nuI\"\>", ",", "\<\"nuS\"\>", 
   ",", "\<\"op\"\>", ",", "\<\"opBasisRep\"\>", ",", "\<\"opNames\"\>", 
   ",", "\<\"opNames$\"\>", ",", "\<\"opValues\"\>", ",", "\<\"opValues$\"\>",
    ",", "\<\"psi\"\>", ",", "\<\"psiAA\"\>", ",", "\<\"psiAB\"\>", 
   ",", "\<\"psiBA\"\>", ",", "\<\"psiBB\"\>", ",", "\<\"psiGen\"\>", 
   ",", "\<\"psiPi2Ix\"\>", ",", "\<\"psiPi2Iy\"\>", ",", "\<\"psiPi2Sx\"\>", 
   ",", "\<\"psiPi2Sy\"\>", ",", "\<\"psiPi2x\"\>", ",", "\<\"psiPi2y\"\>", 
   ",", "\<\"psiPiIx\"\>", ",", "\<\"psiPiIy\"\>", ",", "\<\"psiPiSx\"\>", 
   ",", "\<\"psiPiSy\"\>", ",", "\<\"psiPix\"\>", ",", "\<\"psiPiy\"\>", 
   ",", "\<\"psiPulseIx\"\>", ",", "\<\"psiPulseIy\"\>", 
   ",", "\<\"psiPulseSx\"\>", ",", "\<\"psiPulseSy\"\>", 
   ",", "\<\"psiPulseX\"\>", ",", "\<\"psiPulseY\"\>", ",", "\<\"psiTime\"\>",
    ",", "\<\"psiTimeC\"\>", ",", "\<\"psiTimeS\"\>", ",", "\<\"rho\"\>", 
   ",", "\<\"rhoEq\"\>", ",", "\<\"rhoGen\"\>", ",", "\<\"rhoPi2Ix\"\>", 
   ",", "\<\"rhoPi2Iy\"\>", ",", "\<\"rhoPi2Sx\"\>", ",", "\<\"rhoPi2Sy\"\>", 
   ",", "\<\"rhoPi2x\"\>", ",", "\<\"rhoPi2y\"\>", ",", "\<\"rhoPiIx\"\>", 
   ",", "\<\"rhoPiIy\"\>", ",", "\<\"rhoPiSx\"\>", ",", "\<\"rhoPiSy\"\>", 
   ",", "\<\"rhoPix\"\>", ",", "\<\"rhoPiy\"\>", ",", "\<\"rhoPulseIx\"\>", 
   ",", "\<\"rhoPulseIy\"\>", ",", "\<\"rhoPulseSx\"\>", 
   ",", "\<\"rhoPulseSy\"\>", ",", "\<\"rhoPulseX\"\>", 
   ",", "\<\"rhoPulseY\"\>", ",", "\<\"rhoTime\"\>", ",", "\<\"rhoTimeC\"\>", 
   ",", "\<\"rhoTimeS\"\>", ",", "\<\"RIx\"\>", ",", "\<\"RIxInv\"\>", 
   ",", "\<\"RIy\"\>", ",", "\<\"RIyInv\"\>", ",", "\<\"RSx\"\>", 
   ",", "\<\"RSxInv\"\>", ",", "\<\"RSy\"\>", ",", "\<\"RSyInv\"\>", 
   ",", "\<\"Sx\"\>", ",", "\<\"Sy\"\>", ",", "\<\"Sz\"\>", 
   ",", "\<\"t\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.4322969030306787`*^9, 3.43309146233843*^9, 
  3.433176775550435*^9, 3.433179967994697*^9, 3.433180015509601*^9, 
  3.433245735016007*^9, 3.4334580477493353`*^9, 3.445774568499928*^9, 
  3.4457746255698557`*^9, 3.445872333453888*^9, 3.4459656924471292`*^9, 
  3.447682843857554*^9, 3.447693373306884*^9, 3.4476941378939466`*^9, 
  3.4479496827846003`*^9, 3.4479502167374363`*^9}]
}, Open  ]],

Cell["\<\
The general form of the wavefunction for a scalar coupled spin pair can be \
written as:
caa psiAA + cab psiAB+ cba psiBA+ cbb psiBB
with the basis set defined in vector form as:\
\>", "Text",
 CellChangeTimes->{{3.432296273502143*^9, 3.432296510562047*^9}, 
   3.432296565438092*^9, {3.432296608633436*^9, 3.432296697020768*^9}, {
   3.432297059386497*^9, 3.432297155351623*^9}}],

Cell[CellGroupData[{

Cell[BoxData["psiAA"], "Input",
 CellChangeTimes->{{3.432297122303176*^9, 3.432297123833791*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432297125360354*^9, 3.433091462409698*^9, 
  3.433176775603175*^9, 3.433245735076145*^9, 3.433458047866434*^9, 
  3.445965692528103*^9, 3.447630519229848*^9, 3.447682843924439*^9, 
  3.447693373384108*^9, 3.4476941379758463`*^9, 3.447949682850321*^9, 
  3.4479502196850767`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["psiAB"], "Input",
 CellChangeTimes->{{3.432297133861019*^9, 3.432297140129375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432297141598771*^9, 3.433091462449037*^9, 
  3.43317677565243*^9, 3.4332457351259317`*^9, 3.433458047983364*^9, 
  3.445965692595859*^9, 3.4476305218078613`*^9, 3.447682844040043*^9, 
  3.4476933734511766`*^9, 3.4476941380415783`*^9, 3.4479496829170856`*^9, 
  3.447950221320122*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["psiBA"], "Input",
 CellChangeTimes->{{3.4322971425796347`*^9, 3.4322971438781347`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432297145185896*^9, 3.43309146251523*^9, 
  3.4331767757035437`*^9, 3.433245735154561*^9, 3.433458048035357*^9, 
  3.4459656927794333`*^9, 3.447630524587476*^9, 3.447682844107677*^9, 
  3.447693373518869*^9, 3.4476941381087112`*^9, 3.447949682984015*^9, 
  3.4479502241439247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["psiBB"], "Input",
 CellChangeTimes->{{3.432297146321267*^9, 3.4322971481190767`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.432297148959972*^9, 3.433091462582142*^9, 
  3.433176775752708*^9, 3.433245735193417*^9, 3.433458048085651*^9, 
  3.4459656928458233`*^9, 3.447630528117291*^9, 3.44768284417371*^9, 
  3.447693373585998*^9, 3.447694138175577*^9, 3.4479496830989857`*^9, 
  3.447950226180443*^9}]
}, Open  ]],

Cell["\<\
The general form of a wavefunction can be written in vector form as:\
\>", "Text",
 CellChangeTimes->{{3.432297165877857*^9, 3.432297195318348*^9}}],

Cell[CellGroupData[{

Cell[BoxData["psiGen"], "Input",
 CellChangeTimes->{{3.4322969164329863`*^9, 3.4322969181354856`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"caa", ",", "cab", ",", "cba", ",", "cbb"}], "}"}]], "Output",
 CellChangeTimes->{3.432296919426199*^9, 3.433091462631764*^9, 
  3.4331767758039923`*^9, 3.433245735258209*^9, 3.433458048135051*^9, 
  3.4459656929134398`*^9, 3.447630533644794*^9, 3.447682844291492*^9, 
  3.447693373652419*^9, 3.4476941382425213`*^9, 3.447949683168004*^9, 
  3.447950228485799*^9}]
}, Open  ]],

Cell["There are now six magnetization operators:", "Text",
 CellChangeTimes->{{3.4322969949014893`*^9, 3.432297008163671*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Ix"], "Input",
 CellChangeTimes->{{3.432297263417817*^9, 3.432297263812056*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox["1", "2"], "0"},
     {"0", "0", "0", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432297265923527*^9, 3.433091462699139*^9, 
  3.43317677585506*^9, 3.43324573531008*^9, 3.433458048186545*^9, 
  3.445965692998588*^9, 3.447630537177445*^9, 3.4476828443599157`*^9, 
  3.447693373784864*^9, 3.447694138309782*^9, 3.447949683286224*^9, 
  3.447950230523326*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Iy"], "Input",
 CellChangeTimes->{{3.432297267625431*^9, 3.432297267877692*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}]},
     {
      FractionBox["\[ImaginaryI]", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["\[ImaginaryI]", "2"], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432297268912755*^9, 3.433091462766633*^9, 
  3.4331767759433737`*^9, 3.433245735361092*^9, 3.433458048236273*^9, 
  3.445965693082816*^9, 3.4476305400549173`*^9, 3.4476828444271383`*^9, 
  3.447693373852968*^9, 3.4476941383769484`*^9, 3.447949683403224*^9, 
  3.44795023431518*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Iz"], "Input",
 CellChangeTimes->{{3.432297270264392*^9, 3.432297271891017*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4322972728712*^9, 3.433091462899005*^9, 
  3.433176776043582*^9, 3.433245735410952*^9, 3.4334580482865553`*^9, 
  3.4459656931664467`*^9, 3.447630543102203*^9, 3.447682844494548*^9, 
  3.4476933739194717`*^9, 3.4476941384430857`*^9, 3.447949683471744*^9, 
  3.447950236705172*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Sx"], "Input",
 CellChangeTimes->{{3.432297275292001*^9, 3.432297275613872*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox["1", "2"]},
     {"0", "0", 
      FractionBox["1", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432297276578101*^9, 3.4330914630329323`*^9, 
  3.43317677608887*^9, 3.43324573543941*^9, 3.433458048335935*^9, 
  3.4459656932497683`*^9, 3.447630546100635*^9, 3.4476828445623827`*^9, 
  3.447693373986966*^9, 3.447694138509974*^9, 3.447949683605969*^9, 
  3.4479502379745617`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Sy"], "Input",
 CellChangeTimes->{{3.432297281772252*^9, 3.4322972844213457`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}], "0", "0"},
     {
      FractionBox["\[ImaginaryI]", "2"], "0", "0", "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}]},
     {"0", "0", 
      FractionBox["\[ImaginaryI]", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4322972905752363`*^9, 3.433091463100402*^9, 
  3.433176776138843*^9, 3.43324573547858*^9, 3.433458048387372*^9, 
  3.44596569333114*^9, 3.447630548978037*^9, 3.447682844710403*^9, 
  3.44769337405399*^9, 3.447694138576462*^9, 3.447949683804338*^9, 
  3.447950239675152*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Sz"], "Input",
 CellChangeTimes->{{3.432297292825759*^9, 3.432297293106021*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0"},
     {"0", "0", 
      FractionBox["1", "2"], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4322972940325403`*^9, 3.433091463151174*^9, 
  3.433176776188006*^9, 3.433245735527562*^9, 3.433458048436948*^9, 
  3.445965693397637*^9, 3.447630552127799*^9, 3.447682844777367*^9, 
  3.447693374228043*^9, 3.447694138642482*^9, 3.447949683871181*^9, 
  3.447950241345294*^9}]
}, Open  ]],

Cell["\<\
The average magnetization components are calculated by applying the operator \
to the wavefunction and multiplying the result by the complex conjugate of \
the wavefunction.  For instance, to calculate the average magnetization of \
the I-spin along the z-axis for the psiAA state:\
\>", "Text",
 CellChangeTimes->{{3.4323109007115803`*^9, 3.4323110037395487`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", "psiAA", "]"}], ".", "Iz", ".", 
  "psiAA"}]], "Input",
 CellChangeTimes->{{3.432311010042602*^9, 3.432311042924551*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{{3.4323110328885527`*^9, 3.4323110438140383`*^9}, 
   3.4330914632175083`*^9, 3.4331767762390127`*^9, 3.43324573556218*^9, 
   3.433458048486356*^9, 3.445965693464303*^9, 3.447630584771229*^9, 
   3.447682844842167*^9, 3.447693374303927*^9, 3.4476941387095623`*^9, 
   3.447949683935313*^9, 3.44795024936364*^9}]
}, Open  ]],

Cell["\<\
The twoSpinLib package includes a function to calculate all of the average \
magnetization components for a given wavefunction:\
\>", "Text",
 CellChangeTimes->{{3.432311065274908*^9, 3.432311121272375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiAA", "]"}]], "Input",
 CellChangeTimes->{{3.432311127989491*^9, 3.432311136473736*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4323111373911533`*^9, 3.4330914632851543`*^9, 3.4331767762897463`*^9, {
   3.4331800211636267`*^9, 3.433180038928707*^9}, 3.43324573562719*^9, 
   3.433458048537092*^9, 3.445965693548852*^9, 3.447630590464806*^9, 
   3.447682844912163*^9, 3.4476933743742037`*^9, 3.4476941387784433`*^9, 
   3.447949684003297*^9, 3.447950252039249*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4323111373911533`*^9, 3.4330914632851543`*^9, 3.4331767762897463`*^9, {
   3.4331800211636267`*^9, 3.433180038928707*^9}, 3.43324573562719*^9, 
   3.433458048537092*^9, 3.445965693548852*^9, 3.447630590464806*^9, 
   3.447682844912163*^9, 3.4476933743742037`*^9, 3.4476941387784433`*^9, 
   3.447949684003297*^9, 3.447950252078217*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4323111373911533`*^9, 3.4330914632851543`*^9, 3.4331767762897463`*^9, {
   3.4331800211636267`*^9, 3.433180038928707*^9}, 3.43324573562719*^9, 
   3.433458048537092*^9, 3.445965693548852*^9, 3.447630590464806*^9, 
   3.447682844912163*^9, 3.4476933743742037`*^9, 3.4476941387784433`*^9, 
   3.447949684003297*^9, 3.447950252134653*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Thus, the psiAA wavefunction represents a state in which the magnetization of \
both spins is aligned with the positive z-axis.
For psiAB:\
\>", "Text",
 CellChangeTimes->{{3.432311151755896*^9, 3.432311191182479*^9}, {
  3.4323112256475163`*^9, 3.4323112314612722`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiAB", "]"}]], "Input",
 CellChangeTimes->{{3.432311234130878*^9, 3.432311243294537*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432311244154965*^9, 3.4330914634495707`*^9, 
  3.433176776339714*^9, 3.433180043281619*^9, 3.43324573567904*^9, 
  3.433458048588134*^9, 3.4459656936482964`*^9, 3.447630596943061*^9, 
  3.447682845012581*^9, 3.447693374490035*^9, 3.4476941389948883`*^9, 
  3.447949684103057*^9, 3.447950256281052*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432311244154965*^9, 3.4330914634495707`*^9, 
  3.433176776339714*^9, 3.433180043281619*^9, 3.43324573567904*^9, 
  3.433458048588134*^9, 3.4459656936482964`*^9, 3.447630596943061*^9, 
  3.447682845012581*^9, 3.447693374490035*^9, 3.4476941389948883`*^9, 
  3.447949684103057*^9, 3.4479502562949266`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432311244154965*^9, 3.4330914634495707`*^9, 
  3.433176776339714*^9, 3.433180043281619*^9, 3.43324573567904*^9, 
  3.433458048588134*^9, 3.4459656936482964`*^9, 3.447630596943061*^9, 
  3.447682845012581*^9, 3.447693374490035*^9, 3.4476941389948883`*^9, 
  3.447949684103057*^9, 3.4479502563097343`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
In this case, the I magnetization is aligned with the positive z-axis and the \
S magnetization is aligned with the negative z-axis.

Four other wavefunctions are used extensively as examples in the text.  Three \
of these are generated by applying pulses to some of the basis set \
wavefunctions.  As for the one-spin case, the effects of pulses are \
calculated using special rotation matrices.  For a pulse of angle a to the \
I-spin along the x-axis, the rotation matrix is:\
\>", "Text",
 CellChangeTimes->{{3.432310986273241*^9, 3.4323109893384743`*^9}, {
  3.432311265212549*^9, 3.432311357050005*^9}, {3.432311415935151*^9, 
  3.43231155479655*^9}, {3.432311593833426*^9, 3.432311625850965*^9}, {
  3.4323120859934053`*^9, 3.432312090854106*^9}, {3.4330913748968477`*^9, 
  3.4330913754533253`*^9}, {3.445632808554328*^9, 3.44563280904771*^9}, {
  3.447630616186154*^9, 3.447630618391912*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RIx", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.432311630560302*^9, 3.4323116426491413`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], "0", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], "0"},
     {"0", 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], "0", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], "0", 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], "0"},
     {"0", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], "0", 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432311644094455*^9, 3.433091463502953*^9, 
  3.4331767763900948`*^9, 3.433245735728527*^9, 3.433458048637491*^9, 
  3.445965693853018*^9, 3.447630624854171*^9, 3.447682845161582*^9, 
  3.4476933745904217`*^9, 3.447694139112157*^9, 3.447949684204194*^9, 
  3.447950260990103*^9}]
}, Open  ]],

Cell["\<\
The example wavefunction psiA is defined as the result of applying a pi/2 \
pulse along the x-axis to the S-spin of the psiAA state:\
\>", "Text",
 CellChangeTimes->{{3.4323119580559587`*^9, 3.432312041743415*^9}, {
  3.432312115290213*^9, 3.432312121621516*^9}, {3.4456926433913937`*^9, 
  3.4456926439205008`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiA", " ", "=", " ", 
  RowBox[{
   RowBox[{"RSx", "[", 
    RowBox[{"Pi", "/", "2"}], "]"}], ".", "psiAA"}]}]], "Input",
 CellChangeTimes->{{3.4323120445862617`*^9, 3.43231204834478*^9}, {
   3.432312098065199*^9, 3.432312111431244*^9}, 3.445633743278378*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.4323121123098907`*^9, 3.433091463569406*^9, 
  3.4331767764396544`*^9, 3.433245735777831*^9, 3.4334580487514677`*^9, 
  3.445633744971637*^9, 3.445692655215893*^9, 3.44577458413111*^9, 
  3.445774631463593*^9, 3.445872426246682*^9, 3.445965693932477*^9, 
  3.446134849034378*^9, 3.446203232955855*^9, 3.446220719975486*^9, 
  3.447630632920735*^9, 3.447682845292314*^9, 3.447693374673971*^9, 
  3.447694139178543*^9, 3.447949684269785*^9, 3.447950264546413*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiA", "]"}]], "Input",
 CellChangeTimes->{{3.43231218082323*^9, 3.432312189668792*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432312190692178*^9, 3.433091463636479*^9, 
  3.43317677652851*^9, 3.433179974805444*^9, 3.433180053591701*^9, 
  3.4332457358286123`*^9, 3.433458048805581*^9, 3.445633755937772*^9, 
  3.445692658108046*^9, 3.4457746372062273`*^9, 3.445965693998831*^9, 
  3.446134853830782*^9, 3.44763064057197*^9, 3.4476828454121027`*^9, 
  3.447693374757312*^9, 3.447694139245516*^9, 3.447949684341114*^9, 
  3.447950266699305*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432312190692178*^9, 3.433091463636479*^9, 
  3.43317677652851*^9, 3.433179974805444*^9, 3.433180053591701*^9, 
  3.4332457358286123`*^9, 3.433458048805581*^9, 3.445633755937772*^9, 
  3.445692658108046*^9, 3.4457746372062273`*^9, 3.445965693998831*^9, 
  3.446134853830782*^9, 3.44763064057197*^9, 3.4476828454121027`*^9, 
  3.447693374757312*^9, 3.447694139245516*^9, 3.447949684341114*^9, 
  3.4479502667414083`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432312190692178*^9, 3.433091463636479*^9, 
  3.43317677652851*^9, 3.433179974805444*^9, 3.433180053591701*^9, 
  3.4332457358286123`*^9, 3.433458048805581*^9, 3.445633755937772*^9, 
  3.445692658108046*^9, 3.4457746372062273`*^9, 3.445965693998831*^9, 
  3.446134853830782*^9, 3.44763064057197*^9, 3.4476828454121027`*^9, 
  3.447693374757312*^9, 3.447694139245516*^9, 3.447949684341114*^9, 
  3.447950266801935*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The S magnetization is rotated to the y-axis, as expected.

The twoSpinLib package includes special functions for pi and pi/2 pulses to \
either spin, one of which is used below to calculate another of the example \
wavefunctions.\
\>", "Text",
 CellChangeTimes->{{3.432312198425395*^9, 3.432312214490591*^9}, {
   3.4323122480769587`*^9, 3.432312305912339*^9}, {3.432312504081071*^9, 
   3.4323125045956078`*^9}, {3.432312647911813*^9, 3.432312658615328*^9}, 
   3.44563376251513*^9, {3.4476306549446793`*^9, 3.447630671039783*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiB", " ", "=", " ", 
  RowBox[{"psiPi2Sx", "[", "psiBA", "]"}]}]], "Input",
 CellChangeTimes->{{3.432312229371931*^9, 3.432312241917801*^9}, {
   3.432312310129883*^9, 3.432312312489279*^9}, {3.432312472323598*^9, 
   3.4323124799250517`*^9}, 3.445633776039219*^9, {3.445692593446867*^9, 
   3.445692595139065*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.4323124810200787`*^9, 3.433091463736066*^9, 
  3.433176776706788*^9, 3.4332457358797083`*^9, 3.433458048854622*^9, 
  3.4456337780574503`*^9, 3.445692596660285*^9, 3.445774639311138*^9, 
  3.445872429249302*^9, 3.4459656940989428`*^9, 3.4461348633050222`*^9, 
  3.446203238602581*^9, 3.446220722853676*^9, 3.447630658986987*^9, 
  3.447682845576784*^9, 3.447693374856997*^9, 3.4476941393458853`*^9, 
  3.4479496844381313`*^9, 3.447950280197607*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiB", "]"}]], "Input",
 CellChangeTimes->{{3.432312482657466*^9, 3.432312492228491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323124931425*^9, 3.4330914638040857`*^9, 
  3.433176776774794*^9, 3.433180057928985*^9, 3.433245735945507*^9, 
  3.4334580489063587`*^9, 3.4456337809517183`*^9, 3.445692607416719*^9, 
  3.445965694183277*^9, 3.4461348683522587`*^9, 3.447630679947363*^9, 
  3.447682845712755*^9, 3.447693374924016*^9, 3.4476941394132566`*^9, 
  3.447949684508363*^9, 3.447950283384207*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323124931425*^9, 3.4330914638040857`*^9, 
  3.433176776774794*^9, 3.433180057928985*^9, 3.433245735945507*^9, 
  3.4334580489063587`*^9, 3.4456337809517183`*^9, 3.445692607416719*^9, 
  3.445965694183277*^9, 3.4461348683522587`*^9, 3.447630679947363*^9, 
  3.447682845712755*^9, 3.447693374924016*^9, 3.4476941394132566`*^9, 
  3.447949684508363*^9, 3.447950283427352*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323124931425*^9, 3.4330914638040857`*^9, 
  3.433176776774794*^9, 3.433180057928985*^9, 3.433245735945507*^9, 
  3.4334580489063587`*^9, 3.4456337809517183`*^9, 3.445692607416719*^9, 
  3.445965694183277*^9, 3.4461348683522587`*^9, 3.447630679947363*^9, 
  3.447682845712755*^9, 3.447693374924016*^9, 3.4476941394132566`*^9, 
  3.447949684508363*^9, 3.447950283487837*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
A pulse to both spins is calculated by multiplying the wavefunction by one \
rotation matrix and then multiplying the result by the other matrix:\
\>", "Text",
 CellChangeTimes->{{3.432312508394911*^9, 3.432312644607017*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiC", " ", "=", " ", 
  RowBox[{
   RowBox[{"RIx", "[", 
    RowBox[{"Pi", "/", "2"}], "]"}], ".", 
   RowBox[{"RSx", "[", 
    RowBox[{"Pi", "/", "2"}], "]"}], ".", "psiAA"}]}]], "Input",
 CellChangeTimes->{{3.432312661285961*^9, 3.4323127161720257`*^9}, {
  3.445633793031563*^9, 3.445633800174898*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"], ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.432312717602462*^9, 3.433091463921075*^9, 
  3.433176776824964*^9, 3.433245736068165*^9, 3.4334580489561462`*^9, 
  3.445633801522071*^9, 3.445705205237671*^9, 3.445774643189365*^9, 
  3.445872432909362*^9, 3.445965694283746*^9, 3.4461348742981663`*^9, 
  3.446203241877799*^9, 3.4462207264901857`*^9, 3.44763069331017*^9, 
  3.4476828459801197`*^9, 3.4476933750225554`*^9, 3.447694139512003*^9, 
  3.447949684605752*^9, 3.447950288730557*^9}]
}, Open  ]],

Cell["\<\
Although matrix multiplication is not, in general, commutative, \
multiplications by the rotation matrices can be carried out in either order:\
\>", "Text",
 CellChangeTimes->{{3.432312733266047*^9, 3.4323127813472013`*^9}, {
  3.4323128519215193`*^9, 3.432312861201686*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RSx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}], ".", 
  RowBox[{"RIx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}], ".", "psiAA"}]], "Input",
 CellChangeTimes->{{3.432312815891038*^9, 3.432312835894537*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"], ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.432312836882287*^9, 3.433091464053392*^9, 
  3.4331767768743773`*^9, 3.433245736129315*^9, 3.433458049006311*^9, 
  3.44570521432975*^9, 3.445774650302907*^9, 3.4459656943506927`*^9, 
  3.446134878538012*^9, 3.447630701982172*^9, 3.447682846045439*^9, 
  3.44769337508927*^9, 3.447694139578252*^9, 3.4479496846721992`*^9, 
  3.447950291185231*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiC", "]"}]], "Input",
 CellChangeTimes->{{3.432312877019299*^9, 3.4323128861940517`*^9}, 
   3.4330914429297028`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330914641224318`*^9, 3.43317677692489*^9, 
  3.433180064440793*^9, 3.433245736165066*^9, 3.433458049056818*^9, 
  3.445705217036327*^9, 3.445774654312682*^9, 3.445965694434552*^9, 
  3.446134882835*^9, 3.44763070789042*^9, 3.447682846114768*^9, 
  3.447693375279132*^9, 3.447694139646482*^9, 3.447949684855373*^9, 
  3.447950303363594*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 
   Rational[1, 2], "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330914641224318`*^9, 3.43317677692489*^9, 
  3.433180064440793*^9, 3.433245736165066*^9, 3.433458049056818*^9, 
  3.445705217036327*^9, 3.445774654312682*^9, 3.445965694434552*^9, 
  3.446134882835*^9, 3.44763070789042*^9, 3.447682846114768*^9, 
  3.447693375279132*^9, 3.447694139646482*^9, 3.447949684855373*^9, 
  3.44795030337831*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330914641224318`*^9, 3.43317677692489*^9, 
  3.433180064440793*^9, 3.433245736165066*^9, 3.433458049056818*^9, 
  3.445705217036327*^9, 3.445774654312682*^9, 3.445965694434552*^9, 
  3.446134882835*^9, 3.44763070789042*^9, 3.447682846114768*^9, 
  3.447693375279132*^9, 3.447694139646482*^9, 3.447949684855373*^9, 
  3.447950303393796*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The other wavefunction used for examples in the text is psiD:\
\>", "Text",
 CellChangeTimes->{{3.432313301076784*^9, 3.43231332295639*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiD", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4323133263834677`*^9, 3.432313364709638*^9}, 
   3.446134888969883*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432313459477027*^9, 3.433091464172185*^9, 
  3.433176777013939*^9, 3.433245736246587*^9, 3.433458049108118*^9, 
  3.445774657015332*^9, 3.445872436465488*^9, 3.44596569453365*^9, 
  3.446134890480382*^9, 3.4462032488404818`*^9, 3.446220732254651*^9, 
  3.447630717033175*^9, 3.447682846212637*^9, 3.4476933753909597`*^9, 
  3.44769413974568*^9, 3.4479496849544477`*^9, 3.447950309072132*^9}]
}, Open  ]],

Cell["\<\
This wavefunction is not so easy to generate from one of the basis \
wavefunctions, but has very interesting properties:\
\>", "Text",
 CellChangeTimes->{{3.432313370825246*^9, 3.4323134199617357`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiD", "]"}]], "Input",
 CellChangeTimes->{{3.4323134227666388`*^9, 3.432313430570916*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432313431513603*^9, 3.432313461779018*^9, 
  3.4330914642382917`*^9, 3.433176777115075*^9, 3.4331800687121887`*^9, 
  3.433245736296832*^9, 3.433458049173346*^9, 3.445774661743349*^9, 
  3.445965694599951*^9, 3.4461348956596537`*^9, 3.4476307209174957`*^9, 
  3.447682846281543*^9, 3.4476933754576063`*^9, 3.4476941398124647`*^9, 
  3.4479496850214653`*^9, 3.4479503129666348`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432313431513603*^9, 3.432313461779018*^9, 
  3.4330914642382917`*^9, 3.433176777115075*^9, 3.4331800687121887`*^9, 
  3.433245736296832*^9, 3.433458049173346*^9, 3.445774661743349*^9, 
  3.445965694599951*^9, 3.4461348956596537`*^9, 3.4476307209174957`*^9, 
  3.447682846281543*^9, 3.4476933754576063`*^9, 3.4476941398124647`*^9, 
  3.4479496850214653`*^9, 3.447950312981079*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432313431513603*^9, 3.432313461779018*^9, 
  3.4330914642382917`*^9, 3.433176777115075*^9, 3.4331800687121887`*^9, 
  3.433245736296832*^9, 3.433458049173346*^9, 3.445774661743349*^9, 
  3.445965694599951*^9, 3.4461348956596537`*^9, 3.4476307209174957`*^9, 
  3.447682846281543*^9, 3.4476933754576063`*^9, 3.4476941398124647`*^9, 
  3.4479496850214653`*^9, 3.447950312996407*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
There is no net magnetization in any direction!  For any measurement of \
individual particles, the two possible outcomes, 1/2 and -1/2 will be \
obtained with equal probability.\
\>", "Text",
 CellChangeTimes->{{3.432313472369055*^9, 3.4323134841920643`*^9}, {
  3.432313524491632*^9, 3.432313556902076*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Product operators and correlations", "Section",
 CellChangeTimes->{{3.432313765769538*^9, 3.432313778239874*^9}}],

Cell["\<\
The product operators are generated by multiplying the corresponding operator \
matrices:\
\>", "Text",
 CellChangeTimes->{{3.432313788150378*^9, 3.4323138264145527`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "Sx"}]], "Input",
 CellChangeTimes->{{3.432313829694604*^9, 3.432313832013728*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", 
      FractionBox["1", "4"]},
     {"0", "0", 
      FractionBox["1", "4"], "0"},
     {"0", 
      FractionBox["1", "4"], "0", "0"},
     {
      FractionBox["1", "4"], "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4323138329987383`*^9, 3.433091464291609*^9, 
  3.433176777160494*^9, 3.433245736426691*^9, 3.4334580492243958`*^9, 
  3.445965694700734*^9, 3.447630749995739*^9, 3.44768284638097*^9, 
  3.4476933755574083`*^9, 3.4476941400436783`*^9, 3.447949685122622*^9, 
  3.447950317023181*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "Sy"}]], "Input",
 CellChangeTimes->{{3.432313834832313*^9, 3.432313836703933*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}]},
     {"0", "0", 
      FractionBox["\[ImaginaryI]", "4"], "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}], "0", "0"},
     {
      FractionBox["\[ImaginaryI]", "4"], "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313837892726*^9, 3.433091464421568*^9, 
  3.43317677719342*^9, 3.433245736480701*^9, 3.433458049274008*^9, 
  3.4459656949968157`*^9, 3.447630752256008*^9, 3.447682846465809*^9, 
  3.4476933756238337`*^9, 3.44769414013195*^9, 3.447949685189045*^9, 
  3.447950319459049*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "Sz"}]], "Input",
 CellChangeTimes->{{3.432313840477944*^9, 3.432313845351384*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox["1", "4"], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}]},
     {
      FractionBox["1", "4"], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313846322776*^9, 3.4330914647741947`*^9, 
  3.433176777260605*^9, 3.43324573653017*^9, 3.433458049324009*^9, 
  3.445965695104508*^9, 3.447630754716161*^9, 3.44768284653267*^9, 
  3.447693375690349*^9, 3.447694140214592*^9, 3.447949685255965*^9, 
  3.447950321916013*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iy", ".", "Sx"}]], "Input",
 CellChangeTimes->{{3.432313851083325*^9, 3.4323138551190567`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}]},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}], "0"},
     {"0", 
      FractionBox["\[ImaginaryI]", "4"], "0", "0"},
     {
      FractionBox["\[ImaginaryI]", "4"], "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313856158798*^9, 3.433091464908083*^9, 
  3.43317677730976*^9, 3.43324573658123*^9, 3.433458049374102*^9, 
  3.4459656952059307`*^9, 3.447630757347518*^9, 3.4476828465987473`*^9, 
  3.4476933757570744`*^9, 3.44769414031432*^9, 3.4479496853228073`*^9, 
  3.447950323452577*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iy", ".", "Sy"}]], "Input",
 CellChangeTimes->{{3.432313857296751*^9, 3.432313864383033*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}]},
     {"0", "0", 
      FractionBox["1", "4"], "0"},
     {"0", 
      FractionBox["1", "4"], "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["1", "4"]}], "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313865346993*^9, 3.43309146504237*^9, 
  3.4331767773609447`*^9, 3.433245736631757*^9, 3.4334580494733553`*^9, 
  3.445965695316835*^9, 3.447630760913303*^9, 3.447682846665517*^9, 
  3.447693375824369*^9, 3.44769414038221*^9, 3.44794968538983*^9, 
  3.447950325256426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iy", ".", "Sz"}]], "Input",
 CellChangeTimes->{{3.432313866561379*^9, 3.432313868110811*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}], "0"},
     {"0", "0", "0", 
      FractionBox["\[ImaginaryI]", "4"]},
     {
      FractionBox["\[ImaginaryI]", "4"], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313869018106*^9, 3.4330914651100483`*^9, 
  3.43317677741109*^9, 3.433245736681649*^9, 3.433458049573701*^9, 
  3.445965695418322*^9, 3.447630763608487*^9, 3.447682846732333*^9, 
  3.447693375890952*^9, 3.4476941404474163`*^9, 3.447949685454254*^9, 
  3.447950327510229*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iz", ".", "Sx"}]], "Input",
 CellChangeTimes->{
  3.432313871071075*^9, {3.432313920235341*^9, 3.432313922219749*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "4"], "0", "0"},
     {
      FractionBox["1", "4"], "0", "0", "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}]},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313923082794*^9, 3.4330914651605473`*^9, 
  3.433176777461129*^9, 3.433245736732936*^9, 3.433458049673999*^9, 
  3.4459656954972486`*^9, 3.447630766251807*^9, 3.447682846799217*^9, 
  3.44769337599839*^9, 3.447694140514701*^9, 3.447949685526114*^9, 
  3.4479503295652723`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iz", ".", "Sy"}]], "Input",
 CellChangeTimes->{{3.432313924215631*^9, 3.4323139287176523`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}], "0", "0"},
     {
      FractionBox["\[ImaginaryI]", "4"], "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox["\[ImaginaryI]", "4"]},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.43231392958184*^9, 3.433091465229065*^9, 
  3.4331767775112343`*^9, 3.4332457367831907`*^9, 3.4334580498399477`*^9, 
  3.4459656959924507`*^9, 3.4476307695499697`*^9, 3.447682847030437*^9, 
  3.447693376119666*^9, 3.447694140581956*^9, 3.447949685592778*^9, 
  3.447950330849349*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iz", ".", "Sz"}]], "Input",
 CellChangeTimes->{{3.432313930802973*^9, 3.432313932901524*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "4"], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}], "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}], "0"},
     {"0", "0", "0", 
      FractionBox["1", "4"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.432313933773471*^9, 3.433091465296427*^9, 
  3.433176777561862*^9, 3.4332457368335247`*^9, 3.433458049872096*^9, 
  3.4459656962479277`*^9, 3.447630772797503*^9, 3.447682847165259*^9, 
  3.447693376459648*^9, 3.447694140668027*^9, 3.447949685659295*^9, 
  3.447950332887619*^9}]
}, Open  ]],

Cell["\<\
The product operator matrices are also defined in the twoSpinLib, with \
symbols IxSx, IxSy, etc.
The average value of the product is calculated in the same way as the average \
magnetization components.  For instance, to calculate the average product \
IzSz for the psiAA wavefunction:\
\>", "Text",
 CellChangeTimes->{{3.432313941773397*^9, 3.432314004009508*^9}, {
   3.432314037808744*^9, 3.432314071512517*^9}, 3.447694373234755*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", "psiAA", "]"}], ".", "IzSz", ".", 
  "psiAA"}]], "Input",
 CellChangeTimes->{{3.4323140753436623`*^9, 3.4323141049286127`*^9}}],

Cell[BoxData[
 FractionBox["1", "4"]], "Output",
 CellChangeTimes->{{3.432314093663988*^9, 3.432314106400695*^9}, 
   3.4330914653610153`*^9, 3.4331767776922083`*^9, 3.433245736882433*^9, 
   3.433458049910433*^9, 3.445965696759611*^9, 3.447630829486496*^9, 
   3.4476828473133907`*^9, 3.4476933765988827`*^9, 3.447694140732133*^9, 
   3.447949685770732*^9, 3.4479503403217363`*^9}]
}, Open  ]],

Cell["\<\
A special function is provided to calculate all of the product averages for a \
wavefunction:\
\>", "Text",
 CellChangeTimes->{{3.432314108407201*^9, 3.432314147885661*^9}, {
  3.4458723941966867`*^9, 3.445872399731292*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", "psiAA", "]"}]], "Input",
 CellChangeTimes->{{3.432314150997107*^9, 3.432314164358676*^9}, {
  3.445872374960947*^9, 3.445872383485305*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445872384441579*^9, 3.445965696847632*^9, 
  3.44613491369825*^9, 3.447630833152617*^9, 3.4476828474495983`*^9, 
  3.447693376706571*^9, 3.447694140799548*^9, 3.447949685956942*^9, 
  3.447950344683489*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445872384441579*^9, 3.445965696847632*^9, 
  3.44613491369825*^9, 3.447630833152617*^9, 3.4476828474495983`*^9, 
  3.447693376706571*^9, 3.447694140799548*^9, 3.447949685956942*^9, 
  3.4479503446974373`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"]}],
  SequenceForm[
  "<IzSx> = ", 0, "     ", "<IzSy> = ", 0, "     ", "<IzSz> = ", 
   Rational[1, 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.445872384441579*^9, 3.445965696847632*^9, 
  3.44613491369825*^9, 3.447630833152617*^9, 3.4476828474495983`*^9, 
  3.447693376706571*^9, 3.447694140799548*^9, 3.447949685956942*^9, 
  3.44795034471243*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
This result is consistent with the fact that, for this wavefunction, <Iz>  = \
<Sz> = 1/2, and all of the other average magnetization components are zero.

For psiA, generated by applying a pi/2-x pulse to the S spin:\
\>", "Text",
 CellChangeTimes->{{3.4323145525567217`*^9, 3.43231468319101*^9}, {
   3.44620330761779*^9, 3.446203309141773*^9}, 3.447630869001132*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", "psiA", "]"}]], "Input",
 CellChangeTimes->{{3.432314685421681*^9, 3.4323146934013243`*^9}, {
  3.445872413332755*^9, 3.445872413852166*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.432314694359825*^9, 3.4330914656278543`*^9, 3.4331767777961817`*^9, 
   3.4331800779872923`*^9, 3.433245736985426*^9, 3.433458050110277*^9, 
   3.445635208585816*^9, {3.445872415344714*^9, 3.445872444117816*^9}, 
   3.4459656970143747`*^9, 3.44613491697399*^9, 3.447630848453493*^9, 
   3.447682847616927*^9, 3.44769337767949*^9, 3.447694140918754*^9, 
   3.44794968605733*^9, 3.447950357144103*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.432314694359825*^9, 3.4330914656278543`*^9, 3.4331767777961817`*^9, 
   3.4331800779872923`*^9, 3.433245736985426*^9, 3.433458050110277*^9, 
   3.445635208585816*^9, {3.445872415344714*^9, 3.445872444117816*^9}, 
   3.4459656970143747`*^9, 3.44613491697399*^9, 3.447630848453493*^9, 
   3.447682847616927*^9, 3.44769337767949*^9, 3.447694140918754*^9, 
   3.44794968605733*^9, 3.447950357158547*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.432314694359825*^9, 3.4330914656278543`*^9, 3.4331767777961817`*^9, 
   3.4331800779872923`*^9, 3.433245736985426*^9, 3.433458050110277*^9, 
   3.445635208585816*^9, {3.445872415344714*^9, 3.445872444117816*^9}, 
   3.4459656970143747`*^9, 3.44613491697399*^9, 3.447630848453493*^9, 
   3.447682847616927*^9, 3.44769337767949*^9, 3.447694140918754*^9, 
   3.44794968605733*^9, 3.447950357173716*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The net correlation changes along with the magnetization component.

For the wavefunction psiD\
\>", "Text",
 CellChangeTimes->{{3.4323147176709623`*^9, 3.4323147519492197`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", "psiD", "]"}]], "Input",
 CellChangeTimes->{{3.432314755019445*^9, 3.432314770854115*^9}, {
  3.4458724485880003`*^9, 3.4458724567070837`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IxSx> = ", 
   Rational[1, 4], "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445872457513421*^9, 3.445965697256104*^9, 
  3.4461349215166388`*^9, 3.4476309210638247`*^9, 3.44768284771907*^9, 
  3.447693378142951*^9, 3.4476941412669*^9, 3.447949686157714*^9, 
  3.4479503607005453`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IySx> = ", 0, "     ", "<IySy> = ", 
   Rational[1, 4], "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445872457513421*^9, 3.445965697256104*^9, 
  3.4461349215166388`*^9, 3.4476309210638247`*^9, 3.44768284771907*^9, 
  3.447693378142951*^9, 3.4476941412669*^9, 3.447949686157714*^9, 
  3.4479503607152357`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "4"]}]}],
  SequenceForm[
  "<IzSx> = ", 0, "     ", "<IzSy> = ", 0, "     ", "<IzSz> = ", 
   Rational[-1, 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.445872457513421*^9, 3.445965697256104*^9, 
  3.4461349215166388`*^9, 3.4476309210638247`*^9, 3.44768284771907*^9, 
  3.447693378142951*^9, 3.4476941412669*^9, 3.447949686157714*^9, 
  3.447950360730047*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Even though all of the average magnetization components are zero, there are \
three non-zero product averages, indicating correlations between Ix and Sx, \
Iy and Sy, and Iz and Sz measured for individual spin pairs.\
\>", "Text",
 CellChangeTimes->{{3.432314779284155*^9, 3.432314841458803*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pulses and time evolution for a scalar-coupled spin pair", "Section",
 CellChangeTimes->{{3.432315502805768*^9, 3.432315517032537*^9}}],

Cell["\<\
The matrices used to calculate the effects of a pulse on the wavefunction \
have been  introduced earlier.  These pulses can change the correlations \
associated with a wavefunction, as well as the observable magnetization.  For \
instance, starting with the psiAA wavefunction:\
\>", "Text",
 CellChangeTimes->{{3.432315528408328*^9, 3.432315644893281*^9}, 
   3.447694381673523*^9}],

Cell[CellGroupData[{

Cell["Pulses", "Subsection",
 CellChangeTimes->{{3.432317289278124*^9, 3.432317290153451*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiAA", "]"}]], "Input",
 CellChangeTimes->{{3.432315675285611*^9, 3.432315683757677*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323156845859127`*^9, 3.433091465771701*^9, 
  3.433176778007988*^9, 3.4331800887003393`*^9, 3.433245737152953*^9, 
  3.4334580502614*^9, 3.4459656974153214`*^9, 3.446134970490011*^9, 
  3.447630977315888*^9, 3.447682847820661*^9, 3.447693378266612*^9, 
  3.4476941414326057`*^9, 3.447949686309794*^9, 3.447950365359459*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323156845859127`*^9, 3.433091465771701*^9, 
  3.433176778007988*^9, 3.4331800887003393`*^9, 3.433245737152953*^9, 
  3.4334580502614*^9, 3.4459656974153214`*^9, 3.446134970490011*^9, 
  3.447630977315888*^9, 3.447682847820661*^9, 3.447693378266612*^9, 
  3.4476941414326057`*^9, 3.447949686309794*^9, 3.447950365373769*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323156845859127`*^9, 3.433091465771701*^9, 
  3.433176778007988*^9, 3.4331800887003393`*^9, 3.433245737152953*^9, 
  3.4334580502614*^9, 3.4459656974153214`*^9, 3.446134970490011*^9, 
  3.447630977315888*^9, 3.447682847820661*^9, 3.447693378266612*^9, 
  3.4476941414326057`*^9, 3.447949686309794*^9, 3.447950365388853*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", "psiAA", "]"}]], "Input",
 CellChangeTimes->{{3.432315685423497*^9, 3.43231569379725*^9}, {
  3.4458724706037683`*^9, 3.445872472586499*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323156947576733`*^9, 3.433091465831915*^9, 
  3.433176778045437*^9, 3.4331800927362347`*^9, 3.433245737201776*^9, 
  3.4334580503125353`*^9, 3.4458724735610313`*^9, 3.4459656975652933`*^9, 
  3.446134973694902*^9, 3.4476309808820343`*^9, 3.447682848020941*^9, 
  3.447693378400955*^9, 3.447694141583241*^9, 3.447949686411955*^9, 
  3.447950368350863*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323156947576733`*^9, 3.433091465831915*^9, 
  3.433176778045437*^9, 3.4331800927362347`*^9, 3.433245737201776*^9, 
  3.4334580503125353`*^9, 3.4458724735610313`*^9, 3.4459656975652933`*^9, 
  3.446134973694902*^9, 3.4476309808820343`*^9, 3.447682848020941*^9, 
  3.447693378400955*^9, 3.447694141583241*^9, 3.447949686411955*^9, 
  3.4479503683656282`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"]}],
  SequenceForm[
  "<IzSx> = ", 0, "     ", "<IzSy> = ", 0, "     ", "<IzSz> = ", 
   Rational[1, 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323156947576733`*^9, 3.433091465831915*^9, 
  3.433176778045437*^9, 3.4331800927362347`*^9, 3.433245737201776*^9, 
  3.4334580503125353`*^9, 3.4458724735610313`*^9, 3.4459656975652933`*^9, 
  3.446134973694902*^9, 3.4476309808820343`*^9, 3.447682848020941*^9, 
  3.447693378400955*^9, 3.447694141583241*^9, 3.447949686411955*^9, 
  3.4479503683805*^9}]
}, Open  ]]
}, Open  ]],

Cell["Applying a pi/2-x pulse to the S-spin", "Text",
 CellChangeTimes->{{3.432315705881687*^9, 3.432315720467143*^9}, 
   3.447630985006917*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPi2Sx", "[", "psiAA", "]"}]], "Input",
 CellChangeTimes->{{3.432315647685924*^9, 3.4323156668241777`*^9}, 
   3.4476309892074337`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.4323156678714743`*^9, 3.433091465880731*^9, 
  3.433176778097034*^9, 3.433245737251412*^9, 3.4334580503621683`*^9, 
  3.445965697715015*^9, 3.4461349786025467`*^9, 3.447630990974739*^9, 
  3.4476828481163883`*^9, 3.447693378510721*^9, 3.447694141733605*^9, 
  3.447949686512721*^9, 3.4479503715360518`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", 
     SqrtBox["2"]], ",", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["2"]], ",", "0", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.432315699034934*^9, 3.432315740968299*^9}, 
   3.4476310161331043`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432315743076169*^9, 3.4330914659488373`*^9, 
  3.4331767781480207`*^9, 3.433180099450243*^9, 3.433245737302824*^9, 
  3.43345805041259*^9, 3.445965697799255*^9, 3.446134981395137*^9, 
  3.44763101786279*^9, 3.447682848185999*^9, 3.447693378686879*^9, 
  3.4476941418043537`*^9, 3.4479496865794907`*^9, 3.447950374225753*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432315743076169*^9, 3.4330914659488373`*^9, 
  3.4331767781480207`*^9, 3.433180099450243*^9, 3.433245737302824*^9, 
  3.43345805041259*^9, 3.445965697799255*^9, 3.446134981395137*^9, 
  3.44763101786279*^9, 3.447682848185999*^9, 3.447693378686879*^9, 
  3.4476941418043537`*^9, 3.4479496865794907`*^9, 3.447950374268984*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432315743076169*^9, 3.4330914659488373`*^9, 
  3.4331767781480207`*^9, 3.433180099450243*^9, 3.433245737302824*^9, 
  3.43345805041259*^9, 3.445965697799255*^9, 3.446134981395137*^9, 
  3.44763101786279*^9, 3.447682848185999*^9, 3.447693378686879*^9, 
  3.4476941418043537`*^9, 3.4479496865794907`*^9, 3.447950374329234*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", 
     SqrtBox["2"]], ",", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["2"]], ",", "0", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.432315670224904*^9, 3.43231567206938*^9}, {
   3.432315748243622*^9, 3.43231575279673*^9}, 3.445872488161839*^9, 
   3.4476310249785757`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323157546851397`*^9, 3.433091466015414*^9, 
  3.4331767781977787`*^9, 3.433180103116315*^9, 3.433245737353119*^9, 
  3.4334580505119247`*^9, 3.445965697948844*^9, 3.446134987356151*^9, 
  3.447631026436722*^9, 3.44768284828622*^9, 3.447693378818286*^9, 
  3.447694141918827*^9, 3.447949686679097*^9, 3.447950382262474*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323157546851397`*^9, 3.433091466015414*^9, 
  3.4331767781977787`*^9, 3.433180103116315*^9, 3.433245737353119*^9, 
  3.4334580505119247`*^9, 3.445965697948844*^9, 3.446134987356151*^9, 
  3.447631026436722*^9, 3.44768284828622*^9, 3.447693378818286*^9, 
  3.447694141918827*^9, 3.447949686679097*^9, 3.447950382276248*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323157546851397`*^9, 3.433091466015414*^9, 
  3.4331767781977787`*^9, 3.433180103116315*^9, 3.433245737353119*^9, 
  3.4334580505119247`*^9, 3.445965697948844*^9, 3.446134987356151*^9, 
  3.447631026436722*^9, 3.44768284828622*^9, 3.447693378818286*^9, 
  3.447694141918827*^9, 3.447949686679097*^9, 3.44795038229099*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The Iz component of the IzSz correlation is rotated to the y-axis.

A subsequent pi/2-x pulse to the S-spin:\
\>", "Text",
 CellChangeTimes->{{3.432315792630434*^9, 3.432315827760305*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPi2Ix", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", 
     SqrtBox["2"]], ",", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["2"]], ",", "0", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.43231675545772*^9, 3.432316770092732*^9}, {
  3.4476310510866337`*^9, 3.447631054383007*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"], ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.432316771939171*^9, 3.4330914660817213`*^9, 
  3.4331767782485113`*^9, 3.433245737402368*^9, 3.433458050611989*^9, 
  3.445965698099032*^9, 3.447631056453723*^9, 3.447682848384295*^9, 
  3.447693379931213*^9, 3.447694142083324*^9, 3.447949686776957*^9, 
  3.447950385198245*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", "2"], ",", 
    FractionBox["\[ImaginaryI]", "2"], ",", 
    FractionBox["\[ImaginaryI]", "2"], ",", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.432316783331238*^9, 3.432316797776713*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316798599057*^9, 3.4330914661501217`*^9, 
  3.43317677829801*^9, 3.433180127540381*^9, 3.433245737453999*^9, 
  3.4334580507126226`*^9, 3.445965698266469*^9, 3.447631061089978*^9, 
  3.447682848454359*^9, 3.4476933801407127`*^9, 3.447694142532693*^9, 
  3.447949686962845*^9, 3.447950397310596*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 
   Rational[1, 2], "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316798599057*^9, 3.4330914661501217`*^9, 
  3.43317677829801*^9, 3.433180127540381*^9, 3.433245737453999*^9, 
  3.4334580507126226`*^9, 3.445965698266469*^9, 3.447631061089978*^9, 
  3.447682848454359*^9, 3.4476933801407127`*^9, 3.447694142532693*^9, 
  3.447949686962845*^9, 3.447950397325142*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316798599057*^9, 3.4330914661501217`*^9, 
  3.43317677829801*^9, 3.433180127540381*^9, 3.433245737453999*^9, 
  3.4334580507126226`*^9, 3.445965698266469*^9, 3.447631061089978*^9, 
  3.447682848454359*^9, 3.4476933801407127`*^9, 3.447694142532693*^9, 
  3.447949686962845*^9, 3.447950397340337*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["1", "2"], ",", 
    FractionBox["\[ImaginaryI]", "2"], ",", 
    FractionBox["\[ImaginaryI]", "2"], ",", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.43231680822803*^9, 3.432316810456379*^9}, 
   3.445872488198484*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323168116550207`*^9, 3.433091466216878*^9, 
  3.433176778348955*^9, 3.433180131125078*^9, 3.433245737503461*^9, 
  3.433458050878891*^9, 3.445965698416931*^9, 3.4476310646727877`*^9, 
  3.4476828485537643`*^9, 3.44769338026781*^9, 3.447694142636998*^9, 
  3.447949687064139*^9, 3.4479504027044983`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IySx> = ", 0, "     ", "<IySy> = ", 
   Rational[1, 4], "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323168116550207`*^9, 3.433091466216878*^9, 
  3.433176778348955*^9, 3.433180131125078*^9, 3.433245737503461*^9, 
  3.433458050878891*^9, 3.445965698416931*^9, 3.4476310646727877`*^9, 
  3.4476828485537643`*^9, 3.44769338026781*^9, 3.447694142636998*^9, 
  3.447949687064139*^9, 3.44795040271914*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", 0, "     ", "<IzSy> = ", 0, "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323168116550207`*^9, 3.433091466216878*^9, 
  3.433176778348955*^9, 3.433180131125078*^9, 3.433245737503461*^9, 
  3.433458050878891*^9, 3.445965698416931*^9, 3.4476310646727877`*^9, 
  3.4476828485537643`*^9, 3.44769338026781*^9, 3.447694142636998*^9, 
  3.447949687064139*^9, 3.447950402734396*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The original IzSz correlation is now converted into an IySy correlation.

A pulse applied to the psiD wavefunction:\
\>", "Text",
 CellChangeTimes->{{3.43231692486196*^9, 3.4323169625621233`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["psiD"], "Input",
 CellChangeTimes->{{3.4323169653509893`*^9, 3.432316966816822*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432316967822534*^9, 3.4330914662825336`*^9, 
  3.433176778399323*^9, 3.4332457375536013`*^9, 3.433458050931222*^9, 
  3.4459656985666513`*^9, 3.446135000098607*^9, 3.4476310736953163`*^9, 
  3.447682848651615*^9, 3.447693380383257*^9, 3.447694142752767*^9, 
  3.4479496871606703`*^9, 3.4479504063093367`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", "psiD", "]"}]], "Input",
 CellChangeTimes->{{3.432316969506377*^9, 3.4323169783293552`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316979176773*^9, 3.4330914663509207`*^9, 
  3.4331767784487867`*^9, 3.433180136162018*^9, 3.433245737653488*^9, 
  3.433458050981723*^9, 3.4459656986503687`*^9, 3.4461350027720127`*^9, 
  3.447631078048359*^9, 3.447682848720813*^9, 3.447693380468214*^9, 
  3.44769414283675*^9, 3.4479496872302933`*^9, 3.4479504083994617`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316979176773*^9, 3.4330914663509207`*^9, 
  3.4331767784487867`*^9, 3.433180136162018*^9, 3.433245737653488*^9, 
  3.433458050981723*^9, 3.4459656986503687`*^9, 3.4461350027720127`*^9, 
  3.447631078048359*^9, 3.447682848720813*^9, 3.447693380468214*^9, 
  3.44769414283675*^9, 3.4479496872302933`*^9, 3.4479504084140263`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316979176773*^9, 3.4330914663509207`*^9, 
  3.4331767784487867`*^9, 3.433180136162018*^9, 3.433245737653488*^9, 
  3.433458050981723*^9, 3.4459656986503687`*^9, 3.4461350027720127`*^9, 
  3.447631078048359*^9, 3.447682848720813*^9, 3.447693380468214*^9, 
  3.44769414283675*^9, 3.4479496872302933`*^9, 3.44795040842933*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", "psiD", "]"}]], "Input",
 CellChangeTimes->{{3.432316980332972*^9, 3.432316988377577*^9}, 
   3.445872488205392*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IxSx> = ", 
   Rational[1, 4], "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316989146392*^9, 3.4330914664181633`*^9, 
  3.433176778499073*^9, 3.433180139677848*^9, 3.43324573775371*^9, 
  3.4334580510813293`*^9, 3.4459656988001738`*^9, 3.446135006713892*^9, 
  3.447631092815997*^9, 3.447682848821262*^9, 3.4476933805863237`*^9, 
  3.4476941429395027`*^9, 3.4479496873309526`*^9, 3.447950410773538*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IySx> = ", 0, "     ", "<IySy> = ", 
   Rational[1, 4], "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316989146392*^9, 3.4330914664181633`*^9, 
  3.433176778499073*^9, 3.433180139677848*^9, 3.43324573775371*^9, 
  3.4334580510813293`*^9, 3.4459656988001738`*^9, 3.446135006713892*^9, 
  3.447631092815997*^9, 3.447682848821262*^9, 3.4476933805863237`*^9, 
  3.4476941429395027`*^9, 3.4479496873309526`*^9, 3.447950410788225*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "4"]}]}],
  SequenceForm[
  "<IzSx> = ", 0, "     ", "<IzSy> = ", 0, "     ", "<IzSz> = ", 
   Rational[-1, 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432316989146392*^9, 3.4330914664181633`*^9, 
  3.433176778499073*^9, 3.433180139677848*^9, 3.43324573775371*^9, 
  3.4334580510813293`*^9, 3.4459656988001738`*^9, 3.446135006713892*^9, 
  3.447631092815997*^9, 3.447682848821262*^9, 3.4476933805863237`*^9, 
  3.4476941429395027`*^9, 3.4479496873309526`*^9, 3.4479504108037033`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiPi2Ix", "[", "psiD", "]"}]], "Input",
 CellChangeTimes->{{3.432317034514337*^9, 3.432317049583455*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["\[ImaginaryI]", "2"], ",", 
   FractionBox["1", "2"], ",", 
   FractionBox["1", "2"], ",", 
   FractionBox["\[ImaginaryI]", "2"]}], "}"}]], "Output",
 CellChangeTimes->{3.432317050642169*^9, 3.4330914664836893`*^9, 
  3.43317677854979*^9, 3.4332457378040648`*^9, 3.433458051181027*^9, 
  3.4459656989503927`*^9, 3.446135014144459*^9, 3.44763110143829*^9, 
  3.4476828489178*^9, 3.4476933807014093`*^9, 3.447694143119137*^9, 
  3.447949687428562*^9, 3.447950415897994*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["\[ImaginaryI]", "2"], ",", 
    FractionBox["1", "2"], ",", 
    FractionBox["1", "2"], ",", 
    FractionBox["\[ImaginaryI]", "2"]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.432317052815292*^9, 3.4323170640502577`*^9}, 
   3.446138466037959*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432317065073*^9, 3.4330914665517*^9, 
  3.4331767785998163`*^9, 3.433180151146248*^9, 3.433245737855837*^9, 
  3.433458051232218*^9, 3.4459656990345383`*^9, 3.4461350187728662`*^9, 
  3.446138467362858*^9, 3.447631105656514*^9, 3.4476828491195183`*^9, 
  3.447693380786478*^9, 3.447694143340364*^9, 3.447949687497405*^9, 
  3.4479504179038153`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432317065073*^9, 3.4330914665517*^9, 
  3.4331767785998163`*^9, 3.433180151146248*^9, 3.433245737855837*^9, 
  3.433458051232218*^9, 3.4459656990345383`*^9, 3.4461350187728662`*^9, 
  3.446138467362858*^9, 3.447631105656514*^9, 3.4476828491195183`*^9, 
  3.447693380786478*^9, 3.447694143340364*^9, 3.447949687497405*^9, 
  3.447950417917427*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432317065073*^9, 3.4330914665517*^9, 
  3.4331767785998163`*^9, 3.433180151146248*^9, 3.433245737855837*^9, 
  3.433458051232218*^9, 3.4459656990345383`*^9, 3.4461350187728662`*^9, 
  3.446138467362858*^9, 3.447631105656514*^9, 3.4476828491195183`*^9, 
  3.447693380786478*^9, 3.447694143340364*^9, 3.447949687497405*^9, 
  3.4479504179326477`*^9}]
}, Open  ]]
}, Open  ]],

Cell["There are still no net magnetization components.", "Text",
 CellChangeTimes->{{3.432317085583219*^9, 3.432317100486505*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox["\[ImaginaryI]", "2"], ",", 
    FractionBox["1", "2"], ",", 
    FractionBox["1", "2"], ",", 
    FractionBox["\[ImaginaryI]", "2"]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4323171103157673`*^9, 3.432317128184216*^9}, 
   3.4458724882121973`*^9, 3.446138472218884*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IxSx> = ", 
   Rational[1, 4], "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323171293621063`*^9, 3.433091466716498*^9, 
  3.433176778788772*^9, 3.433180153874913*^9, 3.433245737906657*^9, 
  3.433458051283168*^9, 3.445965699186565*^9, 3.446135022681395*^9, 
  3.446138473193515*^9, 3.447631110412198*^9, 3.447682849221881*^9, 
  3.4476933809023542`*^9, 3.4476941434742393`*^9, 3.447949687599078*^9, 
  3.447950421109709*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "4"]}]}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 
   Rational[-1, 4]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323171293621063`*^9, 3.433091466716498*^9, 
  3.433176778788772*^9, 3.433180153874913*^9, 3.433245737906657*^9, 
  3.433458051283168*^9, 3.445965699186565*^9, 3.446135022681395*^9, 
  3.446138473193515*^9, 3.447631110412198*^9, 3.447682849221881*^9, 
  3.4476933809023542`*^9, 3.4476941434742393`*^9, 3.447949687599078*^9, 
  3.4479504211560783`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "4"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[-1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4323171293621063`*^9, 3.433091466716498*^9, 
  3.433176778788772*^9, 3.433180153874913*^9, 3.433245737906657*^9, 
  3.433458051283168*^9, 3.445965699186565*^9, 3.446135022681395*^9, 
  3.446138473193515*^9, 3.447631110412198*^9, 3.447682849221881*^9, 
  3.4476933809023542`*^9, 3.4476941434742393`*^9, 3.447949687599078*^9, 
  3.447950421211583*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The pulse along the x-axis does not affect IxSx, but IySy is converted to \
-IzSy and -IzSz is converted to -IySz.\
\>", "Text",
 CellChangeTimes->{{3.432317147997126*^9, 3.432317208683776*^9}, 
   3.4476943915359983`*^9, {3.447950696377075*^9, 3.4479507009423313`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time evolution", "Subsection",
 CellChangeTimes->{{3.432317299048023*^9, 3.4323173023690567`*^9}}],

Cell["\<\
The time evolution in a stationary magnetic field is calculated using the \
Hamiltonian operator, which is represented in matrix form as:\
\>", "Text",
 CellChangeTimes->{{3.432317394599134*^9, 3.432317431253725*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H", "[", 
  RowBox[{"t", ",", "nuI", ",", " ", "nuS", ",", " ", "J"}], "]"}]], "Input",
 CellChangeTimes->{{3.432317436241519*^9, 3.432317475682658*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["J", "2"]}], "+", "nuI", "+", "nuS"}], ")"}], " ", 
        "\[Pi]", " ", "t"}]], "0", "0", "0"},
     {"0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["J", "2"], "+", "nuI", "-", "nuS"}], ")"}], " ", 
        "\[Pi]", " ", "t"}]], "0", "0"},
     {"0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["J", "2"], "-", "nuI", "+", "nuS"}], ")"}], " ", 
        "\[Pi]", " ", "t"}]], "0"},
     {"0", "0", "0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["J", "2"]}], "-", "nuI", "-", "nuS"}], ")"}], " ", 
        "\[Pi]", " ", "t"}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.432317458734312*^9, 3.432317477105295*^9}, 
   3.433091466770154*^9, 3.433176778889182*^9, 3.4332457379568872`*^9, 
   3.433458051333866*^9, 3.445965699418857*^9, 3.4476311469242287`*^9, 
   3.447682849371386*^9, 3.447693381004971*^9, 3.447694143590125*^9, 
   3.4479496876956367`*^9, 3.4479507120883703`*^9}]
}, Open  ]],

Cell["\<\
where, nuI and nuS are the Larmor frequencies of the two spins in the absence \
of scalar coupling, and J is the coupling constant.  In this representation, \
the energies of the four states are specified by the frequencies and the \
coupling constant. The general form of the time-dependent wavefunction is:\
\>", "Text",
 CellChangeTimes->{{3.432317480147562*^9, 3.432317516043261*^9}, {
   3.4323175588096933`*^9, 3.432317583225699*^9}, {3.432317860915257*^9, 
   3.432317896857624*^9}, 3.4476944024515123`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}], ".", 
  "psiGen"}]], "Input",
 CellChangeTimes->{{3.4323175861931458`*^9, 3.43231759687396*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"caa", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["J", "2"]}], "+", "nuI", "+", "nuS"}], ")"}], " ", 
      "\[Pi]", " ", "t"}]]}], ",", 
   RowBox[{"cab", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["J", "2"], "+", "nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", 
      " ", "t"}]]}], ",", 
   RowBox[{"cba", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["J", "2"], "-", "nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", 
      " ", "t"}]]}], ",", 
   RowBox[{"cbb", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["J", "2"]}], "-", "nuI", "-", "nuS"}], ")"}], " ", 
      "\[Pi]", " ", "t"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4323175980477467`*^9, 3.433091466836028*^9, 
  3.43317677893521*^9, 3.433245738006365*^9, 3.433458051384754*^9, 
  3.445965699500485*^9, 3.447631266879817*^9, 3.447682849519423*^9, 
  3.447693381181665*^9, 3.447694143671508*^9, 3.4479496878097763`*^9, 
  3.4479507167970057`*^9}]
}, Open  ]],

Cell["\<\
where caa, cab, cba and cbb are the initial values of the complex \
coefficients.  The calculation is incorporated into a function, psiTime, for \
which only the wavefunction and time are explicitly specified:\
\>", "Text",
 CellChangeTimes->{{3.43231760577665*^9, 3.4323177023664103`*^9}, {
   3.432317772332109*^9, 3.432317787820366*^9}, {3.432317852976885*^9, 
   3.432317855458791*^9}, 3.447694411751931*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiTime", "[", 
  RowBox[{"psiGen", ",", " ", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.432317705521991*^9, 3.432317747570594*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"caa", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["J", "2"]}], "+", "nuI", "+", "nuS"}], ")"}], " ", 
      "\[Pi]", " ", "t"}]]}], ",", 
   RowBox[{"cab", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["J", "2"], "+", "nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", 
      " ", "t"}]]}], ",", 
   RowBox[{"cba", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["J", "2"], "-", "nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", 
      " ", "t"}]]}], ",", 
   RowBox[{"cbb", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["J", "2"]}], "-", "nuI", "-", "nuS"}], ")"}], " ", 
      "\[Pi]", " ", "t"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.432317726732441*^9, 3.4323177492126713`*^9}, 
   3.4330914669028473`*^9, 3.4331767789839993`*^9, 3.4332457381727552`*^9, 
   3.433458051433235*^9, 3.445965699584305*^9, 3.447631299088298*^9, 
   3.44768284965337*^9, 3.4476933812539253`*^9, 3.447694143740959*^9, 
   3.4479496880946608`*^9, 3.4479507260501003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evolution of observable magnetization.", "Subsubsection",
 CellChangeTimes->{{3.4323248482354107`*^9, 3.4323248593077106`*^9}}],

Cell["Starting with psiA:", "Text",
 CellChangeTimes->{{3.4323178094717503`*^9, 3.432317814483387*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiTime", "[", 
  RowBox[{"psiA", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.4323178185916862`*^9, 3.432317826668605*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["J", "2"]}], "+", "nuI", "+", "nuS"}], ")"}], " ", 
      "\[Pi]", " ", "t"}]], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["J", "2"], "+", "nuI", "-", "nuS"}], ")"}], " ", "\[Pi]",
        " ", "t"}]]}], 
    SqrtBox["2"]], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.432317827660302*^9, 3.4330914669699593`*^9, 
  3.433176779034391*^9, 3.43324573827317*^9, 3.43345805153302*^9, 
  3.4457014551860867`*^9, 3.445701719918501*^9, 3.445965699667239*^9, 
  3.447631303243368*^9, 3.447682849720066*^9, 3.4476933813551073`*^9, 
  3.447694143807767*^9, 3.447949688162396*^9, 3.4479507304076443`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["J", "2"]}], "+", "nuI", "+", "nuS"}], ")"}], " ", 
       "\[Pi]", " ", "t"}]], 
     SqrtBox["2"]], ",", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["J", "2"], "+", "nuI", "-", "nuS"}], ")"}], " ", 
        "\[Pi]", " ", "t"}]]}], 
     SqrtBox["2"]], ",", "0", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.432317900315695*^9, 3.43231791165779*^9}, 
   3.445701774782606*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Ix> = ", 0, "     ", "<Sx> = ", Rational[-1, 2] 
   Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.432317912972106*^9, 3.433091467134281*^9, 3.433176779130333*^9, 
   3.433180166955024*^9, 3.433245738470334*^9, 3.433458051748498*^9, {
   3.445701705679833*^9, 3.445701723131572*^9}, 3.445701776995916*^9, 
   3.445965699771018*^9, 3.447631353987484*^9, 3.447682849849957*^9, 
   3.447693381464423*^9, 3.447694143889496*^9, 3.447949688299919*^9, 
   3.447950733986418*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Iy> = ", 0, "     ", "<Sy> = ", Rational[1, 2] 
   Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.432317912972106*^9, 3.433091467134281*^9, 3.433176779130333*^9, 
   3.433180166955024*^9, 3.433245738470334*^9, 3.433458051748498*^9, {
   3.445701705679833*^9, 3.445701723131572*^9}, 3.445701776995916*^9, 
   3.445965699771018*^9, 3.447631353987484*^9, 3.447682849849957*^9, 
   3.447693381464423*^9, 3.447694143889496*^9, 3.447949688299919*^9, 
   3.4479507340370827`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.432317912972106*^9, 3.433091467134281*^9, 3.433176779130333*^9, 
   3.433180166955024*^9, 3.433245738470334*^9, 3.433458051748498*^9, {
   3.445701705679833*^9, 3.445701723131572*^9}, 3.445701776995916*^9, 
   3.445965699771018*^9, 3.447631353987484*^9, 3.447682849849957*^9, 
   3.447693381464423*^9, 3.447694143889496*^9, 3.447949688299919*^9, 
   3.44795073410753*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Since Sin(-x) = -Sin(x), the expression for <Sx> can be rewritten as:  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "nuS"}], "-", "J"}], ")"}], " ", "\[Pi]", " ", "t"}],
     "]"}]}]],
  CellChangeTimes->{3.432317912972106*^9}],
 "\nSince Cos(-x) = Cos(x), the expression for <Sy> can be rewritten as: ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "nuS"}], "-", "J"}], ")"}], " ", "\[Pi]", " ", "t"}],
     "]"}]}]],
  CellChangeTimes->{3.432317913046254*^9}],
 "\nThe magnetization precesses with frequency nuS-J/2."
}], "Text",
 CellChangeTimes->{{3.432317942837185*^9, 3.432317978303092*^9}, {
   3.432323815501911*^9, 3.43232399320297*^9}, {3.445701820021962*^9, 
   3.445701839345402*^9}, 3.4476314813828773`*^9, 3.447694415944765*^9}],

Cell["Starting with psiB:, where <Iy> = 1/2 and <Sz> = -1/2", "Text",
 CellChangeTimes->{{3.43232423070398*^9, 3.432324237843897*^9}, {
  3.4323243681822157`*^9, 3.432324397695464*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{"psiB", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4323242470135927`*^9, 3.4323242945928307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Ix> = ", 0, "     ", "<Sx> = ", Rational[1, 2] 
   Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.4323242884465237`*^9, 3.4323242963244047`*^9}, 
   3.433091467238509*^9, 3.4331767792350483`*^9, 3.4331801771513853`*^9, 
   3.4332457386033792`*^9, 3.433458051965774*^9, 3.445702029221982*^9, 
   3.445705151607147*^9, 3.4459656999523697`*^9, 3.447631491366427*^9, 
   3.447682849991918*^9, 3.447693381731845*^9, 3.447694144132894*^9, 
   3.447949688416068*^9, 3.447950751444816*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Iy> = ", 0, "     ", "<Sy> = ", Rational[1, 2] 
   Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.4323242884465237`*^9, 3.4323242963244047`*^9}, 
   3.433091467238509*^9, 3.4331767792350483`*^9, 3.4331801771513853`*^9, 
   3.4332457386033792`*^9, 3.433458051965774*^9, 3.445702029221982*^9, 
   3.445705151607147*^9, 3.4459656999523697`*^9, 3.447631491366427*^9, 
   3.447682849991918*^9, 3.447693381731845*^9, 3.447694144132894*^9, 
   3.447949688416068*^9, 3.447950751493711*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.4323242884465237`*^9, 3.4323242963244047`*^9}, 
   3.433091467238509*^9, 3.4331767792350483`*^9, 3.4331801771513853`*^9, 
   3.4332457386033792`*^9, 3.433458051965774*^9, 3.445702029221982*^9, 
   3.445705151607147*^9, 3.4459656999523697`*^9, 3.447631491366427*^9, 
   3.447682849991918*^9, 3.447693381731845*^9, 3.447694144132894*^9, 
   3.447949688416068*^9, 3.4479507515618687`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The result is the same as for psiA, except that the frequency is now nuS + \
J/2.\
\>", "Text",
 CellChangeTimes->{{3.432324306764237*^9, 3.4323243479448643`*^9}, {
  3.445705157242395*^9, 3.445705157746636*^9}}],

Cell["\<\
Starting with psiC, where <Iy>=1/2 and <Sy>=12, and there is no  net \
z-magnetization for either spin:\
\>", "Text",
 CellChangeTimes->{{3.432324415540389*^9, 3.432324474469301*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{"psiC", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.432324479159955*^9, 3.4323244957103033`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}]}], 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Ix> = ", (Rational[1, 2] Cos[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t], "     ", 
   "<Sx> = ", (Rational[1, 2] Cos[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.432324497682077*^9, 3.433091467478497*^9, 
  3.433176779500005*^9, 3.433180181947897*^9, 3.433245738844098*^9, 
  3.43345805220033*^9, 3.445705168273739*^9, 3.445705230098001*^9, 
  3.445965700382059*^9, 3.447631506259832*^9, 3.447682850519397*^9, 
  3.447693382113941*^9, 3.4476941447625103`*^9, 3.447949688812138*^9, 
  3.447950757196004*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "-", 
          RowBox[{"2", " ", "nuI"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}],
       "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "+", 
          RowBox[{"2", " ", "nuI"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "-", 
          RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}],
       "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "+", 
          RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}]}],
  SequenceForm[
  "<Iy> = ", 
   Rational[1, 4] (
    Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t] + 
    Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t]), 
   "     ", "<Sy> = ", 
   Rational[1, 4] (
    Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t] + 
    Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t])],
  Editable->False]], "Print",
 CellChangeTimes->{3.432324497682077*^9, 3.433091467478497*^9, 
  3.433176779500005*^9, 3.433180181947897*^9, 3.433245738844098*^9, 
  3.43345805220033*^9, 3.445705168273739*^9, 3.445705230098001*^9, 
  3.445965700382059*^9, 3.447631506259832*^9, 3.447682850519397*^9, 
  3.447693382113941*^9, 3.4476941447625103`*^9, 3.447949688812138*^9, 
  3.447950757442765*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.432324497682077*^9, 3.433091467478497*^9, 
  3.433176779500005*^9, 3.433180181947897*^9, 3.433245738844098*^9, 
  3.43345805220033*^9, 3.445705168273739*^9, 3.445705230098001*^9, 
  3.445965700382059*^9, 3.447631506259832*^9, 3.447682850519397*^9, 
  3.447693382113941*^9, 3.4476941447625103`*^9, 3.447949688812138*^9, 
  3.447950757507832*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "For the Iy and Sy components, there are two frequency components for each.  \
The expressions for the Ix and Sx components are less clear, but can be \
rewritten using trigonometric identities built into the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " TrigReduce function.\nFor Ix:"
}], "Text",
 CellChangeTimes->{{3.432324564588501*^9, 3.432324687047867*^9}, {
  3.432324875659107*^9, 3.432324876370331*^9}, {3.44620340919629*^9, 
  3.446203415131036*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.43232467670962*^9, 3.432324699900543*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
       RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}]}], "]"}]}], "+", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
      RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.432324700846466*^9, 3.433091467937446*^9, 
  3.4331767798015423`*^9, 3.433245739058827*^9, 3.433458052454198*^9, 
  3.4459657008891983`*^9, 3.447682850956028*^9, 3.447693382621286*^9, 
  3.4476941452454567`*^9, 3.447949689347217*^9, 3.4479507732661743`*^9}]
}, Open  ]],

Cell["For Sx:", "Text",
 CellChangeTimes->{{3.4323247089264174`*^9, 3.432324714254405*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.432324717503579*^9, 3.432324733680525*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], "+", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.4323247353308372`*^9, 3.433091467990426*^9, 
  3.433176779855006*^9, 3.4332457391760283`*^9, 3.433458052505577*^9, 
  3.4459657009715443`*^9, 3.447682851088821*^9, 3.447693382706357*^9, 
  3.447694145326277*^9, 3.447949689417027*^9, 3.4479507777086163`*^9}]
}, Open  ]],

Cell["\<\
Each spin gives rise to two frequencies, separated by the coupling constant \
J, even though there is only a single wavefunction.\
\>", "Text",
 CellChangeTimes->{{3.432324753018615*^9, 3.432324819187508*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evolution of correlations", "Subsubsection",
 CellChangeTimes->{{3.433092248110744*^9, 3.4330922530571117`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["psiA"], "Input",
 CellChangeTimes->{{3.4330922934225273`*^9, 3.4330922945152397`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["2"]], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.433092296216489*^9, 3.433176779905068*^9, 
  3.433245739229025*^9, 3.433458052554199*^9, 3.4457052780165033`*^9, 
  3.4459657010535192`*^9, 3.4461393524573174`*^9, 3.447631718936564*^9, 
  3.4476828512216463`*^9, 3.447693382787578*^9, 3.447694145408123*^9, 
  3.447949689564719*^9, 3.447950782567853*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psiTime", "[", 
  RowBox[{"psiA", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.433092302487957*^9, 3.433092309655661*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["J", "2"]}], "+", "nuI", "+", "nuS"}], ")"}], " ", 
      "\[Pi]", " ", "t"}]], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["J", "2"], "+", "nuI", "-", "nuS"}], ")"}], " ", "\[Pi]",
        " ", "t"}]]}], 
    SqrtBox["2"]], ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.433092311233745*^9, 3.433176779956277*^9, 
  3.433245739277872*^9, 3.433458052605915*^9, 3.445705282438575*^9, 
  3.445965701137865*^9, 3.446139354895193*^9, 3.447631723875251*^9, 
  3.447682851473754*^9, 3.4476933828555317`*^9, 3.447694145629743*^9, 
  3.447949689698453*^9, 3.4479507860925922`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{"psiA", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.433092572295081*^9, 3.4330925892022867`*^9}, 
   3.4458724883102503`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433092590513399*^9, 3.433176780005652*^9, 
  3.433245739328328*^9, 3.4334580526549892`*^9, 3.445705285681814*^9, 
  3.445965701223545*^9, 3.446139357032321*^9, 3.44763172811406*^9, 
  3.4476828515466013`*^9, 3.447693382939546*^9, 3.44769414570991*^9, 
  3.447949689835371*^9, 3.44795078895161*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433092590513399*^9, 3.433176780005652*^9, 
  3.433245739328328*^9, 3.4334580526549892`*^9, 3.445705285681814*^9, 
  3.445965701223545*^9, 3.446139357032321*^9, 3.44763172811406*^9, 
  3.4476828515466013`*^9, 3.447693382939546*^9, 3.44769414570991*^9, 
  3.447949689835371*^9, 3.447950788966145*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", Rational[-1, 4] 
   Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSy> = ", Rational[1, 4] 
   Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433092590513399*^9, 3.433176780005652*^9, 
  3.433245739328328*^9, 3.4334580526549892`*^9, 3.445705285681814*^9, 
  3.445965701223545*^9, 3.446139357032321*^9, 3.44763172811406*^9, 
  3.4476828515466013`*^9, 3.447693382939546*^9, 3.44769414570991*^9, 
  3.447949689835371*^9, 3.44795078904228*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
To simplify the expressions for the correlations that evolve from psiC, nuI \
and nuS are both set to 0.\
\>", "Text",
 CellChangeTimes->{{3.447632049332055*^9, 3.447632098492535*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{
   RowBox[{"psiTime", "[", 
    RowBox[{"psiC", ",", "t"}], "]"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nuI", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"nuS", "\[Rule]", " ", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.433093109119432*^9, 3.433093120296373*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330931217000713`*^9, 3.433176780965537*^9, 
  3.4332457401800823`*^9, 3.433458053567608*^9, 3.445706140246356*^9, 
  3.4459657030083303`*^9, 3.446139368242597*^9, 3.447632196919232*^9, 
  3.4476828516441307`*^9, 3.4476933830387983`*^9, 3.447694145916615*^9, 
  3.447949690002274*^9, 3.447950797168722*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}]}], 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Iy> = ", Rational[1, 2] Cos[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t], 
   "     ", "<Sy> = ", Rational[1, 2] 
   Cos[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330931217000713`*^9, 3.433176780965537*^9, 
  3.4332457401800823`*^9, 3.433458053567608*^9, 3.445706140246356*^9, 
  3.4459657030083303`*^9, 3.446139368242597*^9, 3.447632196919232*^9, 
  3.4476828516441307`*^9, 3.4476933830387983`*^9, 3.447694145916615*^9, 
  3.447949690002274*^9, 3.447950797183235*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330931217000713`*^9, 3.433176780965537*^9, 
  3.4332457401800823`*^9, 3.433458053567608*^9, 3.445706140246356*^9, 
  3.4459657030083303`*^9, 3.446139368242597*^9, 3.447632196919232*^9, 
  3.4476828516441307`*^9, 3.4476933830387983`*^9, 3.447694145916615*^9, 
  3.447949690002274*^9, 3.447950797198502*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{
   RowBox[{"psiTime", "[", 
    RowBox[{"psiC", ",", "t"}], "]"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nuI", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"nuS", "\[Rule]", " ", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.433092901181638*^9, 3.433092922907504*^9}, {
   3.433093034965043*^9, 3.433093035626245*^9}, 3.445872488360224*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 
   Rational[-1, 4] Sin[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330929245861597`*^9, 3.4330930367245207`*^9, 
  3.4331767810655537`*^9, 3.4332457402339993`*^9, 3.433458053759595*^9, 
  3.445965703103527*^9, 3.446139374930079*^9, 3.447632199931357*^9, 
  3.447682851743239*^9, 3.4476933831391287`*^9, 3.447694146063736*^9, 
  3.4479496901695747`*^9, 3.4479508002665367`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IySx> = ", 0, "     ", "<IySy> = ", 
   Rational[1, 4], "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330929245861597`*^9, 3.4330930367245207`*^9, 
  3.4331767810655537`*^9, 3.4332457402339993`*^9, 3.433458053759595*^9, 
  3.445965703103527*^9, 3.446139374930079*^9, 3.447632199931357*^9, 
  3.447682851743239*^9, 3.4476933831391287`*^9, 3.447694146063736*^9, 
  3.4479496901695747`*^9, 3.447950800281436*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}]}], 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", Rational[-1, 4] Sin[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSy> = ", 0, "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4330929245861597`*^9, 3.4330930367245207`*^9, 
  3.4331767810655537`*^9, 3.4332457402339993`*^9, 3.433458053759595*^9, 
  3.445965703103527*^9, 3.446139374930079*^9, 3.447632199931357*^9, 
  3.447682851743239*^9, 3.4476933831391287`*^9, 3.447694146063736*^9, 
  3.4479496901695747`*^9, 3.447950800332464*^9}]
}, Open  ]]
}, Open  ]],

Cell["Remove the restriction that nuI=0 and nuS=0", "Text",
 CellChangeTimes->{{3.446139397373397*^9, 3.446139414935206*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{"psiC", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.446139425078404*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}]}], 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<Ix> = ", (Rational[1, 2] Cos[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t], "     ", 
   "<Sx> = ", (Rational[1, 2] Cos[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.446139426677595*^9, 3.447632203777008*^9, 
  3.447682851849348*^9, 3.447693383241864*^9, 3.447694146199849*^9, 
  3.447949690430616*^9, 3.447950807197669*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "-", 
          RowBox[{"2", " ", "nuI"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}],
       "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "+", 
          RowBox[{"2", " ", "nuI"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "-", 
          RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}],
       "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "+", 
          RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}]}],
  SequenceForm[
  "<Iy> = ", 
   Rational[1, 4] (
    Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t] + 
    Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t]), 
   "     ", "<Sy> = ", 
   Rational[1, 4] (
    Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t] + 
    Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t])],
  Editable->False]], "Print",
 CellChangeTimes->{3.446139426677595*^9, 3.447632203777008*^9, 
  3.447682851849348*^9, 3.447693383241864*^9, 3.447694146199849*^9, 
  3.447949690430616*^9, 3.447950807246253*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0, "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.446139426677595*^9, 3.447632203777008*^9, 
  3.447682851849348*^9, 3.447693383241864*^9, 3.447694146199849*^9, 
  3.447949690430616*^9, 3.4479508073134003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{"psiC", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.446139481727438*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}], 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
      "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"J", "-", 
           RowBox[{"2", " ", "nuI"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
        "]"}]}], "-", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "+", 
          RowBox[{"2", " ", "nuI"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}]}],
  SequenceForm[
  "<IxSx> = ", (Rational[1, 4] 
    Sin[((2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], "     ", "<IxSy> = ", 
   Rational[1, 8] (
    Sin[((2 (NMR`twoSpinLib`nuI - NMR`twoSpinLib`nuS)) Pi) NMR`twoSpinLib`t] + 
    Sin[((2 (NMR`twoSpinLib`nuI + NMR`twoSpinLib`nuS)) Pi) NMR`twoSpinLib`t]),
    "     ", "<IxSz> = ", 
   Rational[1, 8] (-
     Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t] - 
    Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t])],
  Editable->False]], "Print",
 CellChangeTimes->{3.4461394830474*^9, 3.447682852502707*^9, 
  3.4476933838539267`*^9, 3.4476941468091593`*^9, 3.447949691013386*^9, 
  3.447950811698948*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], 
        "]"}]}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
      "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}]}]}],
  SequenceForm[
  "<IySx> = ", 
   Rational[1, 8] (-
     Sin[((2 (NMR`twoSpinLib`nuI - NMR`twoSpinLib`nuS)) Pi) NMR`twoSpinLib`t] + 
    Sin[((2 (NMR`twoSpinLib`nuI + NMR`twoSpinLib`nuS)) Pi) NMR`twoSpinLib`t]),
    "     ", "<IySy> = ", 
   Rational[1, 8] (
    Cos[((2 (NMR`twoSpinLib`nuI - NMR`twoSpinLib`nuS)) Pi) NMR`twoSpinLib`t] + 
    Cos[((2 (NMR`twoSpinLib`nuI + NMR`twoSpinLib`nuS)) Pi) NMR`twoSpinLib`t]),
    "     ", 
   "<IySz> = ", (Rational[1, 4] Sin[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuI) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4461394830474*^9, 3.447682852502707*^9, 
  3.4476933838539267`*^9, 3.4476941468091593`*^9, 3.447949691013386*^9, 
  3.447950812147685*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"J", "-", 
           RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
        "]"}]}], "-", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"J", "+", 
          RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}], 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", 
   Rational[1, 8] (-
     Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t] - 
    Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]), 
   "     ", "<IzSy> = ", (Rational[1, 4] 
    Sin[(NMR`twoSpinLib`J Pi) NMR`twoSpinLib`t]) 
   Sin[((2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.4461394830474*^9, 3.447682852502707*^9, 
  3.4476933838539267`*^9, 3.4476941468091593`*^9, 3.447949691013386*^9, 
  3.447950812443707*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The evolution of the IxSz, IySz, IzSx and IzSy correlations are accounted for \
by the complementary evolution of the observable transverse magnetization \
components.\
\>", "Text"],

Cell[TextData[{
 "For each of the transverse correlations (IxSx, IxSy, IySx and IySy), the \
average value can be represented as the product of the projections of two \
precessing vectors onto the corresponding axes.  In some cases, though, the \
expressions returned by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " must be re-written:"
}], "Text",
 CellChangeTimes->{{3.446203477646093*^9, 3.446203580141562*^9}, {
   3.446203627885186*^9, 3.446203628340674*^9}, {3.4462038306776237`*^9, 
   3.446203958724022*^9}, 3.44622079260236*^9, {3.44763224777761*^9, 
   3.447632294902635*^9}}],

Cell["For IxSx", "Text",
 CellChangeTimes->{{3.446204723714258*^9, 3.4462047265810738`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<<IxSx> = \>\"", "\[InvisibleSpace]", 
  FractionBox["1", "4"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "\<\"<IxSx> = \"\>", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447682853625639*^9, 3.447693384873993*^9, 
  3.447694147982232*^9, 3.4479496920007343`*^9, 3.4479508204303923`*^9}]
}, Open  ]],

Cell["For IxSy", "Text",
 CellChangeTimes->{{3.4462047333188868`*^9, 3.446204736444869*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<<IxSy> = \>\"", "\[InvisibleSpace]", 
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{3.446204034894712*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "\<\"<IxSy> = \"\>", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447682853759203*^9, 3.447693384990755*^9, 
  3.447694148046818*^9, 3.4479496921346483`*^9}]
}, Open  ]],

Cell["This can be rearranged using trigonometric identities", "Text",
 CellChangeTimes->{{3.446204751373351*^9, 3.446204771803845*^9}, 
   3.4476944275587397`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigFactor", "[", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
     "+", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.446204066893886*^9, 3.4462040843225203`*^9}, {
  3.4462041503808813`*^9, 3.4462041513439693`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}]}], "]"}], 
  " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}]}], 
   "]"}]}]], "Output",
 CellChangeTimes->{{3.446204138412785*^9, 3.446204152257659*^9}, 
   3.4476828541428022`*^9, 3.4476933851075163`*^9, 3.4476941481147633`*^9, 
   3.44794969233571*^9}]
}, Open  ]],

Cell["Simplifying the arguments of the cosine and sine functions", "Text",
 CellChangeTimes->{{3.4462048106316967`*^9, 3.446204826498273*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.446204187473837*^9, 3.4462041972908373`*^9}, {
  3.446204837492674*^9, 3.446204837555973*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447682854229006*^9, 3.4476933851757393`*^9, 
  3.447694148179884*^9, 3.447949692452446*^9}]
}, Open  ]],

Cell["For IySx, simplify as above", "Text",
 CellChangeTimes->{{3.446204842806896*^9, 3.446204876720891*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<<IySx> = \>\"", "\[InvisibleSpace]", 
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}], "\[InvisibleSpace]"}]], "Input",
 CellChangeTimes->{{3.446204104276737*^9, 3.446204135073214*^9}, {
  3.4462042499624987`*^9, 3.446204255216185*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "\<\"<IySx> = \"\>", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447682854295541*^9, 3.447693385242551*^9, 
  3.44769414824704*^9, 3.447949692523444*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[InvisibleSpace]", 
  RowBox[{"TrigFactor", "[", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], 
        "]"}]}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], 
       "]"}]}], ")"}]}], "\[InvisibleSpace]", "]"}]}]], "Input",
 CellChangeTimes->{{3.446204268588889*^9, 3.44620427461273*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}]}], "]"}], 
  " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}]}], 
   "]"}]}]], "Output",
 CellChangeTimes->{3.446204276753269*^9, 3.447682854364644*^9, 
  3.447693385309731*^9, 3.4476941483145514`*^9, 3.447949692590027*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.446204295385022*^9, 3.446204310127858*^9}, {
  3.4462048880471163`*^9, 3.4462048881250134`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447682854530376*^9, 3.447693385376596*^9, 
  3.447694148398077*^9, 3.447949692656111*^9}]
}, Open  ]],

Cell["For IySy", "Text",
 CellChangeTimes->{{3.446204900035458*^9, 3.4462049257275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[InvisibleSpace]", 
  RowBox[{"\"\<<IySy> = \>\"", "\[InvisibleSpace]", 
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
     "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "\<\"<IySy> = \"\>", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447682854595924*^9, 3.447693385443492*^9, 
  3.447694148465333*^9, 3.447949692723078*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigFactor", "[", "\[InvisibleSpace]", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
     "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4462044201873693`*^9, 3.4462044307685757`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}]}], "]"}], 
  " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}]}], 
   "]"}]}]], "Output",
 CellChangeTimes->{3.4462044321479197`*^9, 3.447682854673107*^9, 
  3.44769338551071*^9, 3.4476941485312223`*^9, 3.447949692789977*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.446204446602252*^9, 3.44620445534886*^9}, {
  3.446204931955885*^9, 3.446204932017387*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447682854729574*^9, 3.447693385576996*^9, 
  3.447694148597612*^9, 3.447949692969981*^9}]
}, Open  ]],

Cell["\<\

Each of the expressions for time evolution of correlations can also be \
written as sums of trigonometric functions
For IxSx\
\>", "Text",
 CellChangeTimes->{{3.4462122321119223`*^9, 3.446212275902631*^9}, {
   3.447632338510734*^9, 3.44763235107078*^9}, 3.4476325664069223`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<<IxSx> = \>\"", "\[InvisibleSpace]", 
  FractionBox["1", "4"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "\<\"<IxSx> = \"\>", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447682854797044*^9, 3.447693385692133*^9, 
  3.4476941486649113`*^9, 3.447949693042943*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.44621228987514*^9, 3.446212329183651*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "-", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}], "-", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "nuI", " ", "\[Pi]", " ", "t"}], "+", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.4462123078503647`*^9, 3.446212329978262*^9}, 
   3.447682854865601*^9, 3.447693385925117*^9, 3.4476941487323236`*^9, 
   3.447949693173571*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "-", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.446212398781735*^9, 3.446212409400539*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "-", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447682854929768*^9, 3.4476933859952517`*^9, 
  3.447694148814107*^9, 3.447949693313643*^9}]
}, Open  ]],

Cell["For IxSy", "Text",
 CellChangeTimes->{{3.446212419656424*^9, 3.446212440337982*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<<IxSy> = \>\"", "\[InvisibleSpace]", 
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "\<\"<IxSy> = \"\>", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447682854996051*^9, 3.4476933861091537`*^9, 
  3.447694148882392*^9, 3.4479496933910627`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"For", " ", "IySx"}], "\[IndentingNewLine]"}], "Text"]], "Input",
 CellChangeTimes->{{3.446212493946698*^9, 3.446212510481908*^9}, 
   3.447632681524778*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "For"}], "4"]}]},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "For"}], "4"]}], "0"},
     {"0", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "For"}], "4"], "0", "0"},
     {
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "For"}], "4"], "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.44768285506459*^9, 3.4476933862267647`*^9, 
  3.447694149034811*^9, 3.447949693524581*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<<IySx> = \>\"", "\[InvisibleSpace]", 
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}], "\[InvisibleSpace]"}]], "Input",
 CellChangeTimes->{3.447632692875516*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "\<\"<IySx> = \"\>", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.4476828551300983`*^9, 3.447693386294929*^9, 
  3.447694149118684*^9, 3.447949693591325*^9}]
}, Open  ]],

Cell["For IySy", "Text",
 CellChangeTimes->{{3.446203969647636*^9, 3.446203991633754*^9}, {
  3.446212559097699*^9, 3.4462125627344503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[InvisibleSpace]", 
  RowBox[{"\"\<<IySy> = \>\"", "\[InvisibleSpace]", 
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
     "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
     ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "\<\"<IySy> = \"\>", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "-", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"nuI", "+", "nuS"}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.447682855197444*^9, 3.447693386361397*^9, 
  3.4476941491821127`*^9, 3.447949693657956*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Populations of with multiple wavefunctions", "Section",
 CellChangeTimes->{{3.433093834521597*^9, 3.433093854278276*^9}}],

Cell[CellGroupData[{

Cell["Equilibrium", "Subsection",
 CellChangeTimes->{{3.433093897738579*^9, 3.433093905339196*^9}}],

Cell["\<\
The relative populations of two states at thermal equilibrium are give by the \
Boltzmann equation:

Na/Nb = Exp[-(Ea-Eb)/(k T)]

When the absolute value of deltaE << k T, this can be approximated as:

Na/Nb = 1-(Ea-Eb)/(k T)

Making the simplifying assumptions that:
1. The only states present for the coupled two-spin system are psiAA, psiAB, \
psiBA and psiBB
2. The energy associated with the scalar coupling constant, J, does not \
significantly affect the populations

If the energy differences for the two transitions are deltaEI and deltaES, \
then the energies of the individual states are written as:

Eaa = -(deltaEI+deltaES)/2
Eab = -(deltaEI-deltaES)/2
Eba = (deltaEI-deltaES)/2
Ebb = (deltaEI+deltaES)/2

The fraction of molecules in each state is:

N/Nt = Exp[-E/(k T)]/Sum[Exp(-E/(k T)]
where the sum in the denominator is over all of the states.  For small \
energies relative to k T

N/Nt = (1 - E/(k T))/Sum[1-E/(k T)]

Sum[1-E/(k T)] = (1 + (deltaEI+deltaES)/2) + (1 + (deltaEI-deltaES)/2)) + (1 \
- (deltaEI-deltaES)/2) + (1 -  (deltaEI+deltaES)/2) = 4

Naa/Nt = (1 + (deltaEI+deltaES)/(2 k T))/4
Nab/Nt = (1 + (deltaEI-deltaES)/(2 k T))/4
Nba/Nt = (1 + (deltaEI-deltaES)/(2 k T))/4
Nbb/Nt = (1 + (deltaEI+deltaES)/(2 k T))/4

Define population differences as:

deltaPI = deltaEI/(2 k T)
deltaPS = deltaES/2 k T)

Then, the fractional populations are given by:

faa = Naa/Nt = 1/4(1 + deltaPI + deltaPS)
fab = Naa/Nt = 1/4(1 + deltaPI - deltaPS)
fba = Nba/Nt = 1/4(1 - deltaPI + deltaPS)
fbb = Nbb/Nt = 1/4(1 - deltaPI - deltaPS)\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJwLyk9STGVgYGACYmEQ7fhyinTyXh0lEJ2xeHUbiC7a86AJRFcvuGsFopv3
8BmB6FkLmTtA9Pwtga9A9DKtgFYQvVrBaB6IXl9pegRE77zWUQOib4qpsQNp
m/kX/W6D6H2JL1tA9OE/Z/VA9OkPx0D6bC7JNawB0V/tFUHitmqasj4g2mmf
iTGI9uBJnAWiY4qOzwbRCYeuSIDorE8R/0B0gbWiMogu5v//HkSXy540A9Ez
J8qD5J27nW6zgeipk269A9Ezo95uBNFb5zW5gugL/q8PgOhrGTNMHV+uv1bb
zbUGRDfNe9kFpL/0dCuvB9M3FLkAXlKb/g==
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"faa", "=", 
  RowBox[{
   RowBox[{"1", "/", "4"}], 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.4331768120905333`*^9, 3.4331768238473787`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]], "Output",
 CellChangeTimes->{3.4331768280265007`*^9, 3.433245740277026*^9, 
  3.433458053810835*^9, 3.445712303493607*^9, 3.445774699938233*^9, 
  3.445965703186145*^9, 3.4476329937505083`*^9, 3.447682855313366*^9, 
  3.447693386428001*^9, 3.4476941492484503`*^9, 3.447949693749009*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fab", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "4"}], 
   RowBox[{"(", 
    RowBox[{"1", " ", "+", " ", "deltaPI", " ", "-", " ", "deltaPS"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.4331768379109087`*^9, 3.433176839517404*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}]}]], "Output",
 CellChangeTimes->{3.4331768411017933`*^9, 3.433245740380678*^9, 
  3.433458053861573*^9, 3.445712305431861*^9, 3.44577470344664*^9, 
  3.445965703252076*^9, 3.4476329967943068`*^9, 3.4476828554311047`*^9, 
  3.447693386494714*^9, 3.447694149320006*^9, 3.4479496938254223`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fba", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "4"}], 
   RowBox[{"(", 
    RowBox[{"1", " ", "-", " ", "deltaPI", " ", "+", " ", "deltaPS"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.4331768495795193`*^9, 3.433176851170431*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}]}]], "Output",
 CellChangeTimes->{3.433176852887536*^9, 3.4332457404657373`*^9, 
  3.433458053912217*^9, 3.445712307270327*^9, 3.445774706569663*^9, 
  3.445965703319824*^9, 3.4476329995925713`*^9, 3.447682855649074*^9, 
  3.4476933865626593`*^9, 3.44769414939962*^9, 3.4479496940056133`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fbb", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "4"}], 
   RowBox[{"(", 
    RowBox[{"1", " ", "-", " ", "deltaPI", " ", "-", " ", "deltaPS"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.433176861415922*^9, 3.433176863441306*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}]}]], "Output",
 CellChangeTimes->{3.433176866147826*^9, 3.433245740516515*^9, 
  3.433458053961671*^9, 3.445712309891551*^9, 3.445774711110732*^9, 
  3.4459657034347887`*^9, 3.4476330023532953`*^9, 3.4476828557162743`*^9, 
  3.447693386676807*^9, 3.447694149465714*^9, 3.4479496940751038`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"faa", "+", "fab", "+", "fba", "+", "fbb"}]], "Input",
 CellChangeTimes->{{3.433176885609417*^9, 3.433176893693572*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.433245740565319*^9, 3.4334580540122232`*^9, 
  3.445712313130939*^9, 3.445774714586957*^9, 3.44596570363446*^9, 
  3.447633007610924*^9, 3.4476828557835207`*^9, 3.447693386794458*^9, 
  3.4476941495347147`*^9, 3.44794969414124*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433176907357481*^9, 3.433176907486145*^9}, {
  3.445712317549439*^9, 3.445712321858779*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.433458054062549*^9, 3.4457123230683393`*^9, 
  3.445774717167588*^9, 3.445965703768708*^9, 3.447633010254842*^9, 
  3.447682855848062*^9, 3.447693387111916*^9, 3.447694149664764*^9, 
  3.447949694257516*^9}]
}, Open  ]],

Cell["Calculate the average Iz magnetization at equilibrium:", "Text",
 CellChangeTimes->{{3.433177425848772*^9, 3.4331774403669043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "+", " ", 
  RowBox[{"fab", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "-", " ", 
  RowBox[{"fba", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "-", " ", 
  RowBox[{"fbb", " ", 
   RowBox[{"1", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4331774475245113`*^9, 3.4331774966562033`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.433177498181163*^9, 3.433245740616802*^9, 
  3.433458054179142*^9, 3.445712328279661*^9, 3.445774721733715*^9, 
  3.445965703903041*^9, 3.447633032424367*^9, 3.447682855982954*^9, 
  3.447693387180479*^9, 3.447694149798913*^9, 3.447949694375071*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433177506807953*^9, 3.433177511349378*^9}}],

Cell[BoxData[
 FractionBox["deltaPI", "2"]], "Output",
 CellChangeTimes->{3.433177513012454*^9, 3.433245740667055*^9, 
  3.4334580542791853`*^9, 3.445712331035139*^9, 3.445774723777237*^9, 
  3.445965704137228*^9, 3.447633035534861*^9, 3.447682856098267*^9, 
  3.447693387248098*^9, 3.4476941499491577`*^9, 3.4479496944421787`*^9}]
}, Open  ]],

Cell["Average Sz magnetization at equilibrium:", "Text",
 CellChangeTimes->{{3.433177634952424*^9, 3.433177647267438*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "-", " ", 
  RowBox[{"fab", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "+", " ", 
  RowBox[{"fba", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "-", " ", 
  RowBox[{"fbb", " ", 
   RowBox[{"1", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.433177675598363*^9, 3.433177681412092*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.433177683072401*^9, 3.4332457407178297`*^9, 
  3.433458054378972*^9, 3.445712333908822*^9, 3.445774727747594*^9, 
  3.445965704203985*^9, 3.4476330604320507`*^9, 3.447682856215735*^9, 
  3.4476933873147173`*^9, 3.4476941502025003`*^9, 3.447949694508562*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433177684939828*^9, 3.433177690745685*^9}}],

Cell[BoxData[
 FractionBox["deltaPS", "2"]], "Output",
 CellChangeTimes->{3.433177692245883*^9, 3.43324574076763*^9, 
  3.433458054447063*^9, 3.445712335896015*^9, 3.4457747306197147`*^9, 
  3.445965704271162*^9, 3.4476330631579514`*^9, 3.447682856283888*^9, 
  3.447693387380106*^9, 3.44769415028449*^9, 3.447949694574473*^9}]
}, Open  ]],

Cell["Average product IzSz", "Text",
 CellChangeTimes->{{3.433177776152141*^9, 3.4331777848878393`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", " ", 
   RowBox[{"1", "/", "4"}]}], " ", "-", " ", 
  RowBox[{"fab", " ", 
   RowBox[{"1", "/", "4"}]}], " ", "-", " ", 
  RowBox[{"fba", " ", 
   RowBox[{"1", "/", "4"}]}], " ", "+", " ", 
  RowBox[{"fbb", " ", 
   RowBox[{"1", "/", "4"}]}]}]], "Input",
 CellChangeTimes->{{3.4331777883532543`*^9, 3.433177819726911*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.433177820656948*^9, 3.433245740867319*^9, 
  3.433458054513328*^9, 3.4457123404576406`*^9, 3.445774735965234*^9, 
  3.445965704338587*^9, 3.44763307362298*^9, 3.447682856400072*^9, 
  3.4476933874480343`*^9, 3.447694150351734*^9, 3.447949694641363*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433177822590601*^9, 3.43317782987125*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.433177831203611*^9, 3.4332457409675426`*^9, 
  3.433458054752846*^9, 3.445712344196371*^9, 3.445774738135273*^9, 
  3.4459657044216843`*^9, 3.4476330772716722`*^9, 3.447682856513652*^9, 
  3.447693387562437*^9, 3.447694150418293*^9, 3.447949694707711*^9}]
}, Open  ]],

Cell["\<\
Average magnetization components and products following a pi/2x pulse to the \
S-spin.  The symbols faa, fab, fba, fbb are used to represent the populations \
that began in the corresponding states but have now been changed by the \
pulse.  
\
\>", "Text",
 CellChangeTimes->{{3.433177965014483*^9, 3.4331780840962257`*^9}, {
   3.4331782964329147`*^9, 3.433178298077797*^9}, 3.4457119850319633`*^9, 
   3.445712052825657*^9, 3.4476944584784927`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiAA", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4457120567971478`*^9, 3.4457121479760523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.445712111370051*^9, 3.4457121491377277`*^9}, 
   3.445774741544454*^9, 3.445965704488987*^9, 3.447633111676725*^9, 
   3.4476828566535053`*^9, 3.447693387680719*^9, 3.447694150488771*^9, 
   3.447949694775453*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.445712111370051*^9, 3.4457121491377277`*^9}, 
   3.445774741544454*^9, 3.445965704488987*^9, 3.447633111676725*^9, 
   3.4476828566535053`*^9, 3.447693387680719*^9, 3.447694150488771*^9, 
   3.447949694786133*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.445712111370051*^9, 3.4457121491377277`*^9}, 
   3.445774741544454*^9, 3.445965704488987*^9, 3.447633111676725*^9, 
   3.4476828566535053`*^9, 3.447693387680719*^9, 3.447694150488771*^9, 
   3.447949694799358*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiAB", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.445712167674458*^9, 3.445712168111506*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.44571216908084*^9, 3.4457747464042253`*^9, 
  3.445965704589178*^9, 3.447633114639739*^9, 3.447682856737755*^9, 
  3.447693387830331*^9, 3.4476941506021423`*^9, 3.447949694875474*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.44571216908084*^9, 3.4457747464042253`*^9, 
  3.445965704589178*^9, 3.447633114639739*^9, 3.447682856737755*^9, 
  3.447693387830331*^9, 3.4476941506021423`*^9, 3.4479496948863983`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.44571216908084*^9, 3.4457747464042253`*^9, 
  3.445965704589178*^9, 3.447633114639739*^9, 3.447682856737755*^9, 
  3.447693387830331*^9, 3.4476941506021423`*^9, 3.447949694899633*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiBA", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4457121768660727`*^9, 3.44571217728726*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712180553653*^9, 3.4457747488074503`*^9, 
  3.4459657046892433`*^9, 3.447633118290474*^9, 3.44768285682126*^9, 
  3.447693388136692*^9, 3.447694150703085*^9, 3.447949695077571*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712180553653*^9, 3.4457747488074503`*^9, 
  3.4459657046892433`*^9, 3.447633118290474*^9, 3.44768285682126*^9, 
  3.447693388136692*^9, 3.447694150703085*^9, 3.447949695088263*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712180553653*^9, 3.4457747488074503`*^9, 
  3.4459657046892433`*^9, 3.447633118290474*^9, 3.44768285682126*^9, 
  3.447693388136692*^9, 3.447694150703085*^9, 3.447949695101461*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiBB", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4457121909507303`*^9, 3.4457121918547277`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0, "     ", "<Sx> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712192813301*^9, 3.445774751296186*^9, 
  3.44596570478935*^9, 3.44763312135538*^9, 3.447682856902823*^9, 
  3.447693388232662*^9, 3.447694150802806*^9, 3.44794969517846*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}],
  SequenceForm["<Iy> = ", 0, "     ", "<Sy> = ", 
   Rational[-1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712192813301*^9, 3.445774751296186*^9, 
  3.44596570478935*^9, 3.44763312135538*^9, 3.447682856902823*^9, 
  3.447693388232662*^9, 3.447694150802806*^9, 3.4479496951892567`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712192813301*^9, 3.445774751296186*^9, 
  3.44596570478935*^9, 3.44763312135538*^9, 3.447682856902823*^9, 
  3.447693388232662*^9, 3.447694150802806*^9, 3.447949695202586*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\

The average Sy magnetization\
\>", "Text",
 CellChangeTimes->{
  3.445712048487094*^9, {3.445712203573009*^9, 3.445712212084381*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", " ", 
   RowBox[{"1", "/", "2"}]}], "  ", "-", " ", 
  RowBox[{"fab", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "+", " ", 
  RowBox[{"fba", " ", 
   RowBox[{"1", "/", "2"}]}], " ", "-", 
  RowBox[{"fbb", " ", 
   RowBox[{"1", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.433178094842598*^9, 3.433178177123472*^9}, {
  3.445712226668131*^9, 3.445712261533299*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.433178143150444*^9, 3.433178178808723*^9}, 
   3.433245741068377*^9, 3.4334580547990837`*^9, 3.445712288697383*^9, 
   3.445712352798976*^9, 3.4457747556392307`*^9, 3.445965704889256*^9, 
   3.447633135737211*^9, 3.447682857034881*^9, 3.447693388398234*^9, 
   3.447694150902659*^9, 3.447949695278469*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433178145323532*^9, 3.433178151168467*^9}}],

Cell[BoxData[
 FractionBox["deltaPS", "2"]], "Output",
 CellChangeTimes->{{3.433178152039029*^9, 3.43317818179081*^9}, 
   3.43324574111856*^9, 3.4334580548279753`*^9, 3.445712291203238*^9, 
   3.445712356656363*^9, 3.445965705037611*^9, 3.4476331388480043`*^9, 
   3.4476828571336727`*^9, 3.447693388465523*^9, 3.447694150969592*^9, 
   3.4479496953443613`*^9}]
}, Open  ]],

Cell["\<\
Correlations following the pi/2 pulse to the S-spins
\
\>", "Text",
 CellChangeTimes->{{3.445712428268691*^9, 3.4457124548456306`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiAA", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4457124622655373`*^9, 3.445712492302169*^9}, 
   3.445872488436768*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712494548468*^9, 3.445774760618425*^9, 
  3.445965705340032*^9, 3.4476331654533033`*^9, 3.447682857204999*^9, 
  3.447693388533711*^9, 3.447694151285268*^9, 3.4479496954147243`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712494548468*^9, 3.445774760618425*^9, 
  3.445965705340032*^9, 3.4476331654533033`*^9, 3.447682857204999*^9, 
  3.447693388533711*^9, 3.447694151285268*^9, 3.447949695425145*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712494548468*^9, 3.445774760618425*^9, 
  3.445965705340032*^9, 3.4476331654533033`*^9, 3.447682857204999*^9, 
  3.447693388533711*^9, 3.447694151285268*^9, 3.447949695438389*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiAB", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.445712507880748*^9, 3.445712508358184*^9}, 
   3.445872488450727*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712509612311*^9, 3.4457747639917707`*^9, 
  3.445965705440277*^9, 3.447633171913972*^9, 3.4476828573369627`*^9, 
  3.447693388634337*^9, 3.447694151436163*^9, 3.447949695515679*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712509612311*^9, 3.4457747639917707`*^9, 
  3.445965705440277*^9, 3.447633171913972*^9, 3.4476828573369627`*^9, 
  3.447693388634337*^9, 3.447694151436163*^9, 3.44794969552617*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "4"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[-1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712509612311*^9, 3.4457747639917707`*^9, 
  3.445965705440277*^9, 3.447633171913972*^9, 3.4476828573369627`*^9, 
  3.447693388634337*^9, 3.447694151436163*^9, 3.447949695539421*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiBA", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.445712516896639*^9, 3.445712517293685*^9}, 
   3.445872488464604*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712518650532*^9, 3.445774766479479*^9, 
  3.445965705541226*^9, 3.4476331749771557`*^9, 3.447682857470739*^9, 
  3.447693388734466*^9, 3.447694151538555*^9, 3.447949695614423*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712518650532*^9, 3.445774766479479*^9, 
  3.445965705541226*^9, 3.4476331749771557`*^9, 3.447682857470739*^9, 
  3.447693388734466*^9, 3.447694151538555*^9, 3.447949695625072*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "4"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[-1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.445712518650532*^9, 3.445774766479479*^9, 
  3.445965705541226*^9, 3.4476331749771557`*^9, 3.447682857470739*^9, 
  3.447693388734466*^9, 3.447694151538555*^9, 3.4479496956383467`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiPi2Sx", "[", "psiBB", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4457125277682467`*^9, 3.445712528573594*^9}, 
   3.445872488477522*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.44571252976145*^9, 3.445774769369656*^9, 
  3.445965705705592*^9, 3.447633177709839*^9, 3.447682857603361*^9, 
  3.4476933888344717`*^9, 3.4476941516865*^9, 3.447949695714463*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.44571252976145*^9, 3.445774769369656*^9, 
  3.445965705705592*^9, 3.447633177709839*^9, 3.447682857603361*^9, 
  3.4476933888344717`*^9, 3.4476941516865*^9, 3.447949695725007*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "4"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<IzSx> = ", 0, "     ", "<IzSy> = ", 
   Rational[1, 4], "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.44571252976145*^9, 3.445774769369656*^9, 
  3.445965705705592*^9, 3.447633177709839*^9, 3.447682857603361*^9, 
  3.4476933888344717`*^9, 3.4476941516865*^9, 3.447949695738244*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The only non-zero correlation is IzSy.
The average IzSy correlation is calculated as:\
\>", "Text",
 CellChangeTimes->{{3.433178397536119*^9, 3.433178408566724*^9}, {
   3.445712535235861*^9, 3.445712594825779*^9}, 3.44769446046316*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", " ", 
   RowBox[{"1", "/", "4"}]}], " ", "-", " ", 
  RowBox[{"fab", " ", 
   RowBox[{"1", "/", "4"}]}], " ", "-", " ", 
  RowBox[{"fba", " ", 
   RowBox[{"1", "/", "4"}]}], " ", "+", " ", 
  RowBox[{"fbb", " ", 
   RowBox[{"1", "/", "4"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "deltaPI", "-", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "deltaPI", "+", "deltaPS"}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.433178440450404*^9, 3.4332457412168903`*^9, 
  3.4334580548836308`*^9, 3.445712603324119*^9, 3.445774777936088*^9, 
  3.445965705871998*^9, 3.447633188103196*^9, 3.447682857771235*^9, 
  3.4476933889341717`*^9, 3.447694151852152*^9, 3.447949695812641*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.43317844367689*^9, 3.433178447685199*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4331784487524443`*^9, 3.433245741253015*^9, 
  3.4334580549491987`*^9, 3.4457126060344667`*^9, 3.4457748102183523`*^9, 
  3.445965706004971*^9, 3.447633190847609*^9, 3.4476828578359833`*^9, 
  3.447693389104533*^9, 3.447694151921679*^9, 3.447949695878983*^9}]
}, Open  ]],

Cell["\<\
Time evolution following the pi/2x pulse to the S spin:
For the population that begins in the psiAA state:\
\>", "Text",
 CellChangeTimes->{{3.433178519531528*^9, 3.433178560202797*^9}, {
   3.4331786165629997`*^9, 3.433178635546619*^9}, 3.4457126132528057`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiAA", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.43317863860011*^9, 3.4331786699669123`*^9}, {
  3.44571265098145*^9, 3.445712651690243*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Ix> = ", 0, "     ", "<Sx> = ", Rational[-1, 2] 
   Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178671379373*^9, 3.433245741285935*^9, 
  3.433458055018134*^9, 3.4457126526502867`*^9, 3.445774815138644*^9, 
  3.4459657060748167`*^9, 3.447633212703384*^9, 3.447682857908998*^9, 
  3.447693389168849*^9, 3.447694151990245*^9, 3.44794969594979*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Iy> = ", 0, "     ", "<Sy> = ", Rational[1, 2] 
   Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178671379373*^9, 3.433245741285935*^9, 
  3.433458055018134*^9, 3.4457126526502867`*^9, 3.445774815138644*^9, 
  3.4459657060748167`*^9, 3.447633212703384*^9, 3.447682857908998*^9, 
  3.447693389168849*^9, 3.447694151990245*^9, 3.447949695960445*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178671379373*^9, 3.433245741285935*^9, 
  3.433458055018134*^9, 3.4457126526502867`*^9, 3.445774815138644*^9, 
  3.4459657060748167`*^9, 3.447633212703384*^9, 3.447682857908998*^9, 
  3.447693389168849*^9, 3.447694151990245*^9, 3.447949695973979*^9}]
}, Open  ]]
}, Open  ]],

Cell["For the population that begins in the psiAB state:", "Text",
 CellChangeTimes->{{3.433178686429935*^9, 3.433178725447481*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiAB", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.433178733062251*^9, 3.433178735076041*^9}, {
  3.4457126582208853`*^9, 3.445712658770049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Ix> = ", 0, "     ", "<Sx> = ", Rational[1, 2] 
   Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433245741319353*^9, 
  3.433458055152089*^9, 3.445712659961622*^9, 3.445774819288185*^9, 
  3.445965706407139*^9, 3.447633223101633*^9, 3.44768285805604*^9, 
  3.4476933892692327`*^9, 3.447694152317997*^9, 3.447949696261528*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Iy> = ", 0, "     ", "<Sy> = ", Rational[-1, 2] 
   Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433245741319353*^9, 
  3.433458055152089*^9, 3.445712659961622*^9, 3.445774819288185*^9, 
  3.445965706407139*^9, 3.447633223101633*^9, 3.44768285805604*^9, 
  3.4476933892692327`*^9, 3.447694152317997*^9, 3.447949696272592*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433245741319353*^9, 
  3.433458055152089*^9, 3.445712659961622*^9, 3.445774819288185*^9, 
  3.445965706407139*^9, 3.447633223101633*^9, 3.44768285805604*^9, 
  3.4476933892692327`*^9, 3.447694152317997*^9, 3.4479496962862387`*^9}]
}, Open  ]]
}, Open  ]],

Cell["For the population that begins in the psiBA state:", "Text",
 CellChangeTimes->{{3.433178686429935*^9, 3.433178725447481*^9}, {
  3.433178768709715*^9, 3.4331787704829903`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiBA", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.433178733062251*^9, 3.433178735076041*^9}, {
  3.433178773316888*^9, 3.43317877699617*^9}, {3.445712669132555*^9, 
  3.445712673713739*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Ix> = ", 0, "     ", "<Sx> = ", Rational[1, 2] 
   Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433178780198759*^9, 
  3.433245741352071*^9, 3.433458055294079*^9, 3.445712674782913*^9, 
  3.445774824727379*^9, 3.445965706573701*^9, 3.4476332262286053`*^9, 
  3.4476828582043867`*^9, 3.4476933893772917`*^9, 3.447694152439786*^9, 
  3.447949696362361*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Iy> = ", 0, "     ", "<Sy> = ", Rational[1, 2] 
   Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433178780198759*^9, 
  3.433245741352071*^9, 3.433458055294079*^9, 3.445712674782913*^9, 
  3.445774824727379*^9, 3.445965706573701*^9, 3.4476332262286053`*^9, 
  3.4476828582043867`*^9, 3.4476933893772917`*^9, 3.447694152439786*^9, 
  3.447949696373289*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433178780198759*^9, 
  3.433245741352071*^9, 3.433458055294079*^9, 3.445712674782913*^9, 
  3.445774824727379*^9, 3.445965706573701*^9, 3.4476332262286053`*^9, 
  3.4476828582043867`*^9, 3.4476933893772917`*^9, 3.447694152439786*^9, 
  3.44794969638699*^9}]
}, Open  ]]
}, Open  ]],

Cell["For the population that begins in the psiBB state:", "Text",
 CellChangeTimes->{{3.433178686429935*^9, 3.433178725447481*^9}, {
  3.433178787493267*^9, 3.433178792107099*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiBB", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.433178733062251*^9, 3.433178735076041*^9}, {
  3.4331788646895313`*^9, 3.433178866228731*^9}, {3.445712693012274*^9, 
  3.445712693584978*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Ix> = ", 0, "     ", "<Sx> = ", Rational[-1, 2] 
   Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433178868607699*^9, 
  3.433245741538248*^9, 3.4334580554391212`*^9, 3.445712694929336*^9, 
  3.445774826979678*^9, 3.445965706676426*^9, 3.4476332296160927`*^9, 
  3.447682858342395*^9, 3.447693389534914*^9, 3.447694152571403*^9, 
  3.447949696463979*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
     "]"}]}]}],
  SequenceForm[
  "<Iy> = ", 0, "     ", "<Sy> = ", Rational[-1, 2] 
   Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433178868607699*^9, 
  3.433245741538248*^9, 3.4334580554391212`*^9, 3.445712694929336*^9, 
  3.445774826979678*^9, 3.445965706676426*^9, 3.4476332296160927`*^9, 
  3.447682858342395*^9, 3.447693389534914*^9, 3.447694152571403*^9, 
  3.4479496965079*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<Sz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 
   Rational[-1, 2], "     ", "<Sz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433178737097394*^9, 3.433178868607699*^9, 
  3.433245741538248*^9, 3.4334580554391212`*^9, 3.445712694929336*^9, 
  3.445774826979678*^9, 3.445965706676426*^9, 3.4476332296160927`*^9, 
  3.447682858342395*^9, 3.447693389534914*^9, 3.447694152571403*^9, 
  3.447949696522196*^9}]
}, Open  ]]
}, Open  ]],

Cell["The weighted average for Sy", "Text",
 CellChangeTimes->{{3.433179241600521*^9, 3.4331792489226217`*^9}, {
  3.4457127365075703`*^9, 3.4457127369580593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", 
   RowBox[{"(", " ", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], "+", " ", 
  RowBox[{"fab", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], "+", 
  RowBox[{"fba", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fbb", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.433179252844718*^9, 3.433179348802022*^9}, {
  3.445712762709947*^9, 3.4457128294408913`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "8"]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.4331793510468473`*^9, 3.4332457415897427`*^9, 
  3.4334580556604567`*^9, 3.445712835047262*^9, 3.445774840818181*^9, 
  3.445965706891774*^9, 3.447633280637106*^9, 3.447682858440434*^9, 
  3.447693389636118*^9, 3.447694152757537*^9, 3.44794969659697*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4331793552432127`*^9, 3.4331793599081907`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "deltaPS", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    ")"}]}]], "Output",
 CellChangeTimes->{3.433179361029962*^9, 3.4332457416385117`*^9, 
  3.433458055741221*^9, 3.445712838730255*^9, 3.4457748446284437`*^9, 
  3.4459657070245256`*^9, 3.447633283568597*^9, 3.447682858505828*^9, 
  3.4476933897017612`*^9, 3.447694152822731*^9, 3.447949696710965*^9}]
}, Open  ]],

Cell["The weighted average for Sx:", "Text",
 CellChangeTimes->{{3.433178875677114*^9, 3.4331788914035*^9}, {
  3.445712740613793*^9, 3.445712741181835*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", " ", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fab", " ", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], "+", " ", 
  RowBox[{"fba", " ", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fbb", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.433178897639081*^9, 3.43317897296245*^9}, {
  3.445712869296637*^9, 3.4457129173723173`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.433178977403867*^9, 3.4332457416893797`*^9, 
  3.433458055802894*^9, 3.4457129193072433`*^9, 3.4457748507070923`*^9, 
  3.4459657071587143`*^9, 3.447633296670435*^9, 3.447682858573812*^9, 
  3.447693389818345*^9, 3.447694152889859*^9, 3.447949696847342*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433178979911337*^9, 3.43317898502691*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "deltaPS", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.433178986692706*^9, 3.433245741738669*^9, 
  3.4334580558812313`*^9, 3.4457129245867167`*^9, 3.445774854153985*^9, 
  3.445965707472034*^9, 3.44763329938144*^9, 3.447682858638122*^9, 
  3.4476933898852253`*^9, 3.447694152956064*^9, 3.447949696977442*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4331789912967377`*^9, 3.433179002972507*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "deltaPS"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], "+", 
    RowBox[{"deltaPS", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.433179003704505*^9, 3.4332457417676907`*^9, 
  3.433458055937746*^9, 3.4457129270545473`*^9, 3.445774857503326*^9, 
  3.4459657075441017`*^9, 3.447633309988603*^9, 3.447682858705585*^9, 
  3.447693389951919*^9, 3.447694153023522*^9, 3.447949697046042*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433179019167103*^9, 3.433179023379429*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", "deltaPS", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}], "-", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.433179024584281*^9, 3.4332457418226547`*^9, 
  3.433458056003921*^9, 3.44571293374244*^9, 3.445774861428424*^9, 
  3.445965707610573*^9, 3.447633314104847*^9, 3.447682858956395*^9, 
  3.447693390122978*^9, 3.447694153091113*^9, 3.447949697230936*^9}]
}, Open  ]],

Cell["The correlations also evolve with time:", "Text",
 CellChangeTimes->{{3.4331795026032343`*^9, 3.433179510467319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiAA", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4331795227430973`*^9, 3.433179524916649*^9}, {
   3.4457129586886873`*^9, 3.445712960793645*^9}, 3.445872488547564*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179529481662*^9, 3.433245741874011*^9, 
  3.433458056120002*^9, 3.445712962667221*^9, 3.445774871770843*^9, 
  3.445965707678431*^9, 3.447633401843719*^9, 3.4476828590269833`*^9, 
  3.447693390203835*^9, 3.4476941532749987`*^9, 3.4479496973031597`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179529481662*^9, 3.433245741874011*^9, 
  3.433458056120002*^9, 3.445712962667221*^9, 3.445774871770843*^9, 
  3.445965707678431*^9, 3.447633401843719*^9, 3.4476828590269833`*^9, 
  3.447693390203835*^9, 3.4476941532749987`*^9, 3.447949697313225*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", Rational[-1, 4] 
   Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSy> = ", Rational[1, 4] 
   Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179529481662*^9, 3.433245741874011*^9, 
  3.433458056120002*^9, 3.445712962667221*^9, 3.445774871770843*^9, 
  3.445965707678431*^9, 3.447633401843719*^9, 3.4476828590269833`*^9, 
  3.447693390203835*^9, 3.4476941532749987`*^9, 3.4479496973269987`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiAB", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4331795388323393`*^9, 3.433179541461081*^9}, {
   3.4457129673001747`*^9, 3.4457129678413963`*^9}, 3.445872488561871*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179542462097*^9, 3.433245741921633*^9, 
  3.433458056321597*^9, 3.445712972234207*^9, 3.445774915793562*^9, 
  3.445965707843032*^9, 3.447633404623723*^9, 3.447682859128072*^9, 
  3.447693390304296*^9, 3.447694153376725*^9, 3.447949697403912*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179542462097*^9, 3.433245741921633*^9, 
  3.433458056321597*^9, 3.445712972234207*^9, 3.445774915793562*^9, 
  3.445965707843032*^9, 3.447633404623723*^9, 3.447682859128072*^9, 
  3.447693390304296*^9, 3.447694153376725*^9, 3.44794969741411*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", Rational[1, 4] 
   Sin[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSy> = ", Rational[-1, 4] 
   Cos[((NMR`twoSpinLib`J - 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179542462097*^9, 3.433245741921633*^9, 
  3.433458056321597*^9, 3.445712972234207*^9, 3.445774915793562*^9, 
  3.445965707843032*^9, 3.447633404623723*^9, 3.447682859128072*^9, 
  3.447693390304296*^9, 3.447694153376725*^9, 3.447949697427929*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiBA", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.433179551303112*^9, 3.433179552652829*^9}, {
   3.445712975692205*^9, 3.445712977296978*^9}, 3.445872488576247*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179554147283*^9, 3.433245741972013*^9, 
  3.433458056522623*^9, 3.445712978515811*^9, 3.445774918302286*^9, 
  3.44596570801071*^9, 3.447633411324501*^9, 3.447682859228866*^9, 
  3.447693390408435*^9, 3.4476941534760237`*^9, 3.447949697506447*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179554147283*^9, 3.433245741972013*^9, 
  3.433458056522623*^9, 3.445712978515811*^9, 3.445774918302286*^9, 
  3.44596570801071*^9, 3.447633411324501*^9, 3.447682859228866*^9, 
  3.447693390408435*^9, 3.4476941534760237`*^9, 3.447949697517255*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", Rational[-1, 4] 
   Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSy> = ", Rational[-1, 4] 
   Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179554147283*^9, 3.433245741972013*^9, 
  3.433458056522623*^9, 3.445712978515811*^9, 3.445774918302286*^9, 
  3.44596570801071*^9, 3.447633411324501*^9, 3.447682859228866*^9, 
  3.447693390408435*^9, 3.4476941534760237`*^9, 3.447949697531488*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorPsi", "[", 
  RowBox[{"psiTime", "[", 
   RowBox[{
    RowBox[{"psiPi2Sx", "[", "psiBB", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.433179566255123*^9, 3.433179567284854*^9}, {
   3.445712996552412*^9, 3.44571299774448*^9}, 3.445872488590638*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IxSx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IxSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IxSx> = ", 0, "     ", "<IxSy> = ", 0, "     ", "<IxSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179569063579*^9, 3.433245742021653*^9, 
  3.4334580568714933`*^9, 3.445713001365274*^9, 3.4457749216755037`*^9, 
  3.4459657081150303`*^9, 3.447633414168481*^9, 3.44768285937859*^9, 
  3.447693390510147*^9, 3.447694153826326*^9, 3.4479496976057377`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IySx> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySy> = \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IySz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IySx> = ", 0, "     ", "<IySy> = ", 0, "     ", "<IySz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179569063579*^9, 3.433245742021653*^9, 
  3.4334580568714933`*^9, 3.445713001365274*^9, 3.4457749216755037`*^9, 
  3.4459657081150303`*^9, 3.447633414168481*^9, 3.44768285937859*^9, 
  3.447693390510147*^9, 3.447694153826326*^9, 3.447949697616118*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<IzSx> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    "\[InvisibleSpace]", "\<\"     \"\>", 
   "\[InvisibleSpace]", "\<\"<IzSz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "<IzSx> = ", Rational[1, 4] 
   Sin[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSy> = ", Rational[1, 4] 
   Cos[((NMR`twoSpinLib`J + 2 NMR`twoSpinLib`nuS) Pi) NMR`twoSpinLib`t], 
   "     ", "<IzSz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433179569063579*^9, 3.433245742021653*^9, 
  3.4334580568714933`*^9, 3.445713001365274*^9, 3.4457749216755037`*^9, 
  3.4459657081150303`*^9, 3.447633414168481*^9, 3.44768285937859*^9, 
  3.447693390510147*^9, 3.447694153826326*^9, 3.4479496976303253`*^9}]
}, Open  ]]
}, Open  ]],

Cell["Weighted average of IzSy :", "Text",
 CellChangeTimes->{{3.4331804162625437`*^9, 3.433180417204185*^9}, {
  3.445713131377055*^9, 3.445713134138895*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fab", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fba", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fbb", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], "\[InvisibleSpace]", ")"}]}]}]], "Input",
 CellChangeTimes->{{3.433180421415851*^9, 3.433180472395707*^9}, {
  3.445713216383358*^9, 3.445713251514646*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "-", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.4331804742626467`*^9, 3.4332457420749607`*^9, 
  3.433458056991096*^9, 3.445713253626958*^9, 3.4457749267989492`*^9, 
  3.445965708212603*^9, 3.447633419725739*^9, 3.4476828595260897`*^9, 
  3.447693390656488*^9, 3.447694153975021*^9, 3.447949697701869*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433180476362113*^9, 3.433180480767933*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "deltaPS", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.4331804817877502`*^9, 3.433245742123371*^9, 
  3.433458057068611*^9, 3.445713257050376*^9, 3.4457749337847033`*^9, 
  3.445965708523407*^9, 3.447633423269372*^9, 3.447682859590868*^9, 
  3.447693390721424*^9, 3.447694154042696*^9, 3.4479496977667723`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433180491280061*^9, 3.433180500470271*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"deltaPS", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], "-", 
    RowBox[{"deltaPS", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.4331805014654713`*^9, 3.433245742237894*^9, 
  3.433458057126136*^9, 3.445713259923726*^9, 3.445776069365848*^9, 
  3.445965708596609*^9, 3.447633428045372*^9, 3.447682859657976*^9, 
  3.4476933907878723`*^9, 3.4476941541082907`*^9, 3.44794969783412*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433180507472905*^9, 3.433180512815795*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "deltaPS", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}], "-", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
      RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.433180513485805*^9, 3.4332457422691*^9, 
  3.433458057192944*^9, 3.445713266352518*^9, 3.445776072273141*^9, 
  3.445965708663125*^9, 3.447633430555337*^9, 3.447682859723366*^9, 
  3.447693390856135*^9, 3.4476941543320017`*^9, 3.4479496978983583`*^9}]
}, Open  ]],

Cell["Weighted average of IzSx:", "Text",
 CellChangeTimes->{{3.4331802111281*^9, 3.433180220749061*^9}, {
  3.445713323315382*^9, 3.445713326813264*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"faa", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fab", 
   RowBox[{"(", "\[InvisibleSpace]\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], "\[InvisibleSpace]", ")"}]}], " ", "+", " ", 
  RowBox[{"fba", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "+", " ", 
  RowBox[{"fbb", 
   RowBox[{"(", "\[InvisibleSpace]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.43318022348104*^9, 3.433180278178335*^9}, {
  3.445713331253583*^9, 3.4457133778066797`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "-", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "-", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "-", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}], 
  "-", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "deltaPI", "+", "deltaPS"}], ")"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", "+", 
       RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.433180281145804*^9, 3.433245742309449*^9, 
  3.43345805725982*^9, 3.4457133794905233`*^9, 3.445776103706513*^9, 
  3.445965708795059*^9, 3.4476335602741137`*^9, 3.447682859973514*^9, 
  3.4476933909228773`*^9, 3.447694154409651*^9, 3.447949697965623*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433180287398325*^9, 3.433180292306889*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "8"]}], " ", "deltaPS", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "-", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
    "+", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"J", "+", 
        RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}]}],
    ")"}]}]], "Output",
 CellChangeTimes->{3.433180293506341*^9, 3.433245742358577*^9, 
  3.4334580573763027`*^9, 3.44571338230505*^9, 3.4457761067273903`*^9, 
  3.445965708995422*^9, 3.44763356319565*^9, 3.447682860091692*^9, 
  3.447693390988064*^9, 3.447694154476288*^9, 3.447949698032373*^9}]
}, Open  ]],

Cell["setting nuS to zero for Sy", "Text",
 CellChangeTimes->{{3.433181737182144*^9, 3.433181747456769*^9}, {
  3.445713425776535*^9, 3.4457134263946037`*^9}, {3.445713471001603*^9, 
  3.445713471545517*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", "deltaPS", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
     "+", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], " ", "/.", " ", 
  RowBox[{"nuS", " ", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.433181783803213*^9, 3.4331817906489887`*^9}, {
  3.445713462610443*^9, 3.445713467764539*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "deltaPS", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.433181791830221*^9, 3.433245742408271*^9, 
  3.433458057442709*^9, 3.445713474823456*^9, 3.445776120122747*^9, 
  3.4459657091285963`*^9, 3.4476335758908253`*^9, 3.4476828602075777`*^9, 
  3.447693391220778*^9, 3.447694154591551*^9, 3.447949698098118*^9}]
}, Open  ]],

Cell["setting nuS to zero for IzSx:", "Text",
 CellChangeTimes->{{3.433181272013726*^9, 3.4331812859470453`*^9}, {
  3.4331816565723677`*^9, 3.433181667809922*^9}, {3.433181706276329*^9, 
  3.4331817084079323`*^9}, {3.445713578302392*^9, 3.445713580982288*^9}, {
  3.447633747250289*^9, 3.447633750967929*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "8"]}], " ", "deltaPS", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "-", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], "]"}], 
     "+", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"J", "+", 
         RowBox[{"2", " ", "nuS"}]}], ")"}], " ", "\[Pi]", " ", "t"}], 
      "]"}]}], ")"}]}], "/.", " ", 
  RowBox[{"nuS", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.433180946953944*^9, 3.433180960143816*^9}, 
   3.433181712522088*^9, {3.433181799457679*^9, 3.4331818022731447`*^9}, {
   3.447633851900981*^9, 3.447633855879369*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", "deltaPS", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"J", " ", "\[Pi]", " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.433180961914774*^9, 3.433181714493902*^9, 
  3.4332457424584017`*^9, 3.433458057510231*^9, 3.445776128121522*^9, 
  3.4459657092626057`*^9, 3.447633857870585*^9, 3.447682860275523*^9, 
  3.44769339135397*^9, 3.447694154724841*^9, 3.447949698280747*^9}]
}, Open  ]],

Cell["Setting nuS to zero for Sx", "Text",
 CellChangeTimes->{{3.433181826827984*^9, 3.4331818352483387`*^9}, {
  3.4457135029791737`*^9, 3.445713509080414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", "deltaPS", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}], "-", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], ")"}]}], 
  "/.", " ", 
  RowBox[{"nuS", " ", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.43318187173114*^9, 3.433181878336817*^9}, {
  3.4457135351524687`*^9, 3.445713539482671*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.433181879555346*^9, 3.433245742507472*^9, 
  3.4334580576286907`*^9, 3.4457135405947638`*^9, 3.445776139177843*^9, 
  3.445965709414466*^9, 3.4476338773715343`*^9, 3.4476828603411713`*^9, 
  3.447693391470148*^9, 3.4476941547927*^9, 3.4479496983490458`*^9}]
}, Open  ]],

Cell["Setting nuS to zero for IzSy", "Text",
 CellChangeTimes->{{3.4331812395349693`*^9, 3.43318125634717*^9}, {
  3.433181675113744*^9, 3.433181677705903*^9}, {3.4331817244582157`*^9, 
  3.4331817266557617`*^9}, {3.4457135544097967`*^9, 3.4457135739663353`*^9}, {
  3.445776185658333*^9, 3.4457761862590227`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "8"], " ", "deltaPS", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "-", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"J", " ", "\[Pi]", " ", "t"}], "+", 
       RowBox[{"2", " ", "nuS", " ", "\[Pi]", " ", "t"}]}], "]"}]}], ")"}]}], 
  "/.", " ", 
  RowBox[{"nuS", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.4331817295628777`*^9, 3.4331817310815887`*^9}, {
  3.433181805377619*^9, 3.433181807585054*^9}, {3.445713655080439*^9, 
  3.445713658727312*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.433181259962532*^9, 3.433181732395563*^9, 
  3.433245742557727*^9, 3.433458057744174*^9, 3.445713660897031*^9, 
  3.4457761899349747`*^9, 3.445965709480794*^9, 3.447633880252707*^9, 
  3.447682860408386*^9, 3.4476933915382423`*^9, 3.4476941548592253`*^9, 
  3.447949698415707*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Density matrix for a population of single spins", "Section",
 CellChangeTimes->{{3.433245796563036*^9, 3.433245814727994*^9}}],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<NMR`twoSpinLib`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4332457817776423`*^9, 3.433245790181415*^9}, {
  3.4332458375463743`*^9, 3.4332458435611267`*^9}, {3.433247151290065*^9, 
  3.4332471565535917`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "NMR`oneSpinLib`"}]], "Input",
 CellChangeTimes->{3.447694513143148*^9}],

Cell["The general form of the density matrix is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData["rhoGen"], "Input",
 CellChangeTimes->{{3.4332472739105177`*^9, 3.433247275202756*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"ca", " ", 
       RowBox[{"Conjugate", "[", "ca", "]"}]}], 
      RowBox[{"ca", " ", 
       RowBox[{"Conjugate", "[", "cb", "]"}]}]},
     {
      RowBox[{"cb", " ", 
       RowBox[{"Conjugate", "[", "ca", "]"}]}], 
      RowBox[{"cb", " ", 
       RowBox[{"Conjugate", "[", "cb", "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433247277020938*^9, 3.4334580585988903`*^9, 
  3.445965710800638*^9, 3.447633989040524*^9, 3.4476828615960817`*^9, 
  3.4476933927745447`*^9, 3.447694156061492*^9, 3.447949699620501*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The three operator matrices:", "Subsection",
 CellChangeTimes->{{3.4332466553608627`*^9, 3.433246665779846*^9}, {
  3.433247522906189*^9, 3.433247523690015*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Ix"], "Input",
 CellChangeTimes->{{3.433246668323698*^9, 3.4332466687285013`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433246670351096*^9, 3.433458058665401*^9, 
  3.445965710868444*^9, 3.4476339953382072`*^9, 3.4476828616626883`*^9, 
  3.4476933929077787`*^9, 3.447694156131115*^9, 3.447949699686007*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Iy"], "Input",
 CellChangeTimes->{{3.4332466714333*^9, 3.433246671692717*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "2"]}]},
     {
      FractionBox["\[ImaginaryI]", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433246673296145*^9, 3.4334580587319508`*^9, 
  3.445965710935063*^9, 3.447633997160121*^9, 3.447682861729455*^9, 
  3.447693393041143*^9, 3.4476941561969233`*^9, 3.4479496997538233`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Iz"], "Input",
 CellChangeTimes->{{3.433246674514139*^9, 3.433246675620637*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "2"], "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.43324667748341*^9, 3.4334580587997026`*^9, 
  3.445965711001499*^9, 3.4476339999083767`*^9, 3.447682861796764*^9, 
  3.447693393175008*^9, 3.447694156264287*^9, 3.447949699819968*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
General expressions for calculating the average magnetization components:\
\>", "Subsection",
 CellChangeTimes->{{3.433247292883313*^9, 3.433247342789557*^9}, {
   3.43324749724737*^9, 3.433247498540845*^9}, 3.433247720835669*^9}],

Cell["For Ix:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", 
  RowBox[{"Ix", ".", "rhoGen"}], "]"}]], "Input",
 CellChangeTimes->{{3.4332473483475122`*^9, 3.43324736049015*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "cb", " ", 
   RowBox[{"Conjugate", "[", "ca", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "ca", " ", 
   RowBox[{"Conjugate", "[", "cb", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4332473624624863`*^9, 3.4334580589934893`*^9, 
  3.445965711133313*^9, 3.447634015984069*^9, 3.447682861911167*^9, 
  3.447693393242729*^9, 3.447694156331815*^9, 3.447949699885953*^9}]
}, Open  ]],

Cell["For Iy:", "Text",
 CellChangeTimes->{{3.4332473701962023`*^9, 3.43324737993326*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", 
  RowBox[{"Iy", ".", "rhoGen"}], "]"}]], "Input",
 CellChangeTimes->{{3.433247406823596*^9, 3.433247413551736*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "cb", " ", 
   RowBox[{"Conjugate", "[", "ca", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "ca", " ", 
   RowBox[{"Conjugate", "[", "cb", "]"}]}]}]], "Output",
 CellChangeTimes->{3.433247416760401*^9, 3.433458059050386*^9, 
  3.445965711266695*^9, 3.4476340234955893`*^9, 3.447682861979014*^9, 
  3.447693393309516*^9, 3.4476941563992043`*^9, 3.447949699952222*^9}]
}, Open  ]],

Cell["For Iz:", "Text",
 CellChangeTimes->{{3.433247424104289*^9, 3.433247430849742*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", 
  RowBox[{"Iz", ".", "rhoGen"}], "]"}]], "Input",
 CellChangeTimes->{{3.433247433312793*^9, 3.433247445922861*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "ca", " ", 
   RowBox[{"Conjugate", "[", "ca", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "cb", " ", 
   RowBox[{"Conjugate", "[", "cb", "]"}]}]}]], "Output",
 CellChangeTimes->{3.433247447850503*^9, 3.4334580591167183`*^9, 
  3.445965711399852*^9, 3.4476340267251*^9, 3.447682862045508*^9, 
  3.447693393376484*^9, 3.447694156463822*^9, 3.4479497000193357`*^9}]
}, Open  ]],

Cell["\<\
The oneSpinLib package includes a function to calculate all of the \
magnetization components from the density matrix:\
\>", "Text",
 CellChangeTimes->{{3.4332477325688543`*^9, 3.433247768283717*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "rhoGen", "]"}]], "Input",
 CellChangeTimes->{{3.4332478246460342`*^9, 3.433247834322404*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cb", " ", 
       RowBox[{"Conjugate", "[", "ca", "]"}]}], "+", 
      RowBox[{"ca", " ", 
       RowBox[{"Conjugate", "[", "cb", "]"}]}]}], ")"}]}]}],
  SequenceForm[
  "<Ix> = ", 
   Rational[1, 2] (NMR`oneSpinLib`cb Conjugate[NMR`oneSpinLib`ca] + 
    NMR`oneSpinLib`ca Conjugate[NMR`oneSpinLib`cb])],
  Editable->False]], "Print",
 CellChangeTimes->{3.433247836391848*^9, 3.433458059185648*^9, 
  3.445965711468975*^9, 3.447634032070374*^9, 3.447682862117071*^9, 
  3.447693393443673*^9, 3.447694156533298*^9, 3.447949700086708*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cb", " ", 
       RowBox[{"Conjugate", "[", "ca", "]"}]}], "-", 
      RowBox[{"ca", " ", 
       RowBox[{"Conjugate", "[", "cb", "]"}]}]}], ")"}]}]}],
  SequenceForm["<Iy> = ", Complex[0, 
     Rational[-1, 2]] (NMR`oneSpinLib`cb Conjugate[NMR`oneSpinLib`ca] - 
    NMR`oneSpinLib`ca Conjugate[NMR`oneSpinLib`cb])],
  Editable->False]], "Print",
 CellChangeTimes->{3.433247836391848*^9, 3.433458059185648*^9, 
  3.445965711468975*^9, 3.447634032070374*^9, 3.447682862117071*^9, 
  3.447693393443673*^9, 3.447694156533298*^9, 3.447949700097271*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ca", " ", 
       RowBox[{"Conjugate", "[", "ca", "]"}]}], "-", 
      RowBox[{"cb", " ", 
       RowBox[{"Conjugate", "[", "cb", "]"}]}]}], ")"}]}]}],
  SequenceForm[
  "<Iz> = ", 
   Rational[1, 2] (NMR`oneSpinLib`ca Conjugate[NMR`oneSpinLib`ca] - 
    NMR`oneSpinLib`cb Conjugate[NMR`oneSpinLib`cb])],
  Editable->False]], "Print",
 CellChangeTimes->{3.433247836391848*^9, 3.433458059185648*^9, 
  3.445965711468975*^9, 3.447634032070374*^9, 3.447682862117071*^9, 
  3.447693393443673*^9, 3.447694156533298*^9, 3.447949700110792*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["The equilibrium density matrix:", "Subsection"]], \
"Text",
 CellChangeTimes->{{3.433246683519951*^9, 3.433246692731927*^9}, {
  3.433247553010483*^9, 3.433247555770323*^9}}],

Cell[CellGroupData[{

Cell[BoxData["rhoEq"], "Input",
 CellChangeTimes->{{3.4332458559124317`*^9, 3.433245857056839*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["deltaP", "2"], "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["deltaP", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433245858265539*^9, 3.4334580593180017`*^9, 
  3.445965711569137*^9, 3.447634037157894*^9, 3.447682862213401*^9, 
  3.4476933935439157`*^9, 3.4476941566317377`*^9, 3.4479497001871767`*^9}]
}, Open  ]],

Cell["The equilibrium magnetization components:", "Text",
 CellChangeTimes->{{3.433247850699217*^9, 3.433247862539873*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "rhoEq", "]"}]], "Input",
 CellChangeTimes->{{3.433247864822294*^9, 3.433247872719071*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433247876136697*^9, 3.4334580593852797`*^9, 
  3.4459657116367702`*^9, 3.447634059523801*^9, 3.4476828622816353`*^9, 
  3.447693393675726*^9, 3.44769415669827*^9, 3.447949700254031*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iy> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433247876136697*^9, 3.4334580593852797`*^9, 
  3.4459657116367702`*^9, 3.447634059523801*^9, 3.4476828622816353`*^9, 
  3.447693393675726*^9, 3.44769415669827*^9, 3.447949700264049*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", 
   FractionBox["deltaP", "2"]}],
  SequenceForm["<Iz> = ", Rational[1, 2] NMR`oneSpinLib`deltaP],
  Editable->False]], "Print",
 CellChangeTimes->{3.433247876136697*^9, 3.4334580593852797`*^9, 
  3.4459657116367702`*^9, 3.447634059523801*^9, 3.4476828622816353`*^9, 
  3.447693393675726*^9, 3.44769415669827*^9, 3.447949700277112*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The rotation matrices:", "Subsection",
 CellChangeTimes->{{3.4332475885315933`*^9, 3.433247590218103*^9}}],

Cell["For rotation about the x-axis", "Text",
 CellChangeTimes->{{3.433246902031968*^9, 3.433246956365509*^9}, {
  3.4332475675381517`*^9, 3.433247574594077*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rx", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.433246960686954*^9, 3.433246978419814*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433246980390671*^9, 3.43324814184334*^9, 
  3.433458059520351*^9, 3.445965711960837*^9, 3.447634080617679*^9, 
  3.447682862382166*^9, 3.447693393866835*^9, 3.447694156797812*^9, 
  3.447949700354251*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rinvx", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.433246983531904*^9, 3.4332469921659393`*^9}, {
   3.433247022452054*^9, 3.433247027836081*^9}, 3.433247165693359*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433247028875455*^9, 3.433247167428581*^9, 
  3.433248145377779*^9, 3.43345805960798*^9, 3.445965712037052*^9, 
  3.447634083909767*^9, 3.447682862450623*^9, 3.447693393946047*^9, 
  3.447694156865346*^9, 3.447949700420925*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433247033002948*^9, 3.433247042475973*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.43324704414782*^9, 3.4332471709275618`*^9, 
  3.433248149141843*^9, 3.4334580596707497`*^9, 3.445965712104556*^9, 
  3.4476340948894567`*^9, 3.4476828626159782`*^9, 3.4476933940766068`*^9, 
  3.447694156932474*^9, 3.4479497004891453`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rx", "[", 
  RowBox[{"Pi", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.433248054694705*^9, 3.433248060693881*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", 
       SqrtBox["2"]], 
      FractionBox["\[ImaginaryI]", 
       SqrtBox["2"]]},
     {
      FractionBox["\[ImaginaryI]", 
       SqrtBox["2"]], 
      FractionBox["1", 
       SqrtBox["2"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433248063316741*^9, 3.4332481529586*^9, 
  3.433458059736936*^9, 3.44596571223608*^9, 3.447634103336097*^9, 
  3.447682862681835*^9, 3.447693394209997*^9, 3.447694157221508*^9, 
  3.447949700669285*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.433248097673469*^9, 3.4332481031102667`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rinvx", "[", 
  RowBox[{"Pi", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.433248072192376*^9, 3.4332480795424623`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", 
       SqrtBox["2"]], 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}]},
     {
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", 
        SqrtBox["2"]]}], 
      FractionBox["1", 
       SqrtBox["2"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433248081306028*^9, 3.4332481562568073`*^9, 
  3.433458059850264*^9, 3.4459657123874617`*^9, 3.447634108894618*^9, 
  3.447682862771553*^9, 3.447693394297023*^9, 3.447694157410058*^9, 
  3.447949700751692*^9}]
}, Open  ]],

Cell["For rotation about the y-axis:", "Text",
 CellChangeTimes->{{3.433247182455736*^9, 3.433247196133257*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ry", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.433247199516307*^9, 3.433247201549987*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}]},
     {
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.43324720343999*^9, 3.4334580599781923`*^9, 
  3.4459657124544477`*^9, 3.447634114871318*^9, 3.447682862849922*^9, 
  3.447693394362294*^9, 3.44769415752107*^9, 3.4479497008217793`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rinvy", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.433247205090829*^9, 3.433247209843525*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4332472139544153`*^9, 3.4334580600553207`*^9, 
  3.4459657125218887`*^9, 3.447634117285592*^9, 3.4476828629168253`*^9, 
  3.4476933944295673`*^9, 3.447694157628248*^9, 3.4479497008882513`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433247215839147*^9, 3.433247225916403*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433247227129312*^9, 3.433458060121915*^9, 
  3.44596571258836*^9, 3.4476341202111797`*^9, 3.447682862983426*^9, 
  3.4476933944957314`*^9, 3.447694157745913*^9, 3.447949700955961*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The effect of a pi/2 x-pulse applied to the equilibrium population\
\>", "Subsection",
 CellChangeTimes->{{3.433247598853262*^9, 3.433247621274045*^9}, {
  3.43324766484098*^9, 3.433247682616954*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Rx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}], ".", "rhoEq", ".", 
  RowBox[{"Rinvx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.433247688766115*^9, 3.433247709980071*^9}, {
  3.4332479102492657`*^9, 3.43324792996487*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaP"}], "2"]}]},
     {
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "deltaP"}], "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433247932891101*^9, 3.433247991236223*^9, 
  3.433248164194221*^9, 3.433458060188342*^9, 3.445965712654497*^9, 
  3.447634131663158*^9, 3.447682863049245*^9, 3.447693394563393*^9, 
  3.447694157856659*^9, 3.447949701037898*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433247937655695*^9, 3.433247944548505*^9}, {
  3.433247997878558*^9, 3.433248002483551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Ix> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Ix> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433248003605446*^9, 3.433248170599304*^9, 
  3.433458060256082*^9, 3.445965712721518*^9, 3.4476341562425337`*^9, 
  3.447682863117244*^9, 3.4476933946293373`*^9, 3.447694158047777*^9, 
  3.447949701105247*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iy> = \"\>", "\[InvisibleSpace]", 
   FractionBox["deltaP", "2"]}],
  SequenceForm["<Iy> = ", Rational[1, 2] NMR`oneSpinLib`deltaP],
  Editable->False]], "Print",
 CellChangeTimes->{3.433248003605446*^9, 3.433248170599304*^9, 
  3.433458060256082*^9, 3.445965712721518*^9, 3.4476341562425337`*^9, 
  3.447682863117244*^9, 3.4476933946293373`*^9, 3.447694158047777*^9, 
  3.447949701115443*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"<Iz> = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["<Iz> = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.433248003605446*^9, 3.433248170599304*^9, 
  3.433458060256082*^9, 3.445965712721518*^9, 3.4476341562425337`*^9, 
  3.447682863117244*^9, 3.4476933946293373`*^9, 3.447694158047777*^9, 
  3.44794970112862*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Orthogonality of the operator matrices:", "Subsection",
 CellChangeTimes->{{3.4332484219250317`*^9, 3.4332484367802258`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "Iy"}]], "Input",
 CellChangeTimes->{{3.43324843984842*^9, 3.433248441671691*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["\[ImaginaryI]", "4"], "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "4"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4332484446655197`*^9, 3.433458060406535*^9, 
  3.445965712905497*^9, 3.447634172732698*^9, 3.447682863217331*^9, 
  3.447693394729364*^9, 3.4476941583641367`*^9, 3.447949701205545*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433248447238645*^9, 3.4332484597172737`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.43324846051672*^9, 3.4334580604743013`*^9, 
  3.445965712970994*^9, 3.447634175508644*^9, 3.447682863280801*^9, 
  3.447693394909243*^9, 3.447694158448555*^9, 3.447949701271488*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "Iz"}]], "Input",
 CellChangeTimes->{{3.433248462473568*^9, 3.4332484655891457`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "4"]}]},
     {
      FractionBox["1", "4"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4332484674853086`*^9, 3.4334580605413733`*^9, 
  3.4459657130389357`*^9, 3.44768286334901*^9, 3.447693394979731*^9, 
  3.447694158536697*^9, 3.447949701338768*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433248468299968*^9, 3.4332484728742*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.43324847461567*^9, 3.433458060607854*^9, 
  3.4459657131050167`*^9, 3.447634179194066*^9, 3.447682863415515*^9, 
  3.447693395045415*^9, 3.447694158629538*^9, 3.4479497014054823`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iy", ".", "Iz"}]], "Input",
 CellChangeTimes->{{3.433248476854507*^9, 3.4332484791624317`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["\[ImaginaryI]", "4"]},
     {
      FractionBox["\[ImaginaryI]", "4"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433248481414805*^9, 3.4334580606746187`*^9, 
  3.445965713172196*^9, 3.4476341820220203`*^9, 3.4476828634833117`*^9, 
  3.447693395113451*^9, 3.4476941591797733`*^9, 3.447949701472693*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433248482630302*^9, 3.433248486521158*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4332484881935787`*^9, 3.433458060742032*^9, 
  3.445965713239131*^9, 3.4476341845323343`*^9, 3.447682863631749*^9, 
  3.447693395179358*^9, 3.447694159693111*^9, 3.447949701538583*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Self-products of the operator matrices", "Subsection",
 CellChangeTimes->{{3.4332486001054277`*^9, 3.433248620386435*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ix", ".", "Ix"}]], "Input",
 CellChangeTimes->{{3.433248622904739*^9, 3.433248624309758*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "4"], "0"},
     {"0", 
      FractionBox["1", "4"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433248625576159*^9, 3.4334580608098*^9, 
  3.44596571330595*^9, 3.447634189237101*^9, 3.44768286370111*^9, 
  3.447693395247321*^9, 3.447694159795475*^9, 3.447949701740546*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.43324863089458*^9, 3.433248636112721*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.4332486371099977`*^9, 3.4334580608761797`*^9, 
  3.445965713372818*^9, 3.447634192571229*^9, 3.447682863765357*^9, 
  3.4476933953130283`*^9, 3.447694159891734*^9, 3.4479497018066797`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iy", ".", "Iy"}]], "Input",
 CellChangeTimes->{{3.433248639566723*^9, 3.433248641135931*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "4"], "0"},
     {"0", 
      FractionBox["1", "4"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433248642401444*^9, 3.433458061000291*^9, 
  3.445965713439994*^9, 3.447634195180986*^9, 3.447682863834553*^9, 
  3.447693395381713*^9, 3.4476941600049973`*^9, 3.447949701874508*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433248643283575*^9, 3.433248647260144*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.433248648980028*^9, 3.43345806107736*^9, 
  3.445965713505518*^9, 3.4476341990638*^9, 3.447682863899681*^9, 
  3.447693395512566*^9, 3.447694160115561*^9, 3.447949701939332*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Iz", ".", "Iz"}]], "Input",
 CellChangeTimes->{{3.433248651201784*^9, 3.433248652775454*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "4"], "0"},
     {"0", 
      FractionBox["1", "4"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433248654288329*^9, 3.433458061143938*^9, 
  3.44596571357366*^9, 3.44763420207987*^9, 3.447682863967762*^9, 
  3.4476933956462793`*^9, 3.447694160530272*^9, 3.4479497020072002`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433248655957614*^9, 3.433248661231833*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.4332486625241756`*^9, 3.4334580612109632`*^9, 
  3.445965713639759*^9, 3.447634204438189*^9, 3.447682864032628*^9, 
  3.4476933957622833`*^9, 3.447694160837165*^9, 3.447949702073696*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time evolution of the density matrix", "Subsection",
 CellChangeTimes->{{3.433249202755934*^9, 3.433249209832885*^9}}],

Cell["\<\
The change in the density matrix during a time period in a constant magnetic \
field is calculated using the Hamiltonian matrix and its inverse:\
\>", "Text",
 CellChangeTimes->{{3.433249217605679*^9, 3.433249266800877*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H", "[", 
  RowBox[{"t", ",", "nu"}], "]"}]], "Input",
 CellChangeTimes->{{3.433249272849607*^9, 3.4332492980019817`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], "0"},
     {"0", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.4332492777831163`*^9, 3.433249299460973*^9}, 
   3.433458061274877*^9, 3.44596571370714*^9, 3.447634260474436*^9, 
   3.4476828641024103`*^9, 3.447693395922358*^9, 3.447694160950067*^9, 
   3.447949702141477*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hinv", "[", 
  RowBox[{"t", ",", "nu"}], "]"}]], "Input",
 CellChangeTimes->{{3.433249308430017*^9, 3.433249315079113*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}], 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433249395826968*^9, 3.433458061345188*^9, 
  3.445965713773818*^9, 3.447634262549522*^9, 3.447682864168439*^9, 
  3.4476933959991503`*^9, 3.447694161106689*^9, 3.4479497022078743`*^9}]
}, Open  ]],

Cell["For the general form of the density matrix:", "Text",
 CellChangeTimes->{{3.4332494319328547`*^9, 3.433249441832909*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"t", ",", "nu"}], "]"}], ".", "rhoGen", ".", 
  RowBox[{"Hinv", "[", 
   RowBox[{"t", ",", "nu"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.433249444245346*^9, 3.433249459728376*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"ca", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], " ", 
        RowBox[{"Conjugate", "[", "ca", "]"}], " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}]}], "+", 
       RowBox[{"ca", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], " ", 
        RowBox[{"Conjugate", "[", "cb", "]"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}]}]}], 
      RowBox[{
       RowBox[{"ca", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], " ", 
        RowBox[{"Conjugate", "[", "cb", "]"}], " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}]}], "-", 
       RowBox[{"ca", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], " ", 
        RowBox[{"Conjugate", "[", "ca", "]"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}]}]}]},
     {
      RowBox[{
       RowBox[{"cb", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", 
          "t"}]], " ", 
        RowBox[{"Conjugate", "[", "ca", "]"}], " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}]}], "+", 
       RowBox[{"cb", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", 
          "t"}]], " ", 
        RowBox[{"Conjugate", "[", "cb", "]"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}]}]}], 
      RowBox[{
       RowBox[{"cb", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", 
          "t"}]], " ", 
        RowBox[{"Conjugate", "[", "cb", "]"}], " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}]}], "-", 
       RowBox[{"cb", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", 
          "t"}]], " ", 
        RowBox[{"Conjugate", "[", "ca", "]"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433249461154759*^9, 3.433458061410018*^9, 
  3.445965713924343*^9, 3.447634266670167*^9, 3.447682864236692*^9, 
  3.447693396065605*^9, 3.447694161637039*^9, 3.447949702275332*^9}]
}, Open  ]],

Cell["\<\
Applying a pi/2-x pulse to the equilibrium matrix, followed by a time \
evolution period:\
\>", "Text",
 CellChangeTimes->{{3.433249498112866*^9, 3.433249543140876*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Rx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}], ".", "rhoEq", ".", 
  RowBox[{"Rinvx", "[", 
   RowBox[{"Pi", "/", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.433249549744787*^9, 3.4332495733421593`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaP"}], "2"]}]},
     {
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "deltaP"}], "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.433249574864156*^9, {3.433249635134197*^9, 3.433249656060248*^9}, 
   3.433458061477892*^9, 3.4459657139911423`*^9, 3.447634272896604*^9, 
   3.4476828643022547`*^9, 3.447693396132236*^9, 3.447694161859971*^9, 
   3.4479497023415937`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"t", ",", "nu"}], "]"}], ".", "%", ".", 
  RowBox[{"Hinv", "[", 
   RowBox[{"t", ",", "nu"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.433249582173602*^9, 3.433249658160048*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "nu", " ", "\[Pi]", " ", "t"}]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["a", "2"], "]"}]}]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]],
        " ", 
       RowBox[{"Cos", "[", 
        FractionBox["a", "2"], "]"}]}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "nu", " ", "\[Pi]", " ", "t"}]],
        " ", 
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.433249613769763*^9, 3.433249659691351*^9}, 
   3.4334580615447187`*^9, 3.445965714057623*^9, 3.447634280431826*^9, 
   3.447682864369649*^9, 3.4476933961993847`*^9, 3.4476941619418097`*^9, 
   3.4479497024093*^9}]
}, Open  ]],

Cell["Converting this to trigonometric form:", "Text",
 CellChangeTimes->{{3.433249684748158*^9, 3.433249694306394*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpToTrig", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.433249705105467*^9, 3.433249714138255*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "deltaP", " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "deltaP", " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}]},
     {
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "deltaP", " ", 
        RowBox[{"Cos", "[", 
         FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", "deltaP", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "deltaP", " ", 
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.433249715816901*^9, 3.433458061613258*^9, 
  3.445965714125037*^9, 3.4476342850033493`*^9, 3.447682864436139*^9, 
  3.44769339633153*^9, 3.447694162010152*^9, 3.447949702476458*^9}]
}, Open  ]],

Cell["\<\
This is equivalent to deltaP(Cos[2 nu \[Pi] t] Iy + Sin[2 nu \[Pi] t]Ix)\
\>", "Text",
 CellChangeTimes->{{3.44763431276764*^9, 3.4476343888406477`*^9}, {
  3.4476344229860373`*^9, 3.447634428023567*^9}, {3.447634494381517*^9, 
  3.447634499539049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deltaP", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}], " ", "Iy"}], 
    "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}], "Ix"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{
  3.4476344340938673`*^9, {3.447634502028397*^9, 3.447634505076038*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"deltaP", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}], 
        ")"}]}]},
     {
      RowBox[{"deltaP", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "nu", " ", "\[Pi]", " ", "t"}], "]"}]}]}], 
        ")"}]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4476343982608633`*^9, 3.4476344354578323`*^9, 
  3.447634506733906*^9, 3.447682864504335*^9, 3.447693396465686*^9, 
  3.447694162076137*^9, 3.4479497025427923`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Density matrix for a population of coupled spins", "Section",
 CellChangeTimes->{{3.433245796563036*^9, 3.433245814727994*^9}, {
  3.433458459939721*^9, 3.433458461185195*^9}}],

Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<NMR`oneSpinLib`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4332457817776423`*^9, 3.433245790181415*^9}, {
  3.4332458375463743`*^9, 3.4332458435611267`*^9}, {3.433247151290065*^9, 
  3.4332471565535917`*^9}, {3.433458465144907*^9, 3.433458466553789*^9}}],

Cell[BoxData[
 RowBox[{"<<", "NMR`twoSpinLib`"}]], "Input",
 CellChangeTimes->{{3.487424012908142*^9, 3.487424014209046*^9}}],

Cell["The general form of the density matrix is:", "Text",
 CellChangeTimes->{{3.433247244098051*^9, 3.433247254789134*^9}}],

Cell["General form of the density matrix", "Text",
 CellChangeTimes->{{3.4334584919864492`*^9, 3.433458499296608*^9}}],

Cell[CellGroupData[{

Cell[BoxData["rhoGen"], "Input",
 CellChangeTimes->{{3.433458483148261*^9, 3.4334584844653873`*^9}}],

Cell[BoxData["rhoGen"], "Output",
 CellChangeTimes->{3.433458485497406*^9, 3.445965714275036*^9, 
  3.447634555147191*^9, 3.447682864700433*^9, 3.447693396734055*^9, 
  3.447694162278373*^9, 3.447949702740325*^9}]
}, Open  ]],

Cell["Equilibrium density matrix", "Text",
 CellChangeTimes->{{3.4334585204317417`*^9, 3.433458541436522*^9}}],

Cell[CellGroupData[{

Cell[BoxData["rhoEq"], "Input",
 CellChangeTimes->{{3.4334585432845573`*^9, 3.4334585449094543`*^9}}],

Cell[BoxData["rhoEq"], "Output",
 CellChangeTimes->{3.433458545952712*^9, 3.433460017914817*^9, 
  3.4459657143422003`*^9, 3.447634559512385*^9, 3.4476828647701883`*^9, 
  3.4476933968008537`*^9, 3.4476941623427067`*^9, 3.4479497028086033`*^9}]
}, Open  ]],

Cell["Compare with (deltaPi/2) Iz + (deltaPs/2) Sz", "Text",
 CellChangeTimes->{{3.4334585599916677`*^9, 3.4334586123806047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"deltaPi", "/", "2"}], ")"}], " ", "Iz"}], " ", "+", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"deltaPs", "/", "2"}], ")"}], " ", "Sz"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"deltaPi", " ", "Iz"}], "2"], "+", 
  FractionBox[
   RowBox[{"deltaPs", " ", "Sz"}], "2"]}]], "Output",
 CellChangeTimes->{3.433458618644734*^9, 3.4459657144084272`*^9, 
  3.447634578216483*^9, 3.447682864837726*^9, 3.4476933969744368`*^9, 
  3.447694162409844*^9, 3.447949702875506*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The rotation matrices :", "Subsection",
 CellChangeTimes->{{3.447686547908463*^9, 3.447686551432621*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RIx", "[", "a", "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.4476865541893263`*^9, 3.447686562194495*^9}, {
  3.447686597340951*^9, 3.447686619847979*^9}, {3.447686677291561*^9, 
  3.447686680110478*^9}}],

Cell[BoxData[
 RowBox[{"RIx", "[", "a", "]"}]], "Output",
 CellChangeTimes->{
  3.447686564521245*^9, {3.4476866025943613`*^9, 3.44768662058405*^9}, 
   3.447686681517048*^9, 3.4476933970517187`*^9, 3.447694162477251*^9, 
   3.447949702942288*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RIxInv", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.447686684638914*^9, 3.4476866889501343`*^9}}],

Cell[BoxData[
 RowBox[{"RIxInv", "[", "a", "]"}]], "Output",
 CellChangeTimes->{3.447686689867587*^9, 3.4476933971184464`*^9, 
  3.4476941625682917`*^9, 3.447949703075193*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RSx", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.447686698033687*^9, 3.447686701626296*^9}}],

Cell[BoxData[
 RowBox[{"RSx", "[", "a", "]"}]], "Output",
 CellChangeTimes->{3.447686703425507*^9, 3.447693397233392*^9, 
  3.447694162646399*^9, 3.4479497031945257`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RSxInv", "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.447686705249172*^9, 3.447686718361023*^9}}],

Cell[BoxData[
 RowBox[{"RSxInv", "[", "a", "]"}]], "Output",
 CellChangeTimes->{3.4476867202468653`*^9, 3.447693397351519*^9, 
  3.447694162858275*^9, 3.447949703263645*^9}]
}, Open  ]],

Cell["\<\
The effects of rotations on the density matrix are calculated in the same \
fashion as for the 1-spin case. For a pi/2 pulse to the S-spin applied to the \
equilibrium state:\
\>", "Text",
 CellChangeTimes->{{3.447686733423367*^9, 3.447686800265368*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RIx", "[", 
    RowBox[{"Pi", "/", "2"}], "]"}], ".", "rhoEq", ".", 
   RowBox[{"RIxInv", "[", 
    RowBox[{"Pi", "/", "2"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.447686804189794*^9, 3.447686853722267*^9}, 
   3.447687065182047*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447686836559061*^9, 3.4476868438820887`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RIx", "[", 
   FractionBox["\[Pi]", "2"], "]"}], ".", "rhoEq", ".", 
  RowBox[{"RIxInv", "[", 
   FractionBox["\[Pi]", "2"], "]"}]}]], "Output",
 CellChangeTimes->{{3.447686845034923*^9, 3.4476868580563173`*^9}, 
   3.447687069244175*^9, 3.4476933975005207`*^9, 3.44769416298624*^9, 
   3.447949703345393*^9}]
}, Open  ]],

Cell["\<\
There are functions in the twoSpinLib package to calculate all of the \
magnetization components and correlations from the density matrix:\
\>", "Text",
 CellChangeTimes->{{3.447686865018332*^9, 3.4476869286856728`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox["deltaPs", "4"], "0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}], "0"},
      {"0", 
       RowBox[{"-", 
        FractionBox["deltaPs", "4"]}], "0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}]},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], "0", 
       FractionBox["deltaPs", "4"], "0"},
      {"0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], "0", 
       RowBox[{"-", 
        FractionBox["deltaPs", "4"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], "]"}]], "Input",
 CellChangeTimes->{{3.447686932443718*^9, 3.447686948683107*^9}}],

Cell[BoxData[
 RowBox[{"allMagRho", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox["deltaPs", "4"], ",", "0", ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}], ",", "0"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", 
       FractionBox["deltaPs", "4"]}], ",", "0", ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], ",", "0", ",", 
      FractionBox["deltaPs", "4"], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], ",", "0", ",", 
      RowBox[{"-", 
       FractionBox["deltaPs", "4"]}]}], "}"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.447949703432638*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorRho", "[", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox["deltaPs", "4"], "0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}], "0"},
      {"0", 
       RowBox[{"-", 
        FractionBox["deltaPs", "4"]}], "0", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}]},
      {
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], "0", 
       FractionBox["deltaPs", "4"], "0"},
      {"0", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], "0", 
       RowBox[{"-", 
        FractionBox["deltaPs", "4"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], "]"}]], "Input",
 CellChangeTimes->{{3.4476869552737226`*^9, 3.44768696299737*^9}}],

Cell[BoxData[
 RowBox[{"allCorRho", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox["deltaPs", "4"], ",", "0", ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}], ",", "0"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", 
       FractionBox["deltaPs", "4"]}], ",", "0", ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], ",", "0", ",", 
      FractionBox["deltaPs", "4"], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "deltaPi"}], "4"], ",", "0", ",", 
      RowBox[{"-", 
       FractionBox["deltaPs", "4"]}]}], "}"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.44794970347602*^9}]
}, Open  ]],

Cell["\<\
There are also functions to calculate the effects of pulses, for instance:\
\>", "Text",
 CellChangeTimes->{{3.447687135216497*^9, 3.4476871613511267`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rhoPi2Ix", "[", "rhoEq", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.447687165419642*^9, 3.447687189444203*^9}, 
   3.447687225499234*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447687193782556*^9, 3.447687208152773*^9}}],

Cell[BoxData[
 RowBox[{"rhoPi2Ix", "[", "rhoEq", "]"}]], "Output",
 CellChangeTimes->{{3.4476872091533546`*^9, 3.4476872293805227`*^9}, 
   3.447693398036027*^9, 3.4476941634906883`*^9, 3.447949703538685*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time evolution", "Subsection",
 CellChangeTimes->{{3.447687250360757*^9, 3.447687253348145*^9}}],

Cell["\<\
The Hamiltonian matrix and its inverse are expressed in terms of the Larmor \
frequencies, nuI and nuS, and the coupling constant, J:\
\>", "Text",
 CellChangeTimes->{{3.447687264855413*^9, 3.447687301715019*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H", "[", 
  RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}]], "Input",
 CellChangeTimes->{{3.44768730450878*^9, 3.44768735487541*^9}}],

Cell[BoxData[
 RowBox[{"H", "[", 
  RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}]], "Output",
 CellChangeTimes->{3.447687318416368*^9, 3.447687356138626*^9, 
  3.4476933981688538`*^9, 3.4476941635766077`*^9, 3.447949703610599*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hinv", "[", 
  RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}]], "Input",
 CellChangeTimes->{{3.447687361311701*^9, 3.44768737732926*^9}}],

Cell[BoxData[
 RowBox[{"Hinv", "[", 
  RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}]], "Output",
 CellChangeTimes->{3.447687378981147*^9, 3.4476933982379923`*^9, 
  3.447694163691877*^9, 3.447949703793062*^9}]
}, Open  ]],

Cell["\<\
Time evolution of the density matrix, written in its general form, is:\
\>", "Text",
 CellChangeTimes->{{3.4476874661133757`*^9, 3.4476874939253473`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H", "[", 
    RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}], ".", "rhoGen", 
   ".", 
   RowBox[{"Hinv", "[", 
    RowBox[{"t", ",", "nuI", ",", "nuS", ",", " ", "J"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.447687524011801*^9, 3.44768757870184*^9}, 
   3.447687634519932*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447687589059461*^9, 3.447687593521797*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}], ".", "rhoGen", ".", 
  RowBox[{"Hinv", "[", 
   RowBox[{"t", ",", "nuI", ",", "nuS", ",", "J"}], "]"}]}]], "Output",
 CellChangeTimes->{3.447687594388582*^9, 3.447693398450428*^9, 
  3.4476941640311728`*^9, 3.447949703877132*^9}]
}, Open  ]],

Cell["\<\
A function for calculating the time evolution of the density matrix:\
\>", "Text",
 CellChangeTimes->{{3.4476876582039423`*^9, 3.447687670792183*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rhoTime", "[", 
   RowBox[{"rhoGen", ",", "t"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.447687676434258*^9, 3.447687696389724*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447687699080823*^9, 3.447687713176517*^9}}],

Cell[BoxData[
 RowBox[{"rhoTime", "[", 
  RowBox[{"rhoGen", ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.447687713951427*^9, 3.4476933985401983`*^9, 
  3.447694164161014*^9, 3.447949703957675*^9}]
}, Open  ]],

Cell["\<\
A simple experiment: a pulse to both I and S, followed by time evolution:\
\>", "Text",
 CellChangeTimes->{{3.447687775833056*^9, 3.447687804988287*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rho1", " ", "=", " ", 
   RowBox[{"rhoPi2x", "[", "rhoEq", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.447687809498971*^9, 3.447687870257222*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447687873297084*^9, 3.447687883707554*^9}}],

Cell[BoxData[
 RowBox[{"rhoPi2x", "[", "rhoEq", "]"}]], "Output",
 CellChangeTimes->{3.4476878844729013`*^9, 3.447693398618393*^9, 
  3.44769416430861*^9, 3.44794970404607*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "rho1", "]"}]], "Input",
 CellChangeTimes->{{3.447687891852778*^9, 3.4476879105194883`*^9}}],

Cell[BoxData[
 RowBox[{"allMagRho", "[", 
  RowBox[{"rhoPi2x", "[", "rhoEq", "]"}], "]"}]], "Output",
 CellChangeTimes->{3.4479497041126947`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorRho", "[", "rho1", "]"}]], "Input",
 CellChangeTimes->{{3.4476879131807947`*^9, 3.447687926862191*^9}}],

Cell[BoxData[
 RowBox[{"allCorRho", "[", 
  RowBox[{"rhoPi2x", "[", "rhoEq", "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949704158454*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rho2", "=", " ", 
   RowBox[{"rhoTime", "[", 
    RowBox[{"rho1", ",", "t"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.447687962893778*^9, 3.447688003689466*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447688005825676*^9, 3.447688012239791*^9}}],

Cell[BoxData[
 RowBox[{"rhoTime", "[", 
  RowBox[{
   RowBox[{"rhoPi2x", "[", "rhoEq", "]"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.447688013255015*^9, 3.447693399083253*^9, 
  3.447694165097219*^9, 3.447949704207302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "rho2", "]"}]], "Input",
 CellChangeTimes->{{3.44768801770045*^9, 3.447688037640287*^9}}],

Cell[BoxData[
 RowBox[{"allMagRho", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{
    RowBox[{"rhoPi2x", "[", "rhoEq", "]"}], ",", "t"}], "]"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.447949704278427*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.4476877019880037`*^9, 3.447687702752262*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Representation of the density matrix as a linear combination of operator \
matrices\
\>", "Subsection",
 CellChangeTimes->{{3.447683021958441*^9, 3.4476830489258947`*^9}}],

Cell["\<\
The density matrix can be represented as a linear combination of the matrices \
for the 6 magnetization operators and the 9 product operators, plus the \
identity matrix.  When this is done, the contribution of each term to the \
observable magnetization components can easily be calculated from the \
coefficients of the matrices.  

For instance, consider a density matrix that is composed simply of Ix.  If we \
calculate the average magnetization components and correlations for a state \
represented by this density matrix:\
\>", "Text",
 CellChangeTimes->{{3.447683053624647*^9, 3.447683331797525*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "Ix", "]"}]], "Input",
 CellChangeTimes->{{3.44768333584381*^9, 3.447683349285935*^9}}],

Cell[BoxData[
 RowBox[{"allMagRho", "[", "Ix", "]"}]], "Output",
 CellChangeTimes->{3.447949704341064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorRho", "[", "Ix", "]"}]], "Input",
 CellChangeTimes->{{3.447683352870015*^9, 3.44768336433393*^9}}],

Cell[BoxData[
 RowBox[{"allCorRho", "[", "Ix", "]"}]], "Output",
 CellChangeTimes->{3.4479497043748283`*^9}]
}, Open  ]],

Cell["\<\
The only non-zero average is <Ix> = 1.  Thus, the average is simply the \
coefficient of the matrix.  This is not a valid result for a real state, \
though, which simply means that Ix is not a density matrix for a real state.

Consider a density matrix composed of IxSy:\
\>", "Text",
 CellChangeTimes->{{3.4476833996182823`*^9, 3.44768354311935*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", "IxSy", "]"}]], "Input",
 CellChangeTimes->{{3.447683546331539*^9, 3.447683558614133*^9}}],

Cell[BoxData[
 RowBox[{"allMagRho", "[", "IxSy", "]"}]], "Output",
 CellChangeTimes->{3.4479497044079933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorRho", "[", "IxSy", "]"}]], "Input",
 CellChangeTimes->{{3.4476835620650253`*^9, 3.447683570831211*^9}}],

Cell[BoxData[
 RowBox[{"allCorRho", "[", "IxSy", "]"}]], "Output",
 CellChangeTimes->{3.447949704440544*^9}]
}, Open  ]],

Cell["\<\
In this case, the average value of IxSy is 1/4 of the coefficient.  

If we write a linear combination of Ix and IxSy\
\>", "Text",
 CellChangeTimes->{{3.447683614636347*^9, 3.4476836709076223`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allMagRho", "[", 
  RowBox[{"Ix", "+", "IxSy"}], "]"}]], "Input",
 CellChangeTimes->{{3.4476836775580378`*^9, 3.4476836956361094`*^9}}],

Cell[BoxData[
 RowBox[{"allMagRho", "[", 
  RowBox[{"Ix", "+", "IxSy"}], "]"}]], "Output",
 CellChangeTimes->{3.447949704474022*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allCorRho", "[", 
  RowBox[{"Ix", "+", "IxSy"}], "]"}]], "Input",
 CellChangeTimes->{{3.447683698681546*^9, 3.447683710419595*^9}}],

Cell[BoxData[
 RowBox[{"allCorRho", "[", 
  RowBox[{"Ix", "+", "IxSy"}], "]"}]], "Output",
 CellChangeTimes->{3.4479497045074587`*^9}]
}, Open  ]],

Cell["\<\
The average values are simply added together.  In general, the average value \
for an observable magnetization component is equal to the corresponding \
coefficient in the operator representation, and the average value for a \
correlation is equal to 1/4 of the corresponding coefficient.\
\>", "Text",
 CellChangeTimes->{{3.447683729060391*^9, 3.447683741537537*^9}, {
  3.447684079064159*^9, 3.4476841087990227`*^9}, {3.447684144438099*^9, 
  3.4476842008054657`*^9}}],

Cell["\<\
The twoSpinLib package includes a special function that returns the non-zero \
components of the operator representation for any density matrix:\
\>", "Text",
 CellChangeTimes->{{3.447684283874901*^9, 3.447684348536118*^9}, 
   3.4476880912474413`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", "Ix", "]"}]], "Input",
 CellChangeTimes->{{3.44768435528937*^9, 3.447684363697063*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", "Ix", "]"}]], "Output",
 CellChangeTimes->{3.447949704541871*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"Ix", " ", "+", " ", "IxSy"}], "]"}]], "Input",
 CellChangeTimes->{{3.447684369507506*^9, 3.4476843826327133`*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"Ix", "+", "IxSy"}], "]"}]], "Output",
 CellChangeTimes->{3.4479497046141243`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", "rhoEq", "]"}]], "Input",
 CellChangeTimes->{{3.447684426193576*^9, 3.44768444834276*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", "rhoEq", "]"}]], "Output",
 CellChangeTimes->{3.447949704664236*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rules for operator basis calculations", "Subsection",
 CellChangeTimes->{{3.4476845029390697`*^9, 3.447684520299322*^9}}],

Cell["\<\
The functions for calculating the effects of pulses and evolution periods on \
the density matrix can be applied to any of the operator matrices do \
establish the rules for their transformations.  

For instance for a pulse along the x'-axis:\
\>", "Text",
 CellChangeTimes->{{3.447684526023511*^9, 3.44768454657023*^9}, {
  3.447684593776951*^9, 3.447684721845269*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rhoPulseIx", "[", 
   RowBox[{"Ix", ",", "a"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.447684899042221*^9, 3.4476849107353773`*^9}, 
   3.4476870513581247`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.447684916121697*^9, 3.447684919891733*^9}}],

Cell[BoxData[
 RowBox[{"rhoPulseIx", "[", 
  RowBox[{"Ix", ",", "a"}], "]"}]], "Output",
 CellChangeTimes->{3.4476849207778273`*^9, 3.447687058783113*^9, 
  3.4476934011589317`*^9, 3.4476941670189877`*^9, 3.447949704851775*^9}]
}, Open  ]],

Cell["\<\
This is just the starting matrix Ix, as expected.  To confirm this, use the \
opBasisRep function\
\>", "Text",
 CellChangeTimes->{{3.447684927180019*^9, 3.447684981909816*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoPulseIx", "[", 
   RowBox[{"Ix", ",", "a"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4476849849511538`*^9, 3.447685001454196*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoPulseIx", "[", 
   RowBox[{"Ix", ",", "a"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949704912512*^9}]
}, Open  ]],

Cell["For the same pulse applied to Iy:", "Text",
 CellChangeTimes->{{3.447685024114193*^9, 3.447685037228273*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoPulseIx", "[", 
   RowBox[{"Iy", ",", "a"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.447685046523266*^9, 3.4476850757501802`*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoPulseIx", "[", 
   RowBox[{"Iy", ",", "a"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949704980102*^9}]
}, Open  ]],

Cell["For the analogous pulse to the S-spin:", "Text",
 CellChangeTimes->{{3.447685097401061*^9, 3.447685113521975*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoPulseSx", "[", 
   RowBox[{"Sy", ",", "a"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.447685125926749*^9, 3.447685130059957*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoPulseSx", "[", 
   RowBox[{"Sy", ",", "a"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705024914*^9}]
}, Open  ]],

Cell["Chemical-shift evolution", "Text",
 CellChangeTimes->{{3.447685185955387*^9, 3.44768519831166*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"Ix", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"J", "\[Rule]", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447685212357377*^9, 3.447685294695199*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"Ix", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705058668*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"Sx", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"J", "\[Rule]", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.4476860813717546`*^9}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"Sx", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705092455*^9}]
}, Open  ]],

Cell["For a product operator:", "Text",
 CellChangeTimes->{{3.447686104152341*^9, 3.447686111397162*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"IySx", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"J", "\[Rule]", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4476861281872387`*^9, 3.447686128479065*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"IySx", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705125822*^9}]
}, Open  ]],

Cell["Evolution under the influence of scalar coupling only", "Text",
 CellChangeTimes->{{3.447686181525049*^9, 3.447686207018457*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"Ix", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nuI", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"nuS", "\[Rule]", " ", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447683584095521*^9, 3.447683585735421*^9}, 
   3.4476862159335318`*^9}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"Ix", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705158916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"IxSz", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nuI", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"nuS", "\[Rule]", " ", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447686246632393*^9, 3.447686247116762*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"IxSz", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705192071*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"IzSx", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nuI", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"nuS", "\[Rule]", " ", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447686337380417*^9, 3.4476863393146687`*^9}}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"IzSx", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705238699*^9}]
}, Open  ]],

Cell["\<\
Transverse correlations do not change during scalar coupling evolution\
\>", "Text",
 CellChangeTimes->{{3.4476862881539383`*^9, 3.447686312759247*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{
   RowBox[{"rhoTime", "[", 
    RowBox[{"IxSy", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nuI", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"nuS", "\[Rule]", " ", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.4476863219885063`*^9}],

Cell[BoxData[
 RowBox[{"opBasisRep", "[", 
  RowBox[{"rhoTime", "[", 
   RowBox[{"IxSy", ",", "t"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.447949705276237*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{973, 841},
WindowMargins->{{324, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"7.0 for Mac OS X PowerPC (32-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Text"], FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> 
    "Plain", FontSlant -> "Plain"]}, Visible -> False, FrontEndVersion -> 
  "7.0 for Mac OS X PowerPC (32-bit) (February 18, 2009)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3447928320-2751242"->{
  Cell[18958, 498, 253, 5, 49, "Print",
   CellTags->"Info3447928320-2751242"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3447928320-2751242", 412636, 11707}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 465, 12, 217, "Title"],
Cell[CellGroupData[{
Cell[1057, 38, 117, 1, 83, "Section"],
Cell[1177, 41, 4247, 65, 764, "Text"],
Cell[CellGroupData[{
Cell[5449, 110, 173, 6, 42, "Subsection"],
Cell[5625, 118, 1906, 33, 314, "Text"],
Cell[CellGroupData[{
Cell[7556, 155, 246, 7, 33, "Input"],
Cell[7805, 164, 328, 9, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8170, 178, 259, 8, 33, "Input"],
Cell[8432, 188, 1059, 25, 53, "Output"]
}, Open  ]],
Cell[9506, 216, 308, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[9839, 225, 115, 2, 33, "Input"],
Cell[9957, 229, 188, 3, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10182, 237, 69, 1, 33, "Input"],
Cell[10254, 240, 195, 3, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10486, 248, 122, 2, 33, "Input"],
Cell[10611, 252, 192, 3, 33, "Output"]
}, Open  ]],
Cell[10818, 258, 498, 10, 70, "Text"],
Cell[CellGroupData[{
Cell[11341, 272, 231, 6, 33, "Input"],
Cell[11575, 280, 370, 8, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11982, 293, 129, 2, 33, "Input"],
Cell[12114, 297, 610, 16, 53, "Output"]
}, Open  ]],
Cell[12739, 316, 166, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[12930, 322, 122, 2, 33, "Input"],
Cell[13055, 326, 343, 7, 33, "Output"]
}, Open  ]],
Cell[13413, 336, 109, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[13547, 342, 96, 1, 33, "Input"],
Cell[13646, 345, 144, 2, 33, "Output"]
}, Open  ]],
Cell[13805, 350, 158, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[13988, 357, 115, 2, 33, "Input"],
Cell[14106, 361, 161, 3, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14304, 369, 183, 4, 33, "Input"],
Cell[14490, 375, 164, 3, 33, "Output"]
}, Open  ]],
Cell[14669, 381, 105, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[14799, 386, 263, 7, 33, "Input"],
Cell[15065, 395, 146, 2, 33, "Output"]
}, Open  ]],
Cell[15226, 400, 158, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[15409, 407, 71, 1, 33, "Input"],
Cell[15483, 410, 141, 2, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15661, 417, 69, 1, 33, "Input"],
Cell[15733, 420, 139, 2, 33, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15933, 429, 134, 1, 83, "Section"],
Cell[CellGroupData[{
Cell[16092, 434, 116, 1, 42, "Subsection"],
Cell[16211, 437, 94, 1, 33, "Input"],
Cell[16308, 440, 82, 1, 33, "Input"],
Cell[16393, 443, 101, 2, 33, "Input"],
Cell[16497, 447, 162, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[16684, 454, 125, 2, 33, "Input"],
Cell[16812, 458, 1791, 27, 91, "Output"]
}, Open  ]],
Cell[18618, 488, 194, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[18837, 494, 118, 2, 33, "Input"],
Cell[18958, 498, 253, 5, 49, "Print",
 CellTags->"Info3447928320-2751242"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19260, 509, 103, 1, 42, "Subsection"],
Cell[19366, 512, 1052, 33, 148, "Text"],
Cell[CellGroupData[{
Cell[20443, 549, 98, 1, 33, "Input"],
Cell[20544, 552, 488, 8, 33, "Output"]
}, Open  ]],
Cell[21047, 563, 537, 16, 52, "Text"],
Cell[CellGroupData[{
Cell[21609, 583, 96, 1, 33, "Input"],
Cell[21708, 586, 468, 8, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22213, 599, 97, 1, 33, "Input"],
Cell[22313, 602, 469, 8, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22831, 616, 99, 1, 42, "Subsection"],
Cell[22933, 619, 284, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[23242, 628, 96, 1, 33, "Input"],
Cell[23341, 631, 1002, 25, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24380, 661, 94, 1, 33, "Input"],
Cell[24477, 664, 1044, 26, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25558, 695, 96, 1, 33, "Input"],
Cell[25657, 698, 1025, 26, 77, "Output"]
}, Open  ]],
Cell[26697, 727, 318, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[27040, 736, 119, 2, 33, "Input"],
Cell[27162, 740, 496, 9, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27695, 754, 121, 2, 33, "Input"],
Cell[27819, 758, 488, 9, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28344, 772, 119, 2, 33, "Input"],
Cell[28466, 776, 464, 9, 53, "Output"]
}, Open  ]],
Cell[28945, 788, 468, 8, 70, "Text"],
Cell[CellGroupData[{
Cell[29438, 800, 119, 2, 33, "Input"],
Cell[29560, 804, 483, 10, 53, "Output"]
}, Open  ]],
Cell[30058, 817, 360, 8, 51, "Text"],
Cell[CellGroupData[{
Cell[30443, 829, 131, 2, 33, "Input"],
Cell[30577, 833, 748, 19, 53, "Output"]
}, Open  ]],
Cell[31340, 855, 255, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[31620, 864, 131, 2, 33, "Input"],
Cell[31754, 868, 746, 20, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32537, 893, 133, 2, 33, "Input"],
Cell[32673, 897, 766, 21, 53, "Output"]
}, Open  ]],
Cell[33454, 921, 430, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[33909, 934, 248, 6, 33, "Input"],
Cell[34160, 942, 536, 13, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34733, 960, 153, 4, 33, "Input"],
Cell[34889, 966, 514, 12, 59, "Output"]
}, Open  ]],
Cell[35418, 981, 108, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[35551, 986, 186, 4, 33, "Input"],
Cell[35740, 992, 527, 12, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36304, 1009, 183, 5, 33, "Input"],
Cell[36490, 1016, 555, 13, 59, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37094, 1035, 128, 1, 42, "Subsection"],
Cell[37225, 1038, 702, 13, 89, "Text"],
Cell[CellGroupData[{
Cell[37952, 1055, 218, 5, 33, "Input"],
Cell[38173, 1062, 422, 7, 53, "Output"]
}, Open  ]],
Cell[38610, 1072, 219, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[38854, 1081, 155, 3, 33, "Input"],
Cell[39012, 1086, 421, 7, 53, "Output"]
}, Open  ]],
Cell[39448, 1096, 726, 11, 107, "Text"],
Cell[CellGroupData[{
Cell[40199, 1111, 155, 3, 33, "Input"],
Cell[40357, 1116, 605, 13, 53, "Output"]
}, Open  ]],
Cell[40977, 1132, 227, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[41229, 1140, 131, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[41385, 1146, 556, 10, 25, "Print"],
Cell[41944, 1158, 556, 10, 25, "Print"],
Cell[42503, 1170, 593, 12, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43145, 1188, 133, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[43303, 1194, 519, 10, 25, "Print"],
Cell[43825, 1206, 520, 10, 25, "Print"],
Cell[44348, 1218, 580, 13, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[44977, 1237, 135, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[45137, 1243, 894, 20, 45, "Print"],
Cell[46034, 1265, 993, 21, 45, "Print"],
Cell[47030, 1288, 893, 20, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[47950, 1312, 182, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[48157, 1320, 65, 1, 33, "Input"],
Cell[48225, 1323, 716, 19, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48978, 1347, 285, 7, 33, "Input"],
Cell[CellGroupData[{
Cell[49288, 1358, 589, 13, 45, "Print"],
Cell[49880, 1373, 531, 10, 25, "Print"],
Cell[50414, 1385, 529, 10, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50992, 1401, 187, 5, 33, "Input"],
Cell[CellGroupData[{
Cell[51204, 1410, 541, 11, 45, "Print"],
Cell[51748, 1423, 500, 9, 25, "Print"],
Cell[52251, 1434, 500, 9, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52800, 1449, 135, 2, 33, "Input"],
Cell[52938, 1453, 745, 20, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53720, 1478, 201, 5, 33, "Input"],
Cell[CellGroupData[{
Cell[53946, 1487, 191, 5, 25, "Print"],
Cell[54140, 1494, 252, 8, 45, "Print"],
Cell[54395, 1504, 192, 5, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54636, 1515, 224, 7, 33, "Input"],
Cell[CellGroupData[{
Cell[54885, 1526, 494, 9, 25, "Print"],
Cell[55382, 1537, 532, 11, 45, "Print"],
Cell[55917, 1550, 494, 9, 25, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[56484, 1567, 333, 4, 83, "Section"],
Cell[56820, 1573, 243, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[57088, 1583, 490, 13, 33, "Input"],
Cell[57581, 1598, 537, 13, 57, "Output"]
}, Open  ]],
Cell[58133, 1614, 196, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[58354, 1622, 239, 6, 33, "Input"],
Cell[58596, 1630, 339, 7, 54, "Output"]
}, Open  ]],
Cell[58950, 1640, 112, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[59087, 1645, 292, 8, 33, "Input"],
Cell[59382, 1655, 342, 8, 54, "Output"]
}, Open  ]],
Cell[59739, 1666, 141, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[59905, 1671, 313, 8, 33, "Input"],
Cell[60221, 1681, 341, 7, 54, "Output"]
}, Open  ]],
Cell[60577, 1691, 116, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[60718, 1696, 436, 12, 33, "Input"],
Cell[61157, 1710, 328, 7, 53, "Output"]
}, Open  ]],
Cell[61500, 1720, 103, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[61628, 1725, 340, 10, 33, "Input"],
Cell[61971, 1737, 366, 9, 54, "Output"]
}, Open  ]],
Cell[62352, 1749, 108, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[62485, 1754, 173, 5, 33, "Input"],
Cell[62661, 1761, 294, 6, 33, "Output"]
}, Open  ]],
Cell[62970, 1770, 111, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[63106, 1776, 442, 13, 56, "Input"],
Cell[63551, 1791, 386, 9, 54, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63986, 1806, 226, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[64237, 1813, 143, 2, 42, "Subsection"],
Cell[64383, 1817, 307, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[64715, 1826, 219, 4, 33, "Input"],
Cell[64937, 1832, 1302, 33, 81, "Output"]
}, Open  ]],
Cell[66254, 1868, 127, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[66406, 1873, 172, 3, 33, "Input"],
Cell[66581, 1878, 1240, 32, 81, "Output"]
}, Open  ]],
Cell[67836, 1913, 140, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[68001, 1918, 317, 6, 33, "Input"],
Cell[68321, 1926, 606, 13, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68964, 1944, 262, 8, 62, "Input"],
Cell[CellGroupData[{
Cell[69251, 1956, 523, 10, 25, "Print"],
Cell[69777, 1968, 564, 12, 45, "Print"],
Cell[70344, 1982, 523, 10, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[70894, 1996, 246, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[71165, 2005, 276, 6, 33, "Input"],
Cell[71444, 2013, 558, 13, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72039, 2031, 275, 9, 62, "Input"],
Cell[CellGroupData[{
Cell[72339, 2044, 558, 12, 45, "Print"],
Cell[72900, 2058, 498, 9, 25, "Print"],
Cell[73401, 2069, 498, 9, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[73926, 2082, 444, 15, 239, "Text"],
Cell[CellGroupData[{
Cell[74395, 2101, 179, 4, 33, "Input"],
Cell[74577, 2107, 505, 11, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75119, 2123, 131, 2, 33, "Input"],
Cell[75253, 2127, 540, 12, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75830, 2144, 131, 2, 33, "Input"],
Cell[75964, 2148, 199, 7, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76200, 2160, 133, 2, 33, "Input"],
Cell[76336, 2164, 484, 11, 59, "Output"]
}, Open  ]],
Cell[76835, 2178, 206, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[77066, 2186, 167, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[77258, 2193, 558, 12, 45, "Print"],
Cell[77819, 2207, 500, 9, 25, "Print"],
Cell[78322, 2218, 498, 9, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78869, 2233, 169, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[79063, 2240, 536, 11, 45, "Print"],
Cell[79602, 2253, 499, 9, 25, "Print"],
Cell[80104, 2264, 497, 9, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80650, 2279, 105, 1, 30, "Subsubsection"],
Cell[80758, 2282, 1381, 24, 257, "Text"],
Cell[CellGroupData[{
Cell[82164, 2310, 148, 3, 33, "Input"],
Cell[82315, 2315, 1171, 27, 62, "Output"]
}, Open  ]],
Cell[83501, 2345, 163, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[83689, 2351, 173, 4, 33, "Input"],
Cell[83865, 2357, 704, 15, 42, "Output"]
}, Open  ]],
Cell[84584, 2375, 390, 7, 70, "Text"],
Cell[CellGroupData[{
Cell[84999, 2386, 139, 4, 33, "Input"],
Cell[85141, 2392, 757, 17, 63, "Output"]
}, Open  ]],
Cell[85913, 2412, 243, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[86181, 2421, 291, 6, 33, "Input"],
Cell[86475, 2429, 885, 19, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87397, 2453, 533, 15, 66, "Input"],
Cell[CellGroupData[{
Cell[87955, 2472, 720, 16, 45, "Print"],
Cell[88678, 2490, 720, 16, 45, "Print"],
Cell[89401, 2508, 520, 10, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[89948, 2522, 157, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[90130, 2529, 191, 4, 33, "Input"],
Cell[90324, 2535, 735, 17, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91096, 2557, 130, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[91251, 2563, 689, 15, 45, "Print"],
Cell[91943, 2580, 689, 15, 45, "Print"],
Cell[92635, 2597, 472, 9, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[93134, 2610, 290, 6, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93485, 2623, 138, 1, 83, "Section"],
Cell[93626, 2626, 146, 4, 51, "Text"],
Cell[93775, 2632, 199, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[93999, 2639, 127, 2, 33, "Input"],
Cell[94129, 2643, 588, 10, 47, "Message"],
Cell[94720, 2655, 594, 10, 47, "Message"],
Cell[95317, 2667, 596, 10, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95950, 2682, 149, 2, 33, "Input"],
Cell[96102, 2686, 2994, 44, 205, "Output"]
}, Open  ]],
Cell[99111, 2733, 390, 8, 70, "Text"],
Cell[CellGroupData[{
Cell[99526, 2745, 97, 1, 33, "Input"],
Cell[99626, 2748, 393, 7, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100056, 2760, 97, 1, 33, "Input"],
Cell[100156, 2763, 398, 7, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100591, 2775, 101, 1, 33, "Input"],
Cell[100695, 2778, 396, 7, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101128, 2790, 99, 1, 33, "Input"],
Cell[101230, 2793, 392, 7, 33, "Output"]
}, Open  ]],
Cell[101637, 2803, 158, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[101820, 2810, 102, 1, 33, "Input"],
Cell[101925, 2813, 403, 7, 33, "Output"]
}, Open  ]],
Cell[102343, 2823, 126, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[102494, 2828, 94, 1, 33, "Input"],
Cell[102591, 2831, 1053, 28, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103681, 2864, 94, 1, 33, "Input"],
Cell[103778, 2867, 1154, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104969, 2902, 94, 1, 33, "Input"],
Cell[105066, 2905, 1105, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106208, 2940, 94, 1, 33, "Input"],
Cell[106305, 2943, 1059, 28, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107401, 2976, 96, 1, 33, "Input"],
Cell[107500, 2979, 1146, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108683, 3014, 94, 1, 33, "Input"],
Cell[108780, 3017, 1101, 30, 139, "Output"]
}, Open  ]],
Cell[109896, 3050, 375, 6, 70, "Text"],
Cell[CellGroupData[{
Cell[110296, 3060, 173, 4, 33, "Input"],
Cell[110472, 3066, 380, 6, 53, "Output"]
}, Open  ]],
Cell[110867, 3075, 217, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[111109, 3083, 132, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[111266, 3089, 645, 12, 25, "Print"],
Cell[111914, 3103, 645, 12, 25, "Print"],
Cell[112562, 3117, 719, 15, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[113308, 3136, 281, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[113614, 3146, 132, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[113771, 3152, 608, 11, 25, "Print"],
Cell[114382, 3165, 610, 11, 25, "Print"],
Cell[114995, 3178, 705, 15, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[115727, 3197, 911, 15, 107, "Text"],
Cell[CellGroupData[{
Cell[116663, 3216, 124, 2, 33, "Input"],
Cell[116790, 3220, 1601, 44, 147, "Output"]
}, Open  ]],
Cell[118406, 3267, 326, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[118757, 3277, 285, 6, 33, "Input"],
Cell[119045, 3285, 660, 13, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119742, 3303, 130, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[119897, 3309, 723, 13, 25, "Print"],
Cell[120623, 3324, 764, 15, 45, "Print"],
Cell[121390, 3341, 758, 14, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[122175, 3359, 543, 10, 89, "Text"],
Cell[CellGroupData[{
Cell[122743, 3373, 341, 6, 33, "Input"],
Cell[123087, 3381, 647, 13, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123771, 3399, 131, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[123927, 3405, 680, 12, 25, "Print"],
Cell[124610, 3419, 719, 14, 45, "Print"],
Cell[125332, 3435, 736, 14, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[126095, 3453, 235, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[126355, 3461, 330, 8, 33, "Input"],
Cell[126688, 3471, 690, 14, 53, "Output"]
}, Open  ]],
Cell[127393, 3488, 285, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[127703, 3497, 239, 6, 33, "Input"],
Cell[127945, 3505, 594, 13, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128576, 3523, 161, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[128762, 3530, 647, 12, 25, "Print"],
Cell[129412, 3544, 720, 15, 45, "Print"],
Cell[130135, 3561, 647, 12, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[130809, 3577, 150, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[130984, 3584, 351, 9, 33, "Input"],
Cell[131338, 3595, 578, 12, 59, "Output"]
}, Open  ]],
Cell[131931, 3610, 212, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[132168, 3618, 133, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[132326, 3624, 688, 12, 25, "Print"],
Cell[133017, 3638, 686, 12, 25, "Print"],
Cell[133706, 3652, 686, 12, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[134419, 3668, 319, 6, 51, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134775, 3679, 119, 1, 83, "Section"],
Cell[134897, 3682, 181, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[135103, 3690, 117, 2, 33, "Input"],
Cell[135223, 3694, 1060, 28, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136320, 3727, 117, 2, 33, "Input"],
Cell[136440, 3731, 1149, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137626, 3766, 117, 2, 33, "Input"],
Cell[137746, 3770, 1099, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138882, 3805, 119, 2, 33, "Input"],
Cell[139004, 3809, 1152, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140193, 3844, 117, 2, 33, "Input"],
Cell[140313, 3848, 1100, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141450, 3883, 117, 2, 33, "Input"],
Cell[141570, 3887, 1150, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142757, 3922, 142, 3, 33, "Input"],
Cell[142902, 3927, 1104, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144043, 3962, 119, 2, 33, "Input"],
Cell[144165, 3966, 1156, 30, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145358, 4001, 117, 2, 33, "Input"],
Cell[145478, 4005, 1103, 30, 139, "Output"]
}, Open  ]],
Cell[146596, 4038, 448, 8, 70, "Text"],
Cell[CellGroupData[{
Cell[147069, 4050, 179, 4, 33, "Input"],
Cell[147251, 4056, 382, 6, 53, "Output"]
}, Open  ]],
Cell[147648, 4065, 234, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[147907, 4074, 181, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[148113, 4081, 663, 13, 25, "Print"],
Cell[148779, 4096, 665, 13, 25, "Print"],
Cell[149447, 4111, 701, 15, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[150175, 4130, 379, 7, 89, "Text"],
Cell[CellGroupData[{
Cell[150579, 4141, 182, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[150786, 4148, 859, 16, 25, "Print"],
Cell[151648, 4166, 859, 16, 25, "Print"],
Cell[152510, 4184, 891, 16, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[153428, 4204, 188, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[153641, 4213, 184, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[153850, 4220, 697, 13, 45, "Print"],
Cell[154550, 4235, 697, 13, 45, "Print"],
Cell[155250, 4250, 723, 16, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[156000, 4270, 306, 5, 51, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156343, 4280, 141, 1, 83, "Section"],
Cell[156487, 4283, 394, 7, 70, "Text"],
Cell[CellGroupData[{
Cell[156906, 4294, 94, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[157025, 4299, 132, 2, 33, "Input"],
Cell[CellGroupData[{
Cell[157182, 4305, 631, 11, 25, "Print"],
Cell[157816, 4318, 631, 11, 25, "Print"],
Cell[158450, 4331, 705, 14, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159204, 4351, 182, 3, 33, "Input"],
Cell[CellGroupData[{
Cell[159411, 4358, 812, 15, 25, "Print"],
Cell[160226, 4375, 814, 15, 25, "Print"],
Cell[161043, 4392, 849, 17, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[161919, 4413, 145, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[162089, 4419, 161, 3, 33, "Input"],
Cell[162253, 4424, 505, 11, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162795, 4440, 311, 9, 62, "Input"],
Cell[CellGroupData[{
Cell[163131, 4453, 631, 11, 25, "Print"],
Cell[163765, 4466, 670, 13, 45, "Print"],
Cell[164438, 4481, 666, 12, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[165153, 4499, 381, 10, 62, "Input"],
Cell[CellGroupData[{
Cell[165559, 4513, 780, 14, 25, "Print"],
Cell[166342, 4529, 780, 14, 25, "Print"],
Cell[167125, 4545, 811, 14, 45, "Print"]
}, Open  ]]
}, Open  ]],
Cell[167963, 4563, 198, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[168186, 4572, 332, 9, 62, "Input"],
Cell[168521, 4583, 525, 12, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169083, 4600, 332, 9, 56, "Input"],
Cell[CellGroupData[{
Cell[169440, 4613, 608, 11, 31, "Print"],
Cell[170051, 4626, 682, 14, 56, "Print"],
Cell[170736, 4642, 608, 11, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[171393, 4659, 357, 10, 70, "Input"],
Cell[CellGroupData[{
Cell[171775, 4673, 760, 14, 31, "Print"],
Cell[172538, 4689, 789, 14, 56, "Print"],
Cell[173330, 4705, 758, 14, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[174115, 4723, 206, 5, 87, "Text"],
Cell[CellGroupData[{
Cell[174346, 4732, 98, 1, 41, "Input"],
Cell[174447, 4735, 495, 11, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174979, 4751, 133, 2, 41, "Input"],
Cell[CellGroupData[{
Cell[175137, 4757, 636, 11, 31, "Print"],
Cell[175776, 4770, 636, 11, 31, "Print"],
Cell[176415, 4783, 633, 11, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[177097, 4800, 157, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[177279, 4807, 818, 14, 56, "Print"],
Cell[178100, 4823, 818, 14, 56, "Print"],
Cell[178921, 4839, 848, 17, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[179818, 4862, 130, 2, 41, "Input"],
Cell[179951, 4866, 527, 11, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180515, 4882, 339, 9, 70, "Input"],
Cell[CellGroupData[{
Cell[180879, 4895, 655, 12, 31, "Print"],
Cell[181537, 4909, 653, 12, 31, "Print"],
Cell[182193, 4923, 655, 12, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[182875, 4939, 130, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[183030, 4944, 363, 9, 70, "Input"],
Cell[CellGroupData[{
Cell[183418, 4957, 838, 15, 56, "Print"],
Cell[184259, 4974, 868, 18, 56, "Print"],
Cell[185130, 4994, 859, 16, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[186016, 5014, 280, 5, 40, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186333, 5024, 104, 1, 52, "Subsection"],
Cell[186440, 5027, 227, 4, 63, "Text"],
Cell[CellGroupData[{
Cell[186692, 5035, 177, 3, 41, "Input"],
Cell[186872, 5040, 1911, 50, 173, "Output"]
}, Open  ]],
Cell[188798, 5093, 524, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[189347, 5105, 200, 5, 41, "Input"],
Cell[189550, 5112, 1368, 37, 65, "Output"]
}, Open  ]],
Cell[190933, 5152, 422, 7, 63, "Text"],
Cell[CellGroupData[{
Cell[191380, 5163, 159, 3, 41, "Input"],
Cell[191542, 5168, 1404, 37, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192983, 5210, 133, 1, 37, "Subsubsection"],
Cell[193119, 5213, 103, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[193247, 5218, 154, 3, 41, "Input"],
Cell[193404, 5223, 989, 25, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194430, 5253, 788, 23, 92, "Input"],
Cell[CellGroupData[{
Cell[195243, 5280, 1004, 24, 56, "Print"],
Cell[196250, 5306, 984, 23, 56, "Print"],
Cell[197237, 5331, 716, 14, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[197980, 5349, 981, 27, 115, "Text"],
Cell[198964, 5378, 185, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[199174, 5384, 193, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[199392, 5392, 991, 22, 56, "Print"],
Cell[200386, 5416, 991, 22, 56, "Print"],
Cell[201380, 5440, 749, 14, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[202156, 5458, 222, 5, 40, "Text"],
Cell[202381, 5465, 193, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[202599, 5473, 191, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[202815, 5481, 1310, 28, 56, "Print"],
Cell[204128, 5511, 1890, 51, 108, "Print"],
Cell[206021, 5564, 651, 12, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[206699, 5580, 486, 10, 87, "Text"],
Cell[CellGroupData[{
Cell[207210, 5594, 338, 9, 70, "Input"],
Cell[207551, 5605, 729, 18, 66, "Output"]
}, Open  ]],
Cell[208295, 5626, 91, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[208411, 5631, 339, 9, 70, "Input"],
Cell[208753, 5642, 729, 18, 66, "Output"]
}, Open  ]],
Cell[209497, 5663, 219, 4, 63, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209753, 5672, 118, 1, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[209896, 5677, 100, 1, 41, "Input"],
Cell[209999, 5680, 503, 11, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210539, 5696, 152, 3, 41, "Input"],
Cell[210694, 5701, 965, 25, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211696, 5731, 219, 5, 41, "Input"],
Cell[CellGroupData[{
Cell[211940, 5740, 754, 14, 31, "Print"],
Cell[212697, 5756, 755, 14, 31, "Print"],
Cell[213455, 5772, 1366, 33, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[214848, 5809, 194, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[215067, 5817, 347, 9, 41, "Input"],
Cell[CellGroupData[{
Cell[215439, 5830, 613, 11, 31, "Print"],
Cell[216055, 5843, 976, 22, 56, "Print"],
Cell[217034, 5867, 613, 11, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[217696, 5884, 419, 10, 41, "Input"],
Cell[CellGroupData[{
Cell[218140, 5898, 969, 20, 56, "Print"],
Cell[219112, 5920, 797, 14, 56, "Print"],
Cell[219912, 5936, 967, 20, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[220906, 5960, 125, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[221056, 5965, 165, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[221246, 5973, 1124, 25, 56, "Print"],
Cell[222373, 6000, 1704, 48, 108, "Print"],
Cell[224080, 6050, 467, 9, 31, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[224596, 6065, 165, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[224786, 6073, 2181, 57, 163, "Print"],
Cell[226970, 6132, 2131, 55, 111, "Print"],
Cell[229104, 6189, 1575, 40, 110, "Print"]
}, Open  ]]
}, Open  ]],
Cell[230706, 6233, 191, 4, 63, "Text"],
Cell[230900, 6239, 596, 12, 87, "Text"],
Cell[231499, 6253, 92, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[231616, 6258, 282, 6, 70, "Input"],
Cell[231901, 6266, 404, 8, 66, "Output"]
}, Open  ]],
Cell[232320, 6277, 92, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[232437, 6282, 492, 15, 71, "Input"],
Cell[232932, 6299, 548, 16, 67, "Output"]
}, Open  ]],
Cell[233495, 6318, 163, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[233683, 6324, 579, 17, 71, "Input"],
Cell[234265, 6343, 747, 23, 66, "Output"]
}, Open  ]],
Cell[235027, 6369, 142, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[235194, 6374, 357, 8, 70, "Input"],
Cell[235554, 6384, 354, 8, 66, "Output"]
}, Open  ]],
Cell[235923, 6395, 109, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[236057, 6400, 612, 17, 71, "Input"],
Cell[236672, 6419, 569, 17, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237278, 6441, 622, 18, 71, "Input"],
Cell[237903, 6461, 734, 23, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[238674, 6489, 359, 8, 70, "Input"],
Cell[239036, 6499, 352, 8, 66, "Output"]
}, Open  ]],
Cell[239403, 6510, 88, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[239516, 6515, 497, 15, 71, "Input"],
Cell[240016, 6532, 546, 16, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[240599, 6553, 549, 16, 71, "Input"],
Cell[241151, 6571, 716, 22, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241904, 6598, 354, 8, 70, "Input"],
Cell[242261, 6608, 352, 8, 66, "Output"]
}, Open  ]],
Cell[242628, 6619, 290, 7, 87, "Text"],
Cell[CellGroupData[{
Cell[242943, 6630, 282, 6, 70, "Input"],
Cell[243228, 6638, 380, 8, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[243645, 6651, 350, 9, 70, "Input"],
Cell[243998, 6662, 616, 16, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[244651, 6683, 474, 15, 71, "Input"],
Cell[245128, 6700, 522, 16, 67, "Output"]
}, Open  ]],
Cell[245665, 6719, 90, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[245780, 6724, 450, 14, 71, "Input"],
Cell[246233, 6740, 550, 16, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246820, 6761, 204, 5, 67, "Input"],
Cell[247027, 6768, 1085, 31, 173, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248149, 6804, 537, 16, 71, "Input"],
Cell[248689, 6822, 572, 17, 67, "Output"]
}, Open  ]],
Cell[249276, 6842, 141, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[249442, 6848, 497, 15, 71, "Input"],
Cell[249942, 6865, 548, 16, 67, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[250563, 6889, 127, 1, 103, "Section"],
Cell[CellGroupData[{
Cell[250715, 6894, 99, 1, 52, "Subsection"],
Cell[250817, 6897, 1959, 59, 1095, "Text"],
Cell[CellGroupData[{
Cell[252801, 6960, 234, 6, 41, "Input"],
Cell[253038, 6968, 417, 8, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[253492, 6981, 267, 7, 41, "Input"],
Cell[253762, 6990, 418, 8, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254217, 7003, 267, 7, 41, "Input"],
Cell[254487, 7012, 418, 8, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254942, 7025, 265, 7, 41, "Input"],
Cell[255210, 7034, 419, 8, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255666, 7047, 143, 2, 41, "Input"],
Cell[255812, 7051, 787, 21, 118, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256636, 7077, 176, 3, 41, "Input"],
Cell[256815, 7082, 257, 4, 41, "Output"]
}, Open  ]],
Cell[257087, 7089, 138, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[257250, 7094, 365, 10, 41, "Input"],
Cell[257618, 7106, 847, 23, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258502, 7134, 127, 2, 41, "Input"],
Cell[258632, 7138, 331, 5, 66, "Output"]
}, Open  ]],
Cell[258978, 7146, 122, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[259125, 7151, 361, 10, 41, "Input"],
Cell[259489, 7163, 855, 23, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[260381, 7191, 127, 2, 41, "Input"],
Cell[260511, 7195, 327, 5, 66, "Output"]
}, Open  ]],
Cell[260853, 7203, 104, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[260982, 7208, 363, 10, 41, "Input"],
Cell[261348, 7220, 854, 23, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262239, 7248, 126, 2, 41, "Input"],
Cell[262368, 7252, 305, 4, 41, "Output"]
}, Open  ]],
Cell[262688, 7259, 460, 9, 87, "Text"],
Cell[CellGroupData[{
Cell[263173, 7272, 171, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[263369, 7279, 521, 10, 31, "Print"],
Cell[263893, 7291, 560, 12, 56, "Print"],
Cell[264456, 7305, 556, 11, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[265061, 7322, 167, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[265253, 7329, 490, 9, 31, "Print"],
Cell[265746, 7340, 552, 12, 56, "Print"],
Cell[266301, 7354, 525, 10, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[266875, 7370, 168, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[267068, 7377, 490, 9, 31, "Print"],
Cell[267561, 7388, 529, 11, 56, "Print"],
Cell[268093, 7401, 546, 11, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[268688, 7418, 171, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[268884, 7425, 484, 9, 31, "Print"],
Cell[269371, 7436, 547, 12, 56, "Print"],
Cell[269921, 7450, 541, 11, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[270489, 7465, 144, 5, 63, "Text"],
Cell[CellGroupData[{
Cell[270658, 7474, 406, 11, 41, "Input"],
Cell[271067, 7487, 904, 24, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272008, 7516, 127, 2, 41, "Input"],
Cell[272138, 7520, 362, 6, 66, "Output"]
}, Open  ]],
Cell[272515, 7529, 145, 4, 63, "Text"],
Cell[CellGroupData[{
Cell[272685, 7537, 195, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[272905, 7545, 641, 12, 31, "Print"],
Cell[273549, 7559, 639, 12, 31, "Print"],
Cell[274191, 7573, 671, 12, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[274911, 7591, 193, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[275129, 7599, 641, 12, 31, "Print"],
Cell[275773, 7613, 640, 12, 31, "Print"],
Cell[276416, 7627, 694, 13, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[277159, 7646, 193, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[277377, 7654, 639, 12, 31, "Print"],
Cell[278019, 7668, 639, 12, 31, "Print"],
Cell[278661, 7682, 694, 13, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279404, 7701, 195, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[279624, 7709, 636, 12, 31, "Print"],
Cell[280263, 7723, 636, 12, 31, "Print"],
Cell[280902, 7737, 668, 12, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[281597, 7753, 246, 5, 63, "Text"],
Cell[CellGroupData[{
Cell[281868, 7762, 295, 9, 41, "Input"],
Cell[282166, 7773, 857, 23, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[283060, 7801, 126, 2, 41, "Input"],
Cell[283189, 7805, 309, 4, 41, "Output"]
}, Open  ]],
Cell[283513, 7812, 272, 5, 63, "Text"],
Cell[CellGroupData[{
Cell[283810, 7821, 279, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[284114, 7832, 881, 21, 56, "Print"],
Cell[284998, 7855, 860, 20, 56, "Print"],
Cell[285861, 7877, 595, 11, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[286483, 7892, 132, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[286640, 7897, 281, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[286946, 7908, 857, 20, 56, "Print"],
Cell[287806, 7930, 879, 21, 56, "Print"],
Cell[288688, 7953, 594, 11, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[289309, 7968, 183, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[289517, 7974, 327, 8, 41, "Input"],
Cell[CellGroupData[{
Cell[289869, 7986, 887, 21, 56, "Print"],
Cell[290759, 8009, 887, 21, 56, "Print"],
Cell[291649, 8032, 642, 13, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[292318, 8049, 181, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[292524, 8055, 330, 8, 41, "Input"],
Cell[CellGroupData[{
Cell[292879, 8067, 907, 22, 56, "Print"],
Cell[293789, 8091, 905, 22, 56, "Print"],
Cell[294697, 8115, 641, 13, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[295365, 8132, 164, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[295554, 8138, 1416, 45, 125, "Input"],
Cell[296973, 8185, 1496, 46, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298506, 8236, 131, 2, 41, "Input"],
Cell[298640, 8240, 738, 20, 66, "Output"]
}, Open  ]],
Cell[299393, 8263, 157, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[299575, 8269, 1439, 45, 125, "Input"],
Cell[301017, 8316, 1479, 45, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302533, 8366, 126, 2, 41, "Input"],
Cell[302662, 8370, 521, 10, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[303220, 8385, 131, 2, 41, "Input"],
Cell[303354, 8389, 794, 20, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304185, 8414, 125, 2, 41, "Input"],
Cell[304313, 8418, 733, 18, 66, "Output"]
}, Open  ]],
Cell[305061, 8439, 123, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[305209, 8444, 306, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[305540, 8455, 712, 13, 31, "Print"],
Cell[306255, 8470, 710, 13, 31, "Print"],
Cell[306968, 8485, 1324, 32, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[308341, 8523, 308, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[308674, 8534, 706, 13, 31, "Print"],
Cell[309383, 8549, 705, 13, 31, "Print"],
Cell[310091, 8564, 1318, 32, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[311458, 8602, 302, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[311785, 8613, 707, 13, 31, "Print"],
Cell[312495, 8628, 707, 13, 31, "Print"],
Cell[313205, 8643, 1341, 33, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[314595, 8682, 301, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[314921, 8693, 713, 13, 31, "Print"],
Cell[315637, 8708, 711, 13, 31, "Print"],
Cell[316351, 8723, 1303, 31, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[317681, 8758, 159, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[317865, 8764, 1415, 45, 125, "Input"],
Cell[319283, 8811, 1503, 46, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320823, 8862, 127, 2, 41, "Input"],
Cell[320953, 8866, 522, 10, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321512, 8881, 129, 2, 41, "Input"],
Cell[321644, 8885, 772, 19, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322453, 8909, 125, 2, 41, "Input"],
Cell[322581, 8913, 715, 17, 67, "Output"]
}, Open  ]],
Cell[323311, 8933, 154, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[323490, 8939, 1429, 45, 125, "Input"],
Cell[324922, 8986, 1480, 45, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326439, 9036, 127, 2, 41, "Input"],
Cell[326569, 9040, 751, 21, 67, "Output"]
}, Open  ]],
Cell[327335, 9064, 208, 3, 40, "Text"],
Cell[CellGroupData[{
Cell[327568, 9071, 667, 20, 70, "Input"],
Cell[328238, 9093, 432, 8, 66, "Output"]
}, Open  ]],
Cell[328685, 9104, 310, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[329020, 9112, 750, 22, 71, "Input"],
Cell[329773, 9136, 448, 9, 66, "Output"]
}, Open  ]],
Cell[330236, 9148, 161, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[330422, 9154, 657, 18, 70, "Input"],
Cell[331082, 9174, 307, 4, 41, "Output"]
}, Open  ]],
Cell[331404, 9181, 314, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[331743, 9189, 684, 18, 71, "Input"],
Cell[332430, 9209, 330, 5, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[332821, 9221, 132, 1, 103, "Section"],
Cell[332956, 9224, 254, 4, 41, "Input"],
Cell[333213, 9230, 101, 2, 41, "Input"],
Cell[333317, 9234, 58, 0, 40, "Text"],
Cell[CellGroupData[{
Cell[333400, 9238, 100, 1, 41, "Input"],
Cell[333503, 9241, 1071, 28, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[334611, 9274, 167, 2, 52, "Subsection"],
Cell[CellGroupData[{
Cell[334803, 9280, 96, 1, 41, "Input"],
Cell[334902, 9283, 841, 22, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335780, 9310, 92, 1, 41, "Input"],
Cell[335875, 9313, 888, 23, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336800, 9341, 94, 1, 41, "Input"],
Cell[336897, 9344, 861, 23, 96, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[337807, 9373, 240, 4, 52, "Subsection"],
Cell[338050, 9379, 23, 0, 40, "Text"],
Cell[CellGroupData[{
Cell[338098, 9383, 151, 3, 41, "Input"],
Cell[338252, 9388, 444, 10, 66, "Output"]
}, Open  ]],
Cell[338711, 9401, 90, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[338826, 9406, 150, 3, 41, "Input"],
Cell[338979, 9411, 508, 11, 66, "Output"]
}, Open  ]],
Cell[339502, 9425, 89, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[339616, 9430, 150, 3, 41, "Input"],
Cell[339769, 9435, 442, 10, 66, "Output"]
}, Open  ]],
Cell[340226, 9448, 210, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[340461, 9456, 135, 2, 41, "Input"],
Cell[CellGroupData[{
Cell[340621, 9462, 713, 18, 56, "Print"],
Cell[341337, 9482, 768, 18, 56, "Print"],
Cell[342108, 9502, 713, 18, 56, "Print"]
}, Open  ]]
}, Open  ]],
Cell[342848, 9524, 198, 3, 42, "Text"],
Cell[CellGroupData[{
Cell[343071, 9531, 99, 1, 41, "Input"],
Cell[343173, 9534, 876, 23, 96, "Output"]
}, Open  ]],
Cell[344064, 9560, 123, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[344212, 9565, 132, 2, 41, "Input"],
Cell[CellGroupData[{
Cell[344369, 9571, 357, 7, 31, "Print"],
Cell[344729, 9580, 357, 7, 31, "Print"],
Cell[345089, 9589, 419, 8, 56, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[345569, 9604, 112, 1, 52, "Subsection"],
Cell[345684, 9607, 162, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[345871, 9613, 121, 2, 41, "Input"],
Cell[345995, 9617, 1131, 31, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[347163, 9653, 198, 3, 41, "Input"],
Cell[347364, 9658, 1199, 33, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348600, 9696, 127, 2, 41, "Input"],
Cell[348730, 9700, 1211, 33, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349978, 9738, 145, 3, 41, "Input"],
Cell[350126, 9743, 999, 29, 101, "Output"]
}, Open  ]],
Cell[351140, 9775, 94, 1, 41, "Input"],
Cell[CellGroupData[{
Cell[351259, 9780, 150, 3, 41, "Input"],
Cell[351412, 9785, 1054, 31, 101, "Output"]
}, Open  ]],
Cell[352481, 9819, 112, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[352618, 9824, 121, 2, 41, "Input"],
Cell[352742, 9828, 1053, 29, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353832, 9862, 124, 2, 41, "Input"],
Cell[353959, 9866, 1061, 29, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355057, 9900, 127, 2, 41, "Input"],
Cell[355187, 9904, 1052, 29, 101, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[356288, 9939, 210, 4, 52, "Subsection"],
Cell[CellGroupData[{
Cell[356523, 9947, 290, 7, 41, "Input"],
Cell[356816, 9956, 996, 26, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357849, 9987, 177, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[358051, 9994, 381, 8, 31, "Print"],
Cell[358435, 10004, 443, 9, 56, "Print"],
Cell[358881, 10015, 380, 8, 31, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[359322, 10030, 131, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[359478, 10035, 116, 2, 41, "Input"],
Cell[359597, 10039, 886, 23, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360520, 10067, 123, 2, 41, "Input"],
Cell[360646, 10071, 231, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360914, 10079, 119, 2, 41, "Input"],
Cell[361036, 10083, 841, 23, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361914, 10111, 119, 2, 41, "Input"],
Cell[362036, 10115, 233, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[362306, 10123, 119, 2, 41, "Input"],
Cell[362428, 10127, 867, 22, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363332, 10154, 121, 2, 41, "Input"],
Cell[363456, 10158, 234, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[363739, 10167, 128, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[363892, 10172, 117, 2, 41, "Input"],
Cell[364012, 10176, 831, 22, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[364880, 10203, 120, 2, 41, "Input"],
Cell[365003, 10207, 258, 4, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365298, 10216, 117, 2, 41, "Input"],
Cell[365418, 10220, 837, 22, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366292, 10247, 121, 2, 41, "Input"],
Cell[366416, 10251, 247, 4, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366700, 10260, 117, 2, 41, "Input"],
Cell[366820, 10264, 837, 22, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367694, 10291, 121, 2, 41, "Input"],
Cell[367818, 10295, 256, 4, 66, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[368123, 10305, 124, 1, 52, "Subsection"],
Cell[368250, 10308, 234, 4, 63, "Text"],
Cell[CellGroupData[{
Cell[368509, 10316, 146, 3, 41, "Input"],
Cell[368658, 10321, 1056, 26, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369751, 10352, 147, 3, 41, "Input"],
Cell[369901, 10357, 1053, 29, 101, "Output"]
}, Open  ]],
Cell[370969, 10389, 127, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[371121, 10394, 239, 6, 41, "Input"],
Cell[371363, 10402, 3177, 80, 101, "Output"]
}, Open  ]],
Cell[374555, 10485, 179, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[374759, 10493, 242, 6, 41, "Input"],
Cell[375004, 10501, 1010, 27, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[376051, 10533, 234, 6, 41, "Input"],
Cell[376288, 10541, 2041, 52, 101, "Output"]
}, Open  ]],
Cell[378344, 10596, 120, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[378489, 10601, 128, 2, 41, "Input"],
Cell[378620, 10605, 2857, 75, 101, "Output"]
}, Open  ]],
Cell[381492, 10683, 263, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[381780, 10692, 415, 13, 41, "Input"],
Cell[382198, 10707, 1652, 45, 98, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[383911, 10759, 182, 2, 103, "Section"],
Cell[384096, 10763, 300, 4, 41, "Input"],
Cell[384399, 10769, 125, 2, 41, "Input"],
Cell[384527, 10773, 124, 1, 40, "Text"],
Cell[384654, 10776, 118, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[384797, 10781, 100, 1, 41, "Input"],
Cell[384900, 10784, 213, 3, 41, "Output"]
}, Open  ]],
Cell[385128, 10790, 110, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[385263, 10795, 101, 1, 41, "Input"],
Cell[385367, 10798, 244, 3, 41, "Output"]
}, Open  ]],
Cell[385626, 10804, 130, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[385781, 10809, 217, 7, 41, "Input"],
Cell[386001, 10818, 338, 8, 67, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386376, 10831, 111, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[386512, 10836, 284, 6, 90, "Input"],
Cell[386799, 10844, 247, 5, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387083, 10854, 127, 2, 41, "Input"],
Cell[387213, 10858, 175, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387425, 10866, 122, 2, 41, "Input"],
Cell[387550, 10870, 170, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387757, 10878, 125, 2, 41, "Input"],
Cell[387885, 10882, 173, 3, 41, "Output"]
}, Open  ]],
Cell[388073, 10888, 264, 5, 63, "Text"],
Cell[388340, 10895, 290, 8, 41, "Input"],
Cell[CellGroupData[{
Cell[388655, 10907, 129, 2, 41, "Input"],
Cell[388787, 10911, 344, 8, 62, "Output"]
}, Open  ]],
Cell[389146, 10922, 230, 4, 63, "Text"],
Cell[CellGroupData[{
Cell[389401, 10930, 1294, 37, 178, "Input"],
Cell[390698, 10969, 963, 29, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391698, 11003, 1295, 37, 178, "Input"],
Cell[392996, 11042, 962, 29, 121, "Output"]
}, Open  ]],
Cell[393973, 11074, 166, 3, 40, "Text"],
Cell[394142, 11079, 175, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[394342, 11087, 127, 2, 41, "Input"],
Cell[394472, 11091, 208, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[394729, 11100, 102, 1, 52, "Subsection"],
Cell[394834, 11103, 223, 4, 63, "Text"],
Cell[CellGroupData[{
Cell[395082, 11111, 165, 3, 41, "Input"],
Cell[395250, 11116, 239, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395526, 11125, 169, 3, 41, "Input"],
Cell[395698, 11130, 218, 4, 41, "Output"]
}, Open  ]],
Cell[395931, 11137, 164, 3, 40, "Text"],
Cell[396098, 11142, 344, 10, 41, "Input"],
Cell[CellGroupData[{
Cell[396467, 11156, 127, 2, 41, "Input"],
Cell[396597, 11160, 333, 7, 41, "Output"]
}, Open  ]],
Cell[396945, 11170, 160, 3, 40, "Text"],
Cell[397108, 11175, 173, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[397306, 11183, 127, 2, 41, "Input"],
Cell[397436, 11187, 202, 4, 41, "Output"]
}, Open  ]],
Cell[397653, 11194, 163, 3, 40, "Text"],
Cell[397819, 11199, 185, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[398029, 11207, 127, 2, 41, "Input"],
Cell[398159, 11211, 176, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398372, 11219, 133, 2, 41, "Input"],
Cell[398508, 11223, 145, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398690, 11231, 133, 2, 41, "Input"],
Cell[398826, 11235, 143, 3, 41, "Output"]
}, Open  ]],
Cell[398984, 11241, 204, 5, 41, "Input"],
Cell[CellGroupData[{
Cell[399213, 11250, 127, 2, 41, "Input"],
Cell[399343, 11254, 234, 5, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[399614, 11264, 130, 2, 41, "Input"],
Cell[399747, 11268, 206, 6, 41, "Output"]
}, Open  ]],
Cell[399968, 11277, 94, 1, 41, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[400099, 11283, 181, 4, 52, "Subsection"],
Cell[400283, 11289, 618, 11, 157, "Text"],
Cell[CellGroupData[{
Cell[400926, 11304, 128, 2, 41, "Input"],
Cell[401057, 11308, 106, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401200, 11315, 128, 2, 41, "Input"],
Cell[401331, 11319, 108, 2, 41, "Output"]
}, Open  ]],
Cell[401454, 11324, 361, 7, 111, "Text"],
Cell[CellGroupData[{
Cell[401840, 11335, 131, 2, 41, "Input"],
Cell[401974, 11339, 110, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402121, 11346, 133, 2, 41, "Input"],
Cell[402257, 11350, 108, 2, 41, "Output"]
}, Open  ]],
Cell[402380, 11355, 209, 5, 87, "Text"],
Cell[CellGroupData[{
Cell[402614, 11364, 159, 3, 41, "Input"],
Cell[402776, 11369, 132, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402945, 11377, 155, 3, 41, "Input"],
Cell[403103, 11382, 134, 3, 41, "Output"]
}, Open  ]],
Cell[403252, 11388, 480, 8, 87, "Text"],
Cell[403735, 11398, 262, 5, 63, "Text"],
Cell[CellGroupData[{
Cell[404022, 11407, 129, 2, 41, "Input"],
Cell[404154, 11411, 107, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404298, 11418, 168, 3, 41, "Input"],
Cell[404469, 11423, 135, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404641, 11431, 132, 2, 41, "Input"],
Cell[404776, 11435, 110, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[404935, 11443, 127, 1, 52, "Subsection"],
Cell[405065, 11446, 381, 8, 111, "Text"],
Cell[405449, 11456, 202, 5, 41, "Input"],
Cell[CellGroupData[{
Cell[405676, 11465, 127, 2, 41, "Input"],
Cell[405806, 11469, 227, 4, 41, "Output"]
}, Open  ]],
Cell[406048, 11476, 187, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[406260, 11484, 193, 4, 41, "Input"],
Cell[406456, 11490, 168, 4, 41, "Output"]
}, Open  ]],
Cell[406639, 11497, 115, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[406779, 11502, 193, 4, 41, "Input"],
Cell[406975, 11508, 168, 4, 41, "Output"]
}, Open  ]],
Cell[407158, 11515, 120, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[407303, 11520, 191, 4, 41, "Input"],
Cell[407497, 11526, 168, 4, 41, "Output"]
}, Open  ]],
Cell[407680, 11533, 105, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[407810, 11538, 269, 7, 41, "Input"],
Cell[408082, 11547, 165, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408284, 11556, 247, 7, 41, "Input"],
Cell[408534, 11565, 165, 4, 41, "Output"]
}, Open  ]],
Cell[408714, 11572, 105, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[408844, 11577, 273, 7, 41, "Input"],
Cell[409120, 11586, 167, 4, 41, "Output"]
}, Open  ]],
Cell[409302, 11593, 135, 1, 40, "Text"],
Cell[CellGroupData[{
Cell[409462, 11598, 374, 10, 41, "Input"],
Cell[409839, 11610, 165, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[410041, 11619, 348, 9, 41, "Input"],
Cell[410392, 11630, 167, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[410596, 11639, 350, 9, 41, "Input"],
Cell[410949, 11650, 167, 4, 41, "Output"]
}, Open  ]],
Cell[411131, 11657, 162, 3, 40, "Text"],
Cell[CellGroupData[{
Cell[411318, 11664, 326, 9, 41, "Input"],
Cell[411647, 11675, 167, 4, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
